/********************************************************************************
** Form generated from reading UI file 'outputlocation.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OUTPUTLOCATION_H
#define UI_OUTPUTLOCATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"

QT_BEGIN_NAMESPACE

class Ui_OutputLocationDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_3;
    QGroupBox *positionGroupBox;
    QVBoxLayout *verticalLayout_2;
    QFormLayout *positionFormLayout;
    QGroupBox *urlGroupBox;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *lowerFilenameCheckBox;
    KMessageWidget *messageWidget;
    QFormLayout *urlFormLayout;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *OutputLocationDialog)
    {
        if (OutputLocationDialog->objectName().isEmpty())
            OutputLocationDialog->setObjectName("OutputLocationDialog");
        OutputLocationDialog->resize(448, 250);
        verticalLayout = new QVBoxLayout(OutputLocationDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox_3 = new QGroupBox(OutputLocationDialog);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_3 = new QGridLayout(groupBox_3);
        gridLayout_3->setObjectName("gridLayout_3");
        positionGroupBox = new QGroupBox(groupBox_3);
        positionGroupBox->setObjectName("positionGroupBox");
        positionGroupBox->setEnabled(true);
        positionGroupBox->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(positionGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        positionFormLayout = new QFormLayout();
        positionFormLayout->setObjectName("positionFormLayout");

        verticalLayout_2->addLayout(positionFormLayout);


        gridLayout_3->addWidget(positionGroupBox, 1, 0, 1, 1);

        urlGroupBox = new QGroupBox(groupBox_3);
        urlGroupBox->setObjectName("urlGroupBox");
        urlGroupBox->setFlat(true);
        urlGroupBox->setCheckable(false);
        verticalLayout_3 = new QVBoxLayout(urlGroupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        lowerFilenameCheckBox = new QCheckBox(urlGroupBox);
        lowerFilenameCheckBox->setObjectName("lowerFilenameCheckBox");
        lowerFilenameCheckBox->setChecked(true);

        verticalLayout_3->addWidget(lowerFilenameCheckBox);

        messageWidget = new KMessageWidget(urlGroupBox);
        messageWidget->setObjectName("messageWidget");

        verticalLayout_3->addWidget(messageWidget);

        urlFormLayout = new QFormLayout();
        urlFormLayout->setObjectName("urlFormLayout");
        urlFormLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);

        verticalLayout_3->addLayout(urlFormLayout);


        gridLayout_3->addWidget(urlGroupBox, 0, 0, 1, 1);


        verticalLayout->addWidget(groupBox_3);

        verticalSpacer = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(OutputLocationDialog);

        QMetaObject::connectSlotsByName(OutputLocationDialog);
    } // setupUi

    void retranslateUi(QWidget *OutputLocationDialog)
    {
        groupBox_3->setTitle(tr2i18n("Choose where to save the generated content.", nullptr));
        lowerFilenameCheckBox->setText(tr2i18n("Lower case file names", "@option:check"));
        (void)OutputLocationDialog;
    } // retranslateUi

};

namespace Ui {
    class OutputLocationDialog: public Ui_OutputLocationDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OUTPUTLOCATION_H

