/****************************************************************************
** Meta object code from reading C++ file 'workingsetcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/shell/workingsetcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'workingsetcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop20WorkingSetControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::WorkingSetController::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop20WorkingSetControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::WorkingSetController",
        "workingSetAdded",
        "",
        "WorkingSet*",
        "set",
        "aboutToRemoveWorkingSet",
        "workingSetSwitched",
        "saveArea",
        "Sublime::Area*",
        "area",
        "areaCreated",
        "nextDocument",
        "previousDocument",
        "showGlobalToolTip",
        "changingWorkingSet",
        "oldArea",
        "oldSet",
        "newSet",
        "changedWorkingSet",
        "viewAdded",
        "Sublime::AreaIndex*",
        "Sublime::View*",
        "clearWorkingSet"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'workingSetAdded'
        QtMocHelpers::SignalData<void(WorkingSet *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'aboutToRemoveWorkingSet'
        QtMocHelpers::SignalData<void(WorkingSet *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'workingSetSwitched'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveArea'
        QtMocHelpers::SlotData<void(Sublime::Area *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'areaCreated'
        QtMocHelpers::SlotData<void(Sublime::Area *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'nextDocument'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'previousDocument'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showGlobalToolTip'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changingWorkingSet'
        QtMocHelpers::SlotData<void(Sublime::Area *, Sublime::Area *, const QString &, const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'changedWorkingSet'
        QtMocHelpers::SlotData<void(Sublime::Area *, Sublime::Area *, const QString &, const QString &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'viewAdded'
        QtMocHelpers::SlotData<void(Sublime::AreaIndex *, Sublime::View *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 2 }, { 0x80000000 | 21, 2 },
        }}),
        // Slot 'clearWorkingSet'
        QtMocHelpers::SlotData<void(Sublime::Area *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WorkingSetController, qt_meta_tag_ZN8KDevelop20WorkingSetControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::WorkingSetController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop20WorkingSetControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop20WorkingSetControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop20WorkingSetControllerE_t>.metaTypes,
    nullptr
} };

void KDevelop::WorkingSetController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorkingSetController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->workingSetAdded((*reinterpret_cast<std::add_pointer_t<WorkingSet*>>(_a[1]))); break;
        case 1: _t->aboutToRemoveWorkingSet((*reinterpret_cast<std::add_pointer_t<WorkingSet*>>(_a[1]))); break;
        case 2: _t->workingSetSwitched(); break;
        case 3: _t->saveArea((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        case 4: _t->areaCreated((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        case 5: _t->nextDocument(); break;
        case 6: _t->previousDocument(); break;
        case 7: _t->showGlobalToolTip(); break;
        case 8: _t->changingWorkingSet((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 9: _t->changedWorkingSet((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 10: _t->viewAdded((*reinterpret_cast<std::add_pointer_t<Sublime::AreaIndex*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[2]))); break;
        case 11: _t->clearWorkingSet((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorkingSetController::*)(WorkingSet * )>(_a, &WorkingSetController::workingSetAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkingSetController::*)(WorkingSet * )>(_a, &WorkingSetController::aboutToRemoveWorkingSet, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WorkingSetController::*)()>(_a, &WorkingSetController::workingSetSwitched, 2))
            return;
    }
}

const QMetaObject *KDevelop::WorkingSetController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::WorkingSetController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop20WorkingSetControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::WorkingSetController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::WorkingSetController::workingSetAdded(WorkingSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevelop::WorkingSetController::aboutToRemoveWorkingSet(WorkingSet * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDevelop::WorkingSetController::workingSetSwitched()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
