/********************************************************************************
** Form generated from reading UI file 'plasmoidexecutionconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLASMOIDEXECUTIONCONFIG_H
#define UI_PLASMOIDEXECUTIONCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "project/widgets/dependencieswidget.h"

QT_BEGIN_NAMESPACE

class Ui_PlasmoidExecutionPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label;
    QComboBox *identifier;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout_2;
    QLabel *label_2;
    QComboBox *formFactor;
    QLabel *label_3;
    QComboBox *themes;
    QGroupBox *groupBox_3;
    QFormLayout *formLayout_3;
    QLabel *label_7;
    KDevelop::DependenciesWidget *dependencies;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *PlasmoidExecutionPage)
    {
        if (PlasmoidExecutionPage->objectName().isEmpty())
            PlasmoidExecutionPage->setObjectName("PlasmoidExecutionPage");
        PlasmoidExecutionPage->resize(633, 616);
        verticalLayout = new QVBoxLayout(PlasmoidExecutionPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(PlasmoidExecutionPage);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        identifier = new QComboBox(groupBox);
        identifier->setObjectName("identifier");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(identifier->sizePolicy().hasHeightForWidth());
        identifier->setSizePolicy(sizePolicy);
        identifier->setEditable(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, identifier);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(PlasmoidExecutionPage);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy1);
        formLayout_2 = new QFormLayout(groupBox_2);
        formLayout_2->setObjectName("formLayout_2");
        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        formFactor = new QComboBox(groupBox_2);
        formFactor->addItem(QString::fromUtf8("planar"));
        formFactor->addItem(QString::fromUtf8("horizontal"));
        formFactor->addItem(QString::fromUtf8("vertical"));
        formFactor->addItem(QString::fromUtf8("mediacenter"));
        formFactor->setObjectName("formFactor");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, formFactor);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        themes = new QComboBox(groupBox_2);
        themes->setObjectName("themes");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, themes);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(PlasmoidExecutionPage);
        groupBox_3->setObjectName("groupBox_3");
        formLayout_3 = new QFormLayout(groupBox_3);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_7 = new QLabel(groupBox_3);
        label_7->setObjectName("label_7");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        dependencies = new KDevelop::DependenciesWidget(groupBox_3);
        dependencies->setObjectName("dependencies");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, dependencies);


        verticalLayout->addWidget(groupBox_3);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

#if QT_CONFIG(shortcut)
        label->setBuddy(identifier);
        label_2->setBuddy(formFactor);
        label_3->setBuddy(themes);
        label_7->setBuddy(dependencies);
#endif // QT_CONFIG(shortcut)

        retranslateUi(PlasmoidExecutionPage);

        QMetaObject::connectSlotsByName(PlasmoidExecutionPage);
    } // setupUi

    void retranslateUi(QWidget *PlasmoidExecutionPage)
    {
        groupBox->setTitle(tr2i18n("Plasmoid", "@title:group"));
        label->setText(tr2i18n("Path or name:", "@label:listbox"));
        groupBox_2->setTitle(tr2i18n("Behavior", "@title:group"));
        label_2->setText(tr2i18n("Form factor:", "@label:listbox"));

        label_3->setText(tr2i18n("Theme:", "@label:listbox"));
        groupBox_3->setTitle(tr2i18n("Dependencies", "@title:group"));
        label_7->setText(tr2i18n("&Targets:", "@label:chooser"));
        (void)PlasmoidExecutionPage;
    } // retranslateUi

};

namespace Ui {
    class PlasmoidExecutionPage: public Ui_PlasmoidExecutionPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLASMOIDEXECUTIONCONFIG_H

