/********************************************************************************
** Form generated from reading UI file 'globalconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GLOBALCONFIGPAGE_H
#define UI_GLOBALCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

namespace cppcheck {

class Ui_GlobalConfigPage
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *pathsGroupBox;
    QHBoxLayout *horizontalLayout;
    QLabel *cppcheckLabel;
    KUrlRequester *kcfg_executablePath;
    QGroupBox *outputGroupBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_hideOutputView;
    QCheckBox *kcfg_showXmlOutput;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *cppcheck__GlobalConfigPage)
    {
        if (cppcheck__GlobalConfigPage->objectName().isEmpty())
            cppcheck__GlobalConfigPage->setObjectName("cppcheck__GlobalConfigPage");
        cppcheck__GlobalConfigPage->resize(757, 397);
        verticalLayout_2 = new QVBoxLayout(cppcheck__GlobalConfigPage);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        pathsGroupBox = new QGroupBox(cppcheck__GlobalConfigPage);
        pathsGroupBox->setObjectName("pathsGroupBox");
        horizontalLayout = new QHBoxLayout(pathsGroupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        cppcheckLabel = new QLabel(pathsGroupBox);
        cppcheckLabel->setObjectName("cppcheckLabel");
        cppcheckLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(cppcheckLabel);

        kcfg_executablePath = new KUrlRequester(pathsGroupBox);
        kcfg_executablePath->setObjectName("kcfg_executablePath");

        horizontalLayout->addWidget(kcfg_executablePath);


        verticalLayout_2->addWidget(pathsGroupBox);

        outputGroupBox = new QGroupBox(cppcheck__GlobalConfigPage);
        outputGroupBox->setObjectName("outputGroupBox");
        verticalLayout = new QVBoxLayout(outputGroupBox);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_hideOutputView = new QCheckBox(outputGroupBox);
        kcfg_hideOutputView->setObjectName("kcfg_hideOutputView");

        verticalLayout->addWidget(kcfg_hideOutputView);

        kcfg_showXmlOutput = new QCheckBox(outputGroupBox);
        kcfg_showXmlOutput->setObjectName("kcfg_showXmlOutput");

        verticalLayout->addWidget(kcfg_showXmlOutput);


        verticalLayout_2->addWidget(outputGroupBox);

        verticalSpacer = new QSpacerItem(20, 149, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        cppcheckLabel->setBuddy(kcfg_executablePath);
#endif // QT_CONFIG(shortcut)

        retranslateUi(cppcheck__GlobalConfigPage);

        QMetaObject::connectSlotsByName(cppcheck__GlobalConfigPage);
    } // setupUi

    void retranslateUi(QWidget *cppcheck__GlobalConfigPage)
    {
        pathsGroupBox->setTitle(tr2i18n("Paths", "@title:group"));
        cppcheckLabel->setText(tr2i18n("Cppchec&k executable:", "@label:chooser"));
        outputGroupBox->setTitle(tr2i18n("Output", "@title:group"));
        kcfg_hideOutputView->setText(tr2i18n("Hide output view during check", "@option:check"));
        kcfg_showXmlOutput->setText(tr2i18n("Show Cppcheck XML output in the output view", "@option:check"));
        (void)cppcheck__GlobalConfigPage;
    } // retranslateUi

};

} // namespace cppcheck

namespace cppcheck {
namespace Ui {
    class GlobalConfigPage: public Ui_GlobalConfigPage {};
} // namespace Ui
} // namespace cppcheck

#endif // GLOBALCONFIGPAGE_H

