/********************************************************************************
** Form generated from reading UI file 'compilerswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPILERSWIDGET_H
#define UI_COMPILERSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_CompilersWidget
{
public:
    QGridLayout *gridLayout;
    QTreeView *compilers;
    QVBoxLayout *verticalLayout;
    QPushButton *addButton;
    QPushButton *removeButton;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *compilerName;
    QLabel *label_2;
    KUrlRequester *compilerPath;

    void setupUi(QWidget *CompilersWidget)
    {
        if (CompilersWidget->objectName().isEmpty())
            CompilersWidget->setObjectName("CompilersWidget");
        CompilersWidget->resize(547, 410);
        gridLayout = new QGridLayout(CompilersWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        compilers = new QTreeView(CompilersWidget);
        compilers->setObjectName("compilers");

        gridLayout->addWidget(compilers, 0, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        addButton = new QPushButton(CompilersWidget);
        addButton->setObjectName("addButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addButton->setIcon(icon);

        verticalLayout->addWidget(addButton);

        removeButton = new QPushButton(CompilersWidget);
        removeButton->setObjectName("removeButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        removeButton->setIcon(icon1);

        verticalLayout->addWidget(removeButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 0, 1, 1, 1);

        groupBox = new QGroupBox(CompilersWidget);
        groupBox->setObjectName("groupBox");
        groupBox->setTitle(QString::fromUtf8(""));
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        compilerName = new QLineEdit(groupBox);
        compilerName->setObjectName("compilerName");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, compilerName);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        compilerPath = new KUrlRequester(groupBox);
        compilerPath->setObjectName("compilerPath");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, compilerPath);


        gridLayout->addWidget(groupBox, 1, 0, 1, 1);


        retranslateUi(CompilersWidget);

        QMetaObject::connectSlotsByName(CompilersWidget);
    } // setupUi

    void retranslateUi(QWidget *CompilersWidget)
    {
        addButton->setText(tr2i18n("&Add", "@action:button"));
        removeButton->setText(tr2i18n("&Remove", "@action:button"));
        label->setText(tr2i18n("Name:", "@label:textbox"));
        label_2->setText(tr2i18n("Compiler executable:", "@label:chooser"));
        (void)CompilersWidget;
    } // retranslateUi

};

namespace Ui {
    class CompilersWidget: public Ui_CompilersWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMPILERSWIDGET_H

