/********************************************************************************
** Form generated from reading UI file 'editstyledialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITSTYLEDIALOG_H
#define UI_EDITSTYLEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EditStyle
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_2;
    QWidget *settingsWidgetParent;
    QCheckBox *showPreviewCheckBox;
    QWidget *previewArea;
    QVBoxLayout *verticalLayout;
    QLabel *lblPreview;
    QWidget *textEditor;

    void setupUi(QWidget *EditStyle)
    {
        if (EditStyle->objectName().isEmpty())
            EditStyle->setObjectName("EditStyle");
        EditStyle->resize(597, 300);
        horizontalLayout = new QHBoxLayout(EditStyle);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        settingsWidgetParent = new QWidget(EditStyle);
        settingsWidgetParent->setObjectName("settingsWidgetParent");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(settingsWidgetParent->sizePolicy().hasHeightForWidth());
        settingsWidgetParent->setSizePolicy(sizePolicy);

        verticalLayout_2->addWidget(settingsWidgetParent);

        showPreviewCheckBox = new QCheckBox(EditStyle);
        showPreviewCheckBox->setObjectName("showPreviewCheckBox");

        verticalLayout_2->addWidget(showPreviewCheckBox);


        horizontalLayout->addLayout(verticalLayout_2);

        previewArea = new QWidget(EditStyle);
        previewArea->setObjectName("previewArea");
        verticalLayout = new QVBoxLayout(previewArea);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        lblPreview = new QLabel(previewArea);
        lblPreview->setObjectName("lblPreview");

        verticalLayout->addWidget(lblPreview);

        textEditor = new QWidget(previewArea);
        textEditor->setObjectName("textEditor");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(2);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(textEditor->sizePolicy().hasHeightForWidth());
        textEditor->setSizePolicy(sizePolicy1);
        textEditor->setMinimumSize(QSize(300, 0));

        verticalLayout->addWidget(textEditor);


        horizontalLayout->addWidget(previewArea);

        horizontalLayout->setStretch(1, 1);

        retranslateUi(EditStyle);

        QMetaObject::connectSlotsByName(EditStyle);
    } // setupUi

    void retranslateUi(QWidget *EditStyle)
    {
#if QT_CONFIG(tooltip)
        showPreviewCheckBox->setToolTip(tr2i18n("Toggle preview visibility for this style.\n"
"Preview should be disabled for styles whose formatting depends on the file path.", nullptr));
#endif // QT_CONFIG(tooltip)
        showPreviewCheckBox->setText(tr2i18n("Show Preview", nullptr));
        lblPreview->setText(tr2i18n("Preview:", "@label"));
        (void)EditStyle;
    } // retranslateUi

};

namespace Ui {
    class EditStyle: public Ui_EditStyle {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITSTYLEDIALOG_H

