/********************************************************************************
** Form generated from reading UI file 'ninjaconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NINJACONFIG_H
#define UI_NINJACONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <util/environmentselectionwidget.h>
#include "KComboBox"
#include "shell/environmentconfigurebutton.h"

QT_BEGIN_NAMESPACE

class Ui_NinjaConfig
{
public:
    QFormLayout *formLayout;
    QLabel *label_7;
    QCheckBox *kcfg_displayOnly;
    QLabel *label_31;
    QCheckBox *kcfg_installAsRoot;
    QLabel *rootinstallationcommandLabel;
    KComboBox *kcfg_suCommand;
    QLabel *jobOverrideLabel;
    QSpinBox *kcfg_numberOfJobs;
    QLabel *label_1;
    QSpinBox *kcfg_numberOfErrors;
    QLabel *label_5;
    QLineEdit *kcfg_additionalOptions;
    QLabel *label_2;
    QWidget *widget;
    QHBoxLayout *horizontalLayout;
    KDevelop::EnvironmentSelectionWidget *kcfg_environmentProfile;
    KDevelop::EnvironmentConfigureButton *configureEnvironment;
    QLabel *label_3;
    QCheckBox *kcfg_overrideNumberOfJobs;

    void setupUi(QWidget *NinjaConfig)
    {
        if (NinjaConfig->objectName().isEmpty())
            NinjaConfig->setObjectName("NinjaConfig");
        NinjaConfig->resize(521, 362);
        formLayout = new QFormLayout(NinjaConfig);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout->setContentsMargins(0, 0, 0, 0);
        label_7 = new QLabel(NinjaConfig);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        kcfg_displayOnly = new QCheckBox(NinjaConfig);
        kcfg_displayOnly->setObjectName("kcfg_displayOnly");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_displayOnly);

        label_31 = new QLabel(NinjaConfig);
        label_31->setObjectName("label_31");
        label_31->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_31);

        kcfg_installAsRoot = new QCheckBox(NinjaConfig);
        kcfg_installAsRoot->setObjectName("kcfg_installAsRoot");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_installAsRoot);

        rootinstallationcommandLabel = new QLabel(NinjaConfig);
        rootinstallationcommandLabel->setObjectName("rootinstallationcommandLabel");
        rootinstallationcommandLabel->setEnabled(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, rootinstallationcommandLabel);

        kcfg_suCommand = new KComboBox(NinjaConfig);
        kcfg_suCommand->addItem(QString::fromUtf8("kdesu"));
        kcfg_suCommand->addItem(QString::fromUtf8("kdesudo"));
        kcfg_suCommand->addItem(QString::fromUtf8("sudo"));
        kcfg_suCommand->setObjectName("kcfg_suCommand");
        kcfg_suCommand->setEnabled(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_suCommand);

        jobOverrideLabel = new QLabel(NinjaConfig);
        jobOverrideLabel->setObjectName("jobOverrideLabel");
        jobOverrideLabel->setEnabled(false);
        jobOverrideLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, jobOverrideLabel);

        kcfg_numberOfJobs = new QSpinBox(NinjaConfig);
        kcfg_numberOfJobs->setObjectName("kcfg_numberOfJobs");
        kcfg_numberOfJobs->setEnabled(false);
        kcfg_numberOfJobs->setMinimum(1);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_numberOfJobs);

        label_1 = new QLabel(NinjaConfig);
        label_1->setObjectName("label_1");
        label_1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_1);

        kcfg_numberOfErrors = new QSpinBox(NinjaConfig);
        kcfg_numberOfErrors->setObjectName("kcfg_numberOfErrors");
        kcfg_numberOfErrors->setMinimum(1);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_numberOfErrors);

        label_5 = new QLabel(NinjaConfig);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_additionalOptions = new QLineEdit(NinjaConfig);
        kcfg_additionalOptions->setObjectName("kcfg_additionalOptions");
        kcfg_additionalOptions->setClearButtonEnabled(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_additionalOptions);

        label_2 = new QLabel(NinjaConfig);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_2);

        widget = new QWidget(NinjaConfig);
        widget->setObjectName("widget");
        horizontalLayout = new QHBoxLayout(widget);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_environmentProfile = new KDevelop::EnvironmentSelectionWidget(widget);
        kcfg_environmentProfile->setObjectName("kcfg_environmentProfile");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_environmentProfile->sizePolicy().hasHeightForWidth());
        kcfg_environmentProfile->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kcfg_environmentProfile);

        configureEnvironment = new KDevelop::EnvironmentConfigureButton(widget);
        configureEnvironment->setObjectName("configureEnvironment");

        horizontalLayout->addWidget(configureEnvironment);


        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, widget);

        label_3 = new QLabel(NinjaConfig);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_overrideNumberOfJobs = new QCheckBox(NinjaConfig);
        kcfg_overrideNumberOfJobs->setObjectName("kcfg_overrideNumberOfJobs");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_overrideNumberOfJobs);

#if QT_CONFIG(shortcut)
        label_7->setBuddy(kcfg_displayOnly);
        label_31->setBuddy(kcfg_installAsRoot);
        rootinstallationcommandLabel->setBuddy(kcfg_suCommand);
        jobOverrideLabel->setBuddy(kcfg_numberOfJobs);
        label_1->setBuddy(kcfg_numberOfErrors);
        label_5->setBuddy(kcfg_additionalOptions);
        label_2->setBuddy(kcfg_environmentProfile);
        label_3->setBuddy(kcfg_overrideNumberOfJobs);
#endif // QT_CONFIG(shortcut)

        retranslateUi(NinjaConfig);
        QObject::connect(kcfg_installAsRoot, SIGNAL(toggled(bool)), kcfg_suCommand, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_installAsRoot, &QCheckBox::toggled, rootinstallationcommandLabel, &QLabel::setEnabled);
        QObject::connect(kcfg_overrideNumberOfJobs, &QCheckBox::toggled, kcfg_numberOfJobs, &QSpinBox::setEnabled);
        QObject::connect(kcfg_overrideNumberOfJobs, &QCheckBox::toggled, jobOverrideLabel, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(NinjaConfig);
    } // setupUi

    void retranslateUi(QWidget *NinjaConfig)
    {
        label_7->setText(tr2i18n("&Display commands but do not execute them:", "@option:check"));
        kcfg_displayOnly->setText(QString());
        label_31->setText(tr2i18n("Install as &root:", "@option:check"));
        kcfg_installAsRoot->setText(QString());
        rootinstallationcommandLabel->setText(tr2i18n("Root installation &command:", "@label:textbox"));

        jobOverrideLabel->setText(tr2i18n("&Number of simultaneous jobs:", "@label:spinbox"));
        label_1->setText(tr2i18n("Count of &errors to be tolerated:", "@label:spinbox"));
        label_5->setText(tr2i18n("Additional ninja &options:", "@label:textbox"));
        label_2->setText(tr2i18n("Active environment &profile:", "@label:chooser"));
        label_3->setText(tr2i18n("O&verride number of jobs:", "@option:check"));
        (void)NinjaConfig;
    } // retranslateUi

};

namespace Ui {
    class NinjaConfig: public Ui_NinjaConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NINJACONFIG_H

