/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/sublime/mainwindow.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Sublime10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Sublime::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN7Sublime10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Sublime::MainWindow",
        "areaCleared",
        "",
        "Sublime::Area*",
        "areaChanged",
        "activeViewChanged",
        "Sublime::View*",
        "activeToolViewChanged",
        "toolViewVisibilityRestored",
        "QList<Sublime::View*>",
        "visibleToolViews",
        "viewAdded",
        "aboutToRemoveView",
        "activateView",
        "view",
        "focus",
        "postMessage",
        "Sublime::Message*",
        "message",
        "tabDoubleClicked",
        "tabContextMenuRequested",
        "QMenu*",
        "tabToolTipRequested",
        "Sublime::Container*",
        "container",
        "tab",
        "newTabRequested",
        "dockBarContextMenuRequested",
        "Qt::DockWidgetArea",
        "QPoint",
        "saveNewToolbarConfig"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'areaCleared'
        QtMocHelpers::SignalData<void(Sublime::Area *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'areaChanged'
        QtMocHelpers::SignalData<void(Sublime::Area *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'activeViewChanged'
        QtMocHelpers::SignalData<void(Sublime::View *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'activeToolViewChanged'
        QtMocHelpers::SignalData<void(Sublime::View *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'toolViewVisibilityRestored'
        QtMocHelpers::SignalData<void(const QList<Sublime::View*> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'viewAdded'
        QtMocHelpers::SignalData<void(Sublime::View *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'aboutToRemoveView'
        QtMocHelpers::SignalData<void(Sublime::View *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'activateView'
        QtMocHelpers::SlotData<void(Sublime::View *, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'activateView'
        QtMocHelpers::SlotData<void(Sublime::View *)>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 14 },
        }}),
        // Slot 'postMessage'
        QtMocHelpers::SlotData<void(Sublime::Message *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'tabDoubleClicked'
        QtMocHelpers::SlotData<void(Sublime::View *)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 14 },
        }}),
        // Slot 'tabContextMenuRequested'
        QtMocHelpers::SlotData<void(Sublime::View *, QMenu *)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 21, 2 },
        }}),
        // Slot 'tabToolTipRequested'
        QtMocHelpers::SlotData<void(Sublime::View *, Sublime::Container *, int)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 14 }, { 0x80000000 | 23, 24 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'newTabRequested'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'dockBarContextMenuRequested'
        QtMocHelpers::SlotData<void(Qt::DockWidgetArea, const QPoint &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 28, 2 }, { 0x80000000 | 29, 2 },
        }}),
        // Slot 'saveNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN7Sublime10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Sublime::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::MainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Sublime10MainWindowE_t>.metaTypes,
    nullptr
} };

void Sublime::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->areaCleared((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        case 1: _t->areaChanged((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        case 2: _t->activeViewChanged((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 3: _t->activeToolViewChanged((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 4: _t->toolViewVisibilityRestored((*reinterpret_cast<std::add_pointer_t<QList<Sublime::View*>>>(_a[1]))); break;
        case 5: _t->viewAdded((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 6: _t->aboutToRemoveView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 7: _t->activateView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->activateView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 9: _t->postMessage((*reinterpret_cast<std::add_pointer_t<Sublime::Message*>>(_a[1]))); break;
        case 10: _t->tabDoubleClicked((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 11: _t->tabContextMenuRequested((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 12: _t->tabToolTipRequested((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Container*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 13: _t->newTabRequested(); break;
        case 14: _t->dockBarContextMenuRequested((*reinterpret_cast<std::add_pointer_t<Qt::DockWidgetArea>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 15: _t->saveNewToolbarConfig(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenu* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Sublime::Area * )>(_a, &MainWindow::areaCleared, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Sublime::Area * )>(_a, &MainWindow::areaChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Sublime::View * )>(_a, &MainWindow::activeViewChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Sublime::View * )>(_a, &MainWindow::activeToolViewChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QList<Sublime::View*> & )>(_a, &MainWindow::toolViewVisibilityRestored, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Sublime::View * )>(_a, &MainWindow::viewAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(Sublime::View * )>(_a, &MainWindow::aboutToRemoveView, 6))
            return;
    }
}

const QMetaObject *Sublime::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sublime::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KParts::MainWindow::qt_metacast(_clname);
}

int Sublime::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Sublime::MainWindow::areaCleared(Sublime::Area * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Sublime::MainWindow::areaChanged(Sublime::Area * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Sublime::MainWindow::activeViewChanged(Sublime::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Sublime::MainWindow::activeToolViewChanged(Sublime::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Sublime::MainWindow::toolViewVisibilityRestored(const QList<Sublime::View*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Sublime::MainWindow::viewAdded(Sublime::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Sublime::MainWindow::aboutToRemoveView(Sublime::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
