/****************************************************************************
** Meta object code from reading C++ file 'filemanagerlistjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/project/filemanagerlistjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filemanagerlistjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop18FileManagerListJobE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::FileManagerListJob::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop18FileManagerListJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::FileManagerListJob",
        "entries",
        "",
        "FileManagerListJob*",
        "job",
        "ProjectFolderItem*",
        "baseItem",
        "KIO::UDSEntryList",
        "nextJob",
        "remoteFolderSubjobEntriesFound",
        "KJob*",
        "foundEntries",
        "remoteFolderSubjobFinished",
        "handleResults",
        "startNextJob"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'entries'
        QtMocHelpers::SignalData<void(FileManagerListJob *, ProjectFolderItem *, const KIO::UDSEntryList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 1 },
        }}),
        // Signal 'nextJob'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'remoteFolderSubjobEntriesFound'
        QtMocHelpers::SlotData<void(KJob *, const KIO::UDSEntryList &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 4 }, { 0x80000000 | 7, 11 },
        }}),
        // Slot 'remoteFolderSubjobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Slot 'handleResults'
        QtMocHelpers::SlotData<void(const KIO::UDSEntryList &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 1 },
        }}),
        // Slot 'startNextJob'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileManagerListJob, qt_meta_tag_ZN8KDevelop18FileManagerListJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::FileManagerListJob::staticMetaObject = { {
    QMetaObject::SuperData::link<KJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18FileManagerListJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18FileManagerListJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop18FileManagerListJobE_t>.metaTypes,
    nullptr
} };

void KDevelop::FileManagerListJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileManagerListJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->entries((*reinterpret_cast<std::add_pointer_t<FileManagerListJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ProjectFolderItem*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KIO::UDSEntryList>>(_a[3]))); break;
        case 1: _t->nextJob(); break;
        case 2: _t->remoteFolderSubjobEntriesFound((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::UDSEntryList>>(_a[2]))); break;
        case 3: _t->remoteFolderSubjobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 4: _t->handleResults((*reinterpret_cast<std::add_pointer_t<KIO::UDSEntryList>>(_a[1]))); break;
        case 5: _t->startNextJob(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FileManagerListJob* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileManagerListJob::*)(FileManagerListJob * , ProjectFolderItem * , const KIO::UDSEntryList & )>(_a, &FileManagerListJob::entries, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerListJob::*)()>(_a, &FileManagerListJob::nextJob, 1))
            return;
    }
}

const QMetaObject *KDevelop::FileManagerListJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::FileManagerListJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18FileManagerListJobE_t>.strings))
        return static_cast<void*>(this);
    return KJob::qt_metacast(_clname);
}

int KDevelop::FileManagerListJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::FileManagerListJob::entries(FileManagerListJob * _t1, ProjectFolderItem * _t2, const KIO::UDSEntryList & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void KDevelop::FileManagerListJob::nextJob()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
