/********************************************************************************
** Form generated from reading UI file 'commandlinewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMMANDLINEWIDGET_H
#define UI_COMMANDLINEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

namespace Clazy {

class Ui_CommandLineWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *filterLayout;
    QLineEdit *cmdFilter;
    QCheckBox *cmdBreak;
    QPlainTextEdit *cmdEdit;

    void setupUi(QWidget *Clazy__CommandLineWidget)
    {
        if (Clazy__CommandLineWidget->objectName().isEmpty())
            Clazy__CommandLineWidget->setObjectName("Clazy__CommandLineWidget");
        Clazy__CommandLineWidget->resize(400, 300);
        verticalLayout = new QVBoxLayout(Clazy__CommandLineWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(Clazy__CommandLineWidget);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        filterLayout = new QHBoxLayout();
        filterLayout->setObjectName("filterLayout");
        cmdFilter = new QLineEdit(groupBox);
        cmdFilter->setObjectName("cmdFilter");
        cmdFilter->setClearButtonEnabled(true);

        filterLayout->addWidget(cmdFilter);

        cmdBreak = new QCheckBox(groupBox);
        cmdBreak->setObjectName("cmdBreak");

        filterLayout->addWidget(cmdBreak);


        verticalLayout_2->addLayout(filterLayout);

        cmdEdit = new QPlainTextEdit(groupBox);
        cmdEdit->setObjectName("cmdEdit");
        cmdEdit->setReadOnly(true);

        verticalLayout_2->addWidget(cmdEdit);


        verticalLayout->addWidget(groupBox);


        retranslateUi(Clazy__CommandLineWidget);

        QMetaObject::connectSlotsByName(Clazy__CommandLineWidget);
    } // setupUi

    void retranslateUi(QWidget *Clazy__CommandLineWidget)
    {
        groupBox->setTitle(tr2i18n("Command Line", "@title:group"));
        cmdFilter->setPlaceholderText(tr2i18n("Search...", "@info:placeholder"));
        cmdBreak->setText(tr2i18n("Break lines", "@option:check"));
        (void)Clazy__CommandLineWidget;
    } // retranslateUi

};

} // namespace Clazy

namespace Clazy {
namespace Ui {
    class CommandLineWidget: public Ui_CommandLineWidget {};
} // namespace Ui
} // namespace Clazy

#endif // COMMANDLINEWIDGET_H

