/********************************************************************************
** Form generated from reading UI file 'projectbuildsetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTBUILDSETWIDGET_H
#define UI_PROJECTBUILDSETWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProjectBuildSetWidget
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QToolButton *topButton;
    QSpacerItem *verticalSpacer_3;
    QToolButton *upButton;
    QToolButton *downButton;
    QSpacerItem *verticalSpacer_4;
    QToolButton *bottomButton;
    QSpacerItem *verticalSpacer_2;
    QTreeView *itemView;
    QHBoxLayout *hboxLayout;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QToolButton *addItemButton;
    QToolButton *removeItemButton;

    void setupUi(QWidget *ProjectBuildSetWidget)
    {
        if (ProjectBuildSetWidget->objectName().isEmpty())
            ProjectBuildSetWidget->setObjectName("ProjectBuildSetWidget");
        ProjectBuildSetWidget->resize(298, 244);
        gridLayout = new QGridLayout(ProjectBuildSetWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(0);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        topButton = new QToolButton(ProjectBuildSetWidget);
        topButton->setObjectName("topButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("go-top")));
        topButton->setIcon(icon);
        topButton->setAutoRaise(true);

        verticalLayout->addWidget(topButton);

        verticalSpacer_3 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_3);

        upButton = new QToolButton(ProjectBuildSetWidget);
        upButton->setObjectName("upButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("go-up")));
        upButton->setIcon(icon1);
        upButton->setAutoRaise(true);

        verticalLayout->addWidget(upButton);

        downButton = new QToolButton(ProjectBuildSetWidget);
        downButton->setObjectName("downButton");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("go-down")));
        downButton->setIcon(icon2);
        downButton->setAutoRaise(true);

        verticalLayout->addWidget(downButton);

        verticalSpacer_4 = new QSpacerItem(20, 5, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_4);

        bottomButton = new QToolButton(ProjectBuildSetWidget);
        bottomButton->setObjectName("bottomButton");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("go-bottom")));
        bottomButton->setIcon(icon3);
        bottomButton->setAutoRaise(true);

        verticalLayout->addWidget(bottomButton);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);


        gridLayout->addLayout(verticalLayout, 1, 1, 1, 1);

        itemView = new QTreeView(ProjectBuildSetWidget);
        itemView->setObjectName("itemView");
        itemView->setAlternatingRowColors(true);
        itemView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        itemView->setRootIsDecorated(false);
        itemView->setUniformRowHeights(true);

        gridLayout->addWidget(itemView, 1, 0, 1, 1);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer_2);

        label = new QLabel(ProjectBuildSetWidget);
        label->setObjectName("label");

        hboxLayout->addWidget(label);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer);

        addItemButton = new QToolButton(ProjectBuildSetWidget);
        addItemButton->setObjectName("addItemButton");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addItemButton->setIcon(icon4);
        addItemButton->setAutoRaise(true);

        hboxLayout->addWidget(addItemButton);

        removeItemButton = new QToolButton(ProjectBuildSetWidget);
        removeItemButton->setObjectName("removeItemButton");
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        removeItemButton->setIcon(icon5);
        removeItemButton->setAutoRaise(true);

        hboxLayout->addWidget(removeItemButton);


        gridLayout->addLayout(hboxLayout, 0, 0, 1, 2);


        retranslateUi(ProjectBuildSetWidget);

        QMetaObject::connectSlotsByName(ProjectBuildSetWidget);
    } // setupUi

    void retranslateUi(QWidget *ProjectBuildSetWidget)
    {
#if QT_CONFIG(tooltip)
        topButton->setToolTip(tr2i18n("Move the selected items to the top", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        topButton->setText(QString());
#if QT_CONFIG(tooltip)
        upButton->setToolTip(tr2i18n("Move the selected items up", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        upButton->setText(QString());
#if QT_CONFIG(tooltip)
        downButton->setToolTip(tr2i18n("Move the selected item down", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        downButton->setText(QString());
#if QT_CONFIG(tooltip)
        bottomButton->setToolTip(tr2i18n("Move the selected items to the bottom", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        bottomButton->setText(QString());
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("These items will be built in the order they are listed.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Build Sequence", "@title"));
#if QT_CONFIG(tooltip)
        addItemButton->setToolTip(tr2i18n("Add currently selected items from project tree view to the build set.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        addItemButton->setText(QString());
#if QT_CONFIG(tooltip)
        removeItemButton->setToolTip(tr2i18n("Remove currently selected item from the build set.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        removeItemButton->setText(QString());
        (void)ProjectBuildSetWidget;
    } // retranslateUi

};

namespace Ui {
    class ProjectBuildSetWidget: public Ui_ProjectBuildSetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTBUILDSETWIDGET_H

