// THIS FILE IS GENERATED BY kdev-pg-qt 2.4.0
// WARNING! All changes made in this file will be lost!

#ifndef QMAKE_AST_FWD_INCLUDED
#define QMAKE_AST_FWD_INCLUDED

namespace QMake
{

struct  AstNode;
struct ArgumentListAst;
struct ElseBodyAst;
struct FunctionArgumentsAst;
struct IfElseAst;
struct ItemAst;
struct OpAst;
struct OrOperatorAst;
struct ProjectAst;
struct ScopeAst;
struct ScopeBodyAst;
struct StatementAst;
struct ValueAst;
struct ValueListAst;
struct VariableAssignmentAst;

} // end of namespace QMake

#endif

