/********************************************************************************
** Form generated from reading UI file 'registersview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REGISTERSVIEW_H
#define UI_REGISTERSVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RegistersView
{
public:
    QHBoxLayout *horizontalLayout_3;
    QTabWidget *tabWidget;
    QWidget *tab;
    QHBoxLayout *horizontalLayout_2;
    QTableView *registers;
    QTableView *flags;
    QWidget *tab_1;
    QHBoxLayout *horizontalLayout_5;
    QTableView *table_1;
    QWidget *tab_2;
    QHBoxLayout *horizontalLayout;
    QTableView *table_2;
    QWidget *tab_3;
    QHBoxLayout *horizontalLayout_8;
    QTableView *table_3;

    void setupUi(QWidget *RegistersView)
    {
        if (RegistersView->objectName().isEmpty())
            RegistersView->setObjectName("RegistersView");
        RegistersView->resize(834, 437);
        horizontalLayout_3 = new QHBoxLayout(RegistersView);
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        tabWidget = new QTabWidget(RegistersView);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        horizontalLayout_2 = new QHBoxLayout(tab);
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        registers = new QTableView(tab);
        registers->setObjectName("registers");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(registers->sizePolicy().hasHeightForWidth());
        registers->setSizePolicy(sizePolicy);
        registers->setMaximumSize(QSize(16777215, 16777215));
        registers->setBaseSize(QSize(10, 0));
        registers->setFrameShape(QFrame::NoFrame);
        registers->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        registers->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);

        horizontalLayout_2->addWidget(registers);

        flags = new QTableView(tab);
        flags->setObjectName("flags");
        sizePolicy.setHeightForWidth(flags->sizePolicy().hasHeightForWidth());
        flags->setSizePolicy(sizePolicy);
        flags->setMaximumSize(QSize(16777215, 16777215));
        flags->setBaseSize(QSize(10, 0));
        flags->setFrameShape(QFrame::NoFrame);
        flags->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        flags->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);

        horizontalLayout_2->addWidget(flags);

        tabWidget->addTab(tab, QString());
        tab_1 = new QWidget();
        tab_1->setObjectName("tab_1");
        horizontalLayout_5 = new QHBoxLayout(tab_1);
        horizontalLayout_5->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        table_1 = new QTableView(tab_1);
        table_1->setObjectName("table_1");
        sizePolicy.setHeightForWidth(table_1->sizePolicy().hasHeightForWidth());
        table_1->setSizePolicy(sizePolicy);
        table_1->setBaseSize(QSize(10, 0));
        table_1->setFrameShape(QFrame::NoFrame);
        table_1->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        table_1->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);

        horizontalLayout_5->addWidget(table_1);

        tabWidget->addTab(tab_1, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        horizontalLayout = new QHBoxLayout(tab_2);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        table_2 = new QTableView(tab_2);
        table_2->setObjectName("table_2");
        sizePolicy.setHeightForWidth(table_2->sizePolicy().hasHeightForWidth());
        table_2->setSizePolicy(sizePolicy);
        table_2->setBaseSize(QSize(10, 0));
        table_2->setFrameShape(QFrame::NoFrame);
        table_2->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        table_2->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);

        horizontalLayout->addWidget(table_2);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        horizontalLayout_8 = new QHBoxLayout(tab_3);
        horizontalLayout_8->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        table_3 = new QTableView(tab_3);
        table_3->setObjectName("table_3");
        sizePolicy.setHeightForWidth(table_3->sizePolicy().hasHeightForWidth());
        table_3->setSizePolicy(sizePolicy);
        table_3->setBaseSize(QSize(10, 0));
        table_3->setFrameShape(QFrame::NoFrame);
        table_3->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
        table_3->setHorizontalScrollMode(QAbstractItemView::ScrollPerPixel);

        horizontalLayout_8->addWidget(table_3);

        tabWidget->addTab(tab_3, QString());

        horizontalLayout_3->addWidget(tabWidget);


        retranslateUi(RegistersView);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(RegistersView);
    } // setupUi

    void retranslateUi(QWidget *RegistersView)
    {
        tabWidget->setTabText(tabWidget->indexOf(tab), QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_1), QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_2), QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_3), QString());
        (void)RegistersView;
    } // retranslateUi

};

namespace Ui {
    class RegistersView: public Ui_RegistersView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REGISTERSVIEW_H

