/********************************************************************************
** Form generated from reading UI file 'mesonrewriterinput.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONREWRITERINPUT_H
#define UI_MESONREWRITERINPUT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MesonRewriterInputBase
{
public:
    QHBoxLayout *layout;
    QLabel *l_name;
    QToolButton *b_reset;
    QToolButton *b_delete;
    QToolButton *b_add;

    void setupUi(QWidget *MesonRewriterInputBase)
    {
        if (MesonRewriterInputBase->objectName().isEmpty())
            MesonRewriterInputBase->setObjectName("MesonRewriterInputBase");
        MesonRewriterInputBase->resize(500, 32);
        layout = new QHBoxLayout(MesonRewriterInputBase);
        layout->setObjectName("layout");
        layout->setContentsMargins(0, 0, 0, 0);
        l_name = new QLabel(MesonRewriterInputBase);
        l_name->setObjectName("l_name");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(l_name->sizePolicy().hasHeightForWidth());
        l_name->setSizePolicy(sizePolicy);
        l_name->setMinimumSize(QSize(50, 0));

        layout->addWidget(l_name);

        b_reset = new QToolButton(MesonRewriterInputBase);
        b_reset->setObjectName("b_reset");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-revert")));
        b_reset->setIcon(icon);

        layout->addWidget(b_reset);

        b_delete = new QToolButton(MesonRewriterInputBase);
        b_delete->setObjectName("b_delete");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        b_delete->setIcon(icon1);

        layout->addWidget(b_delete);

        b_add = new QToolButton(MesonRewriterInputBase);
        b_add->setObjectName("b_add");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-add")));
        b_add->setIcon(icon2);

        layout->addWidget(b_add);


        retranslateUi(MesonRewriterInputBase);
        QObject::connect(b_reset, SIGNAL(clicked()), MesonRewriterInputBase, SLOT(reset()));
        QObject::connect(b_add, SIGNAL(clicked()), MesonRewriterInputBase, SLOT(add()));
        QObject::connect(b_delete, SIGNAL(clicked()), MesonRewriterInputBase, SLOT(remove()));

        QMetaObject::connectSlotsByName(MesonRewriterInputBase);
    } // setupUi

    void retranslateUi(QWidget *MesonRewriterInputBase)
    {
        l_name->setText(tr2i18n("Name:", nullptr));
        (void)MesonRewriterInputBase;
    } // retranslateUi

};

namespace Ui {
    class MesonRewriterInputBase: public Ui_MesonRewriterInputBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONREWRITERINPUT_H

