/********************************************************************************
** Form generated from reading UI file 'checksetmanagewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHECKSETMANAGEWIDGET_H
#define UI_CHECKSETMANAGEWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "config/checkswidget.h"

namespace Clazy {

class Ui_CheckSetManageWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KComboBox *checkSetSelect;
    QPushButton *addCheckSetSelectionButton;
    QPushButton *cloneCheckSetSelectionButton;
    QPushButton *removeCheckSetSelectionButton;
    QPushButton *setAsDefaultCheckSetSelectionButton;
    QPushButton *editCheckSetSelectionNameButton;
    Clazy::ChecksWidget *enabledChecks;

    void setupUi(QWidget *Clazy__CheckSetManageWidget)
    {
        if (Clazy__CheckSetManageWidget->objectName().isEmpty())
            Clazy__CheckSetManageWidget->setObjectName("Clazy__CheckSetManageWidget");
        Clazy__CheckSetManageWidget->resize(704, 480);
        gridLayout = new QGridLayout(Clazy__CheckSetManageWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(Clazy__CheckSetManageWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        checkSetSelect = new KComboBox(Clazy__CheckSetManageWidget);
        checkSetSelect->setObjectName("checkSetSelect");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(checkSetSelect->sizePolicy().hasHeightForWidth());
        checkSetSelect->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(checkSetSelect);

        addCheckSetSelectionButton = new QPushButton(Clazy__CheckSetManageWidget);
        addCheckSetSelectionButton->setObjectName("addCheckSetSelectionButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addCheckSetSelectionButton->setIcon(icon);

        horizontalLayout->addWidget(addCheckSetSelectionButton);

        cloneCheckSetSelectionButton = new QPushButton(Clazy__CheckSetManageWidget);
        cloneCheckSetSelectionButton->setObjectName("cloneCheckSetSelectionButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-clone")));
        cloneCheckSetSelectionButton->setIcon(icon1);

        horizontalLayout->addWidget(cloneCheckSetSelectionButton);

        removeCheckSetSelectionButton = new QPushButton(Clazy__CheckSetManageWidget);
        removeCheckSetSelectionButton->setObjectName("removeCheckSetSelectionButton");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        removeCheckSetSelectionButton->setIcon(icon2);

        horizontalLayout->addWidget(removeCheckSetSelectionButton);

        setAsDefaultCheckSetSelectionButton = new QPushButton(Clazy__CheckSetManageWidget);
        setAsDefaultCheckSetSelectionButton->setObjectName("setAsDefaultCheckSetSelectionButton");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("starred-symbolic")));
        setAsDefaultCheckSetSelectionButton->setIcon(icon3);

        horizontalLayout->addWidget(setAsDefaultCheckSetSelectionButton);

        editCheckSetSelectionNameButton = new QPushButton(Clazy__CheckSetManageWidget);
        editCheckSetSelectionNameButton->setObjectName("editCheckSetSelectionNameButton");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("edit-rename")));
        editCheckSetSelectionNameButton->setIcon(icon4);

        horizontalLayout->addWidget(editCheckSetSelectionNameButton);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        enabledChecks = new Clazy::ChecksWidget(Clazy__CheckSetManageWidget);
        enabledChecks->setObjectName("enabledChecks");
        enabledChecks->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(1);
        sizePolicy1.setHeightForWidth(enabledChecks->sizePolicy().hasHeightForWidth());
        enabledChecks->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(enabledChecks, 1, 0, 1, 1);


        retranslateUi(Clazy__CheckSetManageWidget);

        QMetaObject::connectSlotsByName(Clazy__CheckSetManageWidget);
    } // setupUi

    void retranslateUi(QWidget *Clazy__CheckSetManageWidget)
    {
        label->setText(tr2i18n("Check set:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        addCheckSetSelectionButton->setToolTip(tr2i18n("Add check set", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cloneCheckSetSelectionButton->setToolTip(tr2i18n("Clone check set", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        removeCheckSetSelectionButton->setToolTip(tr2i18n("Remove check set", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        setAsDefaultCheckSetSelectionButton->setToolTip(tr2i18n("Set as default", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        editCheckSetSelectionNameButton->setToolTip(tr2i18n("Edit name of check set", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        (void)Clazy__CheckSetManageWidget;
    } // retranslateUi

};

} // namespace Clazy

namespace Clazy {
namespace Ui {
    class CheckSetManageWidget: public Ui_CheckSetManageWidget {};
} // namespace Ui
} // namespace Clazy

#endif // CHECKSETMANAGEWIDGET_H

