/********************************************************************************
** Form generated from reading UI file 'qmakebuilddirchooser.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QMAKEBUILDDIRCHOOSER_H
#define UI_QMAKEBUILDDIRCHOOSER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KLineEdit"
#include "KMessageWidget"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_QMakeBuildDirChooser
{
public:
    QFormLayout *formLayout;
    QLabel *label_5;
    KUrlRequester *kcfg_qmakeExecutable;
    QLabel *label_3;
    KUrlRequester *kcfg_buildDir;
    QLabel *label;
    KUrlRequester *kcfg_installPrefix;
    QLabel *label_2;
    QComboBox *kcfg_buildType;
    QLabel *label_4;
    KLineEdit *kcfg_extraArgs;
    KMessageWidget *status;

    void setupUi(QWidget *QMakeBuildDirChooser)
    {
        if (QMakeBuildDirChooser->objectName().isEmpty())
            QMakeBuildDirChooser->setObjectName("QMakeBuildDirChooser");
        QMakeBuildDirChooser->resize(611, 200);
        formLayout = new QFormLayout(QMakeBuildDirChooser);
        formLayout->setContentsMargins(0, 0, 0, 0);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_5 = new QLabel(QMakeBuildDirChooser);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_qmakeExecutable = new KUrlRequester(QMakeBuildDirChooser);
        kcfg_qmakeExecutable->setObjectName("kcfg_qmakeExecutable");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_qmakeExecutable->sizePolicy().hasHeightForWidth());
        kcfg_qmakeExecutable->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_qmakeExecutable);

        label_3 = new QLabel(QMakeBuildDirChooser);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_buildDir = new KUrlRequester(QMakeBuildDirChooser);
        kcfg_buildDir->setObjectName("kcfg_buildDir");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_buildDir);

        label = new QLabel(QMakeBuildDirChooser);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        kcfg_installPrefix = new KUrlRequester(QMakeBuildDirChooser);
        kcfg_installPrefix->setObjectName("kcfg_installPrefix");
        sizePolicy.setHeightForWidth(kcfg_installPrefix->sizePolicy().hasHeightForWidth());
        kcfg_installPrefix->setSizePolicy(sizePolicy);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_installPrefix);

        label_2 = new QLabel(QMakeBuildDirChooser);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_buildType = new QComboBox(QMakeBuildDirChooser);
        kcfg_buildType->addItem(QString::fromUtf8("Debug"));
        kcfg_buildType->addItem(QString::fromUtf8("Release"));
        kcfg_buildType->addItem(QString());
        kcfg_buildType->setObjectName("kcfg_buildType");
        kcfg_buildType->setEditable(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_buildType);

        label_4 = new QLabel(QMakeBuildDirChooser);
        label_4->setObjectName("label_4");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        kcfg_extraArgs = new KLineEdit(QMakeBuildDirChooser);
        kcfg_extraArgs->setObjectName("kcfg_extraArgs");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_extraArgs);

        status = new KMessageWidget(QMakeBuildDirChooser);
        status->setObjectName("status");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, status);

#if QT_CONFIG(shortcut)
        label_5->setBuddy(kcfg_qmakeExecutable);
        label_3->setBuddy(kcfg_buildDir);
        label->setBuddy(kcfg_installPrefix);
        label_2->setBuddy(kcfg_buildType);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_qmakeExecutable, kcfg_buildDir);
        QWidget::setTabOrder(kcfg_buildDir, kcfg_installPrefix);
        QWidget::setTabOrder(kcfg_installPrefix, kcfg_buildType);
        QWidget::setTabOrder(kcfg_buildType, kcfg_extraArgs);

        retranslateUi(QMakeBuildDirChooser);

        kcfg_buildType->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(QMakeBuildDirChooser);
    } // setupUi

    void retranslateUi(QWidget *QMakeBuildDirChooser)
    {
        label_5->setText(tr2i18n("QMake &executable:", "@label:textbox"));
        label_3->setText(tr2i18n("&Build directory:", "@label:textbox"));
        label->setText(tr2i18n("&Install to (target.path):", "@label:textbox"));
        label_2->setText(tr2i18n("Build &type:", "@labal:listbox"));
        kcfg_buildType->setItemText(2, tr2i18n("(Use default from .pro file)", "@item:inlistbox"));

        label_4->setText(tr2i18n("Extra arguments:", "@label:textbox"));
        (void)QMakeBuildDirChooser;
    } // retranslateUi

};

namespace Ui {
    class QMakeBuildDirChooser: public Ui_QMakeBuildDirChooser {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QMAKEBUILDDIRCHOOSER_H

