/****************************************************************************
** Meta object code from reading C++ file 'iprojectcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/interfaces/iprojectcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'iprojectcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop18IProjectControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::IProjectController::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop18IProjectControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::IProjectController",
        "projectAboutToBeOpened",
        "",
        "KDevelop::IProject*",
        "project",
        "projectOpened",
        "projectClosing",
        "projectClosed",
        "projectOpeningAborted",
        "projectConfigurationChanged",
        "openProjectForUrl",
        "QUrl",
        "sourceUrl",
        "openProject",
        "url",
        "closeProject",
        "IProject*",
        "closeAllProjects",
        "configureProject",
        "reparseProject",
        "forceUpdate",
        "forceAll",
        "projectAt",
        "projectCount",
        "projects",
        "QList<IProject*>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'projectAboutToBeOpened'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'projectOpened'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'projectClosing'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'projectClosed'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'projectOpeningAborted'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'projectConfigurationChanged'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'openProjectForUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void(const QUrl &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 14 },
        }}),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'closeProject'
        QtMocHelpers::SlotData<void(IProject *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'closeAllProjects'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configureProject'
        QtMocHelpers::SlotData<void(IProject *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'reparseProject'
        QtMocHelpers::SlotData<void(IProject *, bool, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 4 }, { QMetaType::Bool, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'reparseProject'
        QtMocHelpers::SlotData<void(IProject *, bool)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 4 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'reparseProject'
        QtMocHelpers::SlotData<void(IProject *)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 16, 4 },
        }}),
        // Method 'projectAt'
        QtMocHelpers::MethodData<KDevelop::IProject *(int) const>(22, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::Int, 2 },
        }}),
        // Method 'projectCount'
        QtMocHelpers::MethodData<int() const>(23, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'projects'
        QtMocHelpers::MethodData<QList<IProject*>() const>(24, 2, QMC::AccessPublic, 0x80000000 | 25),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IProjectController, qt_meta_tag_ZN8KDevelop18IProjectControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::IProjectController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18IProjectControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18IProjectControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop18IProjectControllerE_t>.metaTypes,
    nullptr
} };

void KDevelop::IProjectController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IProjectController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->projectAboutToBeOpened((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 1: _t->projectOpened((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 2: _t->projectClosing((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 3: _t->projectClosed((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 4: _t->projectOpeningAborted((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 5: _t->projectConfigurationChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 6: _t->openProjectForUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->openProject((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->openProject(); break;
        case 9: _t->closeProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1]))); break;
        case 10: _t->closeAllProjects(); break;
        case 11: _t->configureProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1]))); break;
        case 12: _t->reparseProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 13: _t->reparseProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->reparseProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1]))); break;
        case 15: { KDevelop::IProject* _r = _t->projectAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KDevelop::IProject**>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->projectCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: { QList<IProject*> _r = _t->projects();
            if (_a[0]) *reinterpret_cast<QList<IProject*>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IProjectController::*)(KDevelop::IProject * )>(_a, &IProjectController::projectAboutToBeOpened, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IProjectController::*)(KDevelop::IProject * )>(_a, &IProjectController::projectOpened, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IProjectController::*)(KDevelop::IProject * )>(_a, &IProjectController::projectClosing, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IProjectController::*)(KDevelop::IProject * )>(_a, &IProjectController::projectClosed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IProjectController::*)(KDevelop::IProject * )>(_a, &IProjectController::projectOpeningAborted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IProjectController::*)(KDevelop::IProject * )>(_a, &IProjectController::projectConfigurationChanged, 5))
            return;
    }
}

const QMetaObject *KDevelop::IProjectController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::IProjectController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18IProjectControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::IProjectController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::IProjectController::projectAboutToBeOpened(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevelop::IProjectController::projectOpened(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDevelop::IProjectController::projectClosing(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDevelop::IProjectController::projectClosed(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KDevelop::IProjectController::projectOpeningAborted(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KDevelop::IProjectController::projectConfigurationChanged(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
