/********************************************************************************
** Form generated from reading UI file 'refactoringdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REFACTORINGDIALOG_H
#define UI_REFACTORINGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RefactoringDialog
{
public:
    QGridLayout *gridLayout;
    QProgressBar *progressBar;
    QPushButton *abortButton;
    QLabel *fileLabel;
    QLabel *renameLabel;

    void setupUi(QDialog *RefactoringDialog)
    {
        if (RefactoringDialog->objectName().isEmpty())
            RefactoringDialog->setObjectName("RefactoringDialog");
        RefactoringDialog->resize(536, 99);
        gridLayout = new QGridLayout(RefactoringDialog);
        gridLayout->setObjectName("gridLayout");
        progressBar = new QProgressBar(RefactoringDialog);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(5);

        gridLayout->addWidget(progressBar, 2, 0, 1, 1);

        abortButton = new QPushButton(RefactoringDialog);
        abortButton->setObjectName("abortButton");

        gridLayout->addWidget(abortButton, 2, 1, 1, 1);

        fileLabel = new QLabel(RefactoringDialog);
        fileLabel->setObjectName("fileLabel");

        gridLayout->addWidget(fileLabel, 1, 0, 1, 2);

        renameLabel = new QLabel(RefactoringDialog);
        renameLabel->setObjectName("renameLabel");

        gridLayout->addWidget(renameLabel, 0, 0, 1, 2);


        retranslateUi(RefactoringDialog);
        QObject::connect(abortButton, &QPushButton::clicked, RefactoringDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(RefactoringDialog);
    } // setupUi

    void retranslateUi(QDialog *RefactoringDialog)
    {
        RefactoringDialog->setWindowTitle(tr2i18n("Refactoring", "@title:window"));
        abortButton->setText(tr2i18n("&Abort", "@action:button"));
        fileLabel->setText(QString());
        renameLabel->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class RefactoringDialog: public Ui_RefactoringDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REFACTORINGDIALOG_H

