/********************************************************************************
** Form generated from reading UI file 'astyle_preferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ASTYLE_PREFERENCES_H
#define UI_ASTYLE_PREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_AStylePreferences
{
public:
    QHBoxLayout *horizontalLayout;
    QTabWidget *tabWidget;
    QWidget *tabIndentqtion;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    KComboBox *cbIndentType;
    QSpacerItem *spacer13_3;
    QSpinBox *inpNuberSpaces;
    QCheckBox *chkConvertTabs;
    QCheckBox *chkFillEmptyLines;
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer;
    QLabel *lblIndentObjects;
    QListWidget *listIdentObjects;
    QGridLayout *gridLayout_4;
    QSpinBox *inpMaxStatement;
    QLabel *TextLabel3_2;
    QSpinBox *inpMinConditional;
    QLabel *TextLabel2_2;
    QSpinBox *inpContinuation;
    QCheckBox *chkAfterParens;
    QSpacerItem *verticalSpacer_2;
    QWidget *tabOther;
    QVBoxLayout *verticalLayout_8;
    QGroupBox *gpBrackets;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout_5;
    QLabel *lblBrackets;
    QCheckBox *chkBracketsCloseHeaders;
    KComboBox *cbBrackets;
    QCheckBox *chkBracesAdd;
    QGroupBox *gpBlocks;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *chkBlockBreak;
    QCheckBox *chkBlockBreakAll;
    QCheckBox *chkBlockIfElse;
    QGroupBox *gpPadding;
    QVBoxLayout *verticalLayout_6;
    QGridLayout *gridLayout_6;
    KComboBox *cbParenthesisPadding;
    QCheckBox *chkPadOperators;
    QLabel *lblParenthesis;
    QCheckBox *chkPadParenthesisHeader;
    QGroupBox *gpOneLiners;
    QVBoxLayout *verticalLayout_7;
    QCheckBox *chkKeepStatements;
    QCheckBox *chkKeepBlocks;
    QGroupBox *gpOther;
    QGridLayout *gridLayout;
    QLabel *lblPointerAlign;
    QComboBox *cbPointerAlign;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QWidget *AStylePreferences)
    {
        if (AStylePreferences->objectName().isEmpty())
            AStylePreferences->setObjectName("AStylePreferences");
        AStylePreferences->resize(332, 648);
        horizontalLayout = new QHBoxLayout(AStylePreferences);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(AStylePreferences);
        tabWidget->setObjectName("tabWidget");
        tabIndentqtion = new QWidget();
        tabIndentqtion->setObjectName("tabIndentqtion");
        verticalLayout_2 = new QVBoxLayout(tabIndentqtion);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        cbIndentType = new KComboBox(tabIndentqtion);
        cbIndentType->addItem(QString());
        cbIndentType->addItem(QString());
        cbIndentType->addItem(QString());
        cbIndentType->setObjectName("cbIndentType");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbIndentType->sizePolicy().hasHeightForWidth());
        cbIndentType->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(cbIndentType);

        spacer13_3 = new QSpacerItem(18, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(spacer13_3);

        inpNuberSpaces = new QSpinBox(tabIndentqtion);
        inpNuberSpaces->setObjectName("inpNuberSpaces");
        inpNuberSpaces->setEnabled(true);
        inpNuberSpaces->setMinimum(1);
        inpNuberSpaces->setValue(4);

        horizontalLayout_2->addWidget(inpNuberSpaces);


        verticalLayout_2->addLayout(horizontalLayout_2);

        chkConvertTabs = new QCheckBox(tabIndentqtion);
        chkConvertTabs->setObjectName("chkConvertTabs");
        chkConvertTabs->setEnabled(true);

        verticalLayout_2->addWidget(chkConvertTabs);

        chkFillEmptyLines = new QCheckBox(tabIndentqtion);
        chkFillEmptyLines->setObjectName("chkFillEmptyLines");

        verticalLayout_2->addWidget(chkFillEmptyLines);

        gridLayout_3 = new QGridLayout();
        gridLayout_3->setObjectName("gridLayout_3");
        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 1, 0, 1, 1);

        lblIndentObjects = new QLabel(tabIndentqtion);
        lblIndentObjects->setObjectName("lblIndentObjects");

        gridLayout_3->addWidget(lblIndentObjects, 0, 0, 1, 1);

        listIdentObjects = new QListWidget(tabIndentqtion);
        new QListWidgetItem(listIdentObjects);
        new QListWidgetItem(listIdentObjects);
        new QListWidgetItem(listIdentObjects);
        new QListWidgetItem(listIdentObjects);
        new QListWidgetItem(listIdentObjects);
        new QListWidgetItem(listIdentObjects);
        new QListWidgetItem(listIdentObjects);
        new QListWidgetItem(listIdentObjects);
        listIdentObjects->setObjectName("listIdentObjects");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(listIdentObjects->sizePolicy().hasHeightForWidth());
        listIdentObjects->setSizePolicy(sizePolicy1);

        gridLayout_3->addWidget(listIdentObjects, 0, 1, 2, 1);


        verticalLayout_2->addLayout(gridLayout_3);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        inpMaxStatement = new QSpinBox(tabIndentqtion);
        inpMaxStatement->setObjectName("inpMaxStatement");
        inpMaxStatement->setValue(40);

        gridLayout_4->addWidget(inpMaxStatement, 0, 1, 1, 1);

        TextLabel3_2 = new QLabel(tabIndentqtion);
        TextLabel3_2->setObjectName("TextLabel3_2");
        TextLabel3_2->setWordWrap(false);

        gridLayout_4->addWidget(TextLabel3_2, 1, 0, 1, 1);

        inpMinConditional = new QSpinBox(tabIndentqtion);
        inpMinConditional->setObjectName("inpMinConditional");
        inpMinConditional->setMinimum(-1);
        inpMinConditional->setValue(-1);

        gridLayout_4->addWidget(inpMinConditional, 1, 1, 1, 1);

        TextLabel2_2 = new QLabel(tabIndentqtion);
        TextLabel2_2->setObjectName("TextLabel2_2");
        TextLabel2_2->setWordWrap(false);

        gridLayout_4->addWidget(TextLabel2_2, 0, 0, 1, 1);

        inpContinuation = new QSpinBox(tabIndentqtion);
        inpContinuation->setObjectName("inpContinuation");
        inpContinuation->setMaximum(4);
        inpContinuation->setValue(1);

        gridLayout_4->addWidget(inpContinuation, 2, 1, 1, 1);

        chkAfterParens = new QCheckBox(tabIndentqtion);
        chkAfterParens->setObjectName("chkAfterParens");

        gridLayout_4->addWidget(chkAfterParens, 2, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout_4);

        verticalSpacer_2 = new QSpacerItem(20, 144, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        tabWidget->addTab(tabIndentqtion, QString());
        tabOther = new QWidget();
        tabOther->setObjectName("tabOther");
        verticalLayout_8 = new QVBoxLayout(tabOther);
        verticalLayout_8->setObjectName("verticalLayout_8");
        gpBrackets = new QGroupBox(tabOther);
        gpBrackets->setObjectName("gpBrackets");
        verticalLayout_3 = new QVBoxLayout(gpBrackets);
        verticalLayout_3->setObjectName("verticalLayout_3");
        gridLayout_5 = new QGridLayout();
        gridLayout_5->setObjectName("gridLayout_5");
        lblBrackets = new QLabel(gpBrackets);
        lblBrackets->setObjectName("lblBrackets");
        sizePolicy1.setHeightForWidth(lblBrackets->sizePolicy().hasHeightForWidth());
        lblBrackets->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(lblBrackets, 0, 0, 1, 1);

        chkBracketsCloseHeaders = new QCheckBox(gpBrackets);
        chkBracketsCloseHeaders->setObjectName("chkBracketsCloseHeaders");
        chkBracketsCloseHeaders->setEnabled(true);

        gridLayout_5->addWidget(chkBracketsCloseHeaders, 1, 0, 1, 2);

        cbBrackets = new KComboBox(gpBrackets);
        cbBrackets->addItem(QString());
        cbBrackets->addItem(QString());
        cbBrackets->addItem(QString());
        cbBrackets->addItem(QString());
        cbBrackets->addItem(QString());
        cbBrackets->setObjectName("cbBrackets");
        sizePolicy.setHeightForWidth(cbBrackets->sizePolicy().hasHeightForWidth());
        cbBrackets->setSizePolicy(sizePolicy);

        gridLayout_5->addWidget(cbBrackets, 0, 1, 1, 1);

        chkBracesAdd = new QCheckBox(gpBrackets);
        chkBracesAdd->setObjectName("chkBracesAdd");

        gridLayout_5->addWidget(chkBracesAdd, 2, 0, 1, 2);


        verticalLayout_3->addLayout(gridLayout_5);


        verticalLayout_8->addWidget(gpBrackets);

        gpBlocks = new QGroupBox(tabOther);
        gpBlocks->setObjectName("gpBlocks");
        verticalLayout_5 = new QVBoxLayout(gpBlocks);
        verticalLayout_5->setObjectName("verticalLayout_5");
        chkBlockBreak = new QCheckBox(gpBlocks);
        chkBlockBreak->setObjectName("chkBlockBreak");

        verticalLayout_5->addWidget(chkBlockBreak);

        chkBlockBreakAll = new QCheckBox(gpBlocks);
        chkBlockBreakAll->setObjectName("chkBlockBreakAll");

        verticalLayout_5->addWidget(chkBlockBreakAll);

        chkBlockIfElse = new QCheckBox(gpBlocks);
        chkBlockIfElse->setObjectName("chkBlockIfElse");

        verticalLayout_5->addWidget(chkBlockIfElse);


        verticalLayout_8->addWidget(gpBlocks);

        gpPadding = new QGroupBox(tabOther);
        gpPadding->setObjectName("gpPadding");
        verticalLayout_6 = new QVBoxLayout(gpPadding);
        verticalLayout_6->setObjectName("verticalLayout_6");
        gridLayout_6 = new QGridLayout();
        gridLayout_6->setObjectName("gridLayout_6");
        cbParenthesisPadding = new KComboBox(gpPadding);
        cbParenthesisPadding->addItem(QString());
        cbParenthesisPadding->addItem(QString());
        cbParenthesisPadding->addItem(QString());
        cbParenthesisPadding->addItem(QString());
        cbParenthesisPadding->addItem(QString());
        cbParenthesisPadding->setObjectName("cbParenthesisPadding");
        sizePolicy.setHeightForWidth(cbParenthesisPadding->sizePolicy().hasHeightForWidth());
        cbParenthesisPadding->setSizePolicy(sizePolicy);

        gridLayout_6->addWidget(cbParenthesisPadding, 0, 1, 1, 1);

        chkPadOperators = new QCheckBox(gpPadding);
        chkPadOperators->setObjectName("chkPadOperators");

        gridLayout_6->addWidget(chkPadOperators, 2, 0, 1, 2);

        lblParenthesis = new QLabel(gpPadding);
        lblParenthesis->setObjectName("lblParenthesis");

        gridLayout_6->addWidget(lblParenthesis, 0, 0, 1, 1);

        chkPadParenthesisHeader = new QCheckBox(gpPadding);
        chkPadParenthesisHeader->setObjectName("chkPadParenthesisHeader");

        gridLayout_6->addWidget(chkPadParenthesisHeader, 1, 0, 1, 2);


        verticalLayout_6->addLayout(gridLayout_6);


        verticalLayout_8->addWidget(gpPadding);

        gpOneLiners = new QGroupBox(tabOther);
        gpOneLiners->setObjectName("gpOneLiners");
        verticalLayout_7 = new QVBoxLayout(gpOneLiners);
        verticalLayout_7->setObjectName("verticalLayout_7");
        chkKeepStatements = new QCheckBox(gpOneLiners);
        chkKeepStatements->setObjectName("chkKeepStatements");

        verticalLayout_7->addWidget(chkKeepStatements);

        chkKeepBlocks = new QCheckBox(gpOneLiners);
        chkKeepBlocks->setObjectName("chkKeepBlocks");

        verticalLayout_7->addWidget(chkKeepBlocks);


        verticalLayout_8->addWidget(gpOneLiners);

        gpOther = new QGroupBox(tabOther);
        gpOther->setObjectName("gpOther");
        gridLayout = new QGridLayout(gpOther);
        gridLayout->setObjectName("gridLayout");
        lblPointerAlign = new QLabel(gpOther);
        lblPointerAlign->setObjectName("lblPointerAlign");

        gridLayout->addWidget(lblPointerAlign, 0, 0, 1, 1);

        cbPointerAlign = new QComboBox(gpOther);
        cbPointerAlign->addItem(QString());
        cbPointerAlign->addItem(QString());
        cbPointerAlign->addItem(QString());
        cbPointerAlign->addItem(QString());
        cbPointerAlign->setObjectName("cbPointerAlign");

        gridLayout->addWidget(cbPointerAlign, 0, 1, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        verticalLayout_8->addWidget(gpOther);

        verticalSpacer_3 = new QSpacerItem(20, 70, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_8->addItem(verticalSpacer_3);

        tabWidget->addTab(tabOther, QString());

        horizontalLayout->addWidget(tabWidget);


        retranslateUi(AStylePreferences);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AStylePreferences);
    } // setupUi

    void retranslateUi(QWidget *AStylePreferences)
    {
        cbIndentType->setItemText(0, tr2i18n("Tabs", "@item:inlistbox Indentation type"));
        cbIndentType->setItemText(1, tr2i18n("Force tabs", "@item:inlistbox Indentation type"));
        cbIndentType->setItemText(2, tr2i18n("Spaces", "@item:inlistbox Indentation type"));

#if QT_CONFIG(tooltip)
        inpNuberSpaces->setToolTip(tr2i18n("Number of spaces that will be converted to a tab.\n"
"The number of spaces per tab is controlled by the editor.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkConvertTabs->setToolTip(tr2i18n("Convert tabs to spaces.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkConvertTabs->setText(tr2i18n("Con&vert tabs into spaces", "@option:check"));
#if QT_CONFIG(tooltip)
        chkFillEmptyLines->setToolTip(tr2i18n("Fill empty lines with the white space of their previous lines.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkFillEmptyLines->setText(tr2i18n("Fill empt&y lines", "@option:check"));
        lblIndentObjects->setText(tr2i18n("Indent:", "@label:listbox"));

        const bool __sortingEnabled = listIdentObjects->isSortingEnabled();
        listIdentObjects->setSortingEnabled(false);
        QListWidgetItem *___qlistwidgetitem = listIdentObjects->item(0);
        ___qlistwidgetitem->setText(tr2i18n("Blocks", "@item:inlistbox"));
        QListWidgetItem *___qlistwidgetitem1 = listIdentObjects->item(1);
        ___qlistwidgetitem1->setText(tr2i18n("Brackets", "@item:inlistbox"));
        QListWidgetItem *___qlistwidgetitem2 = listIdentObjects->item(2);
        ___qlistwidgetitem2->setText(tr2i18n("Cases", "@item:inlistbox"));
        QListWidgetItem *___qlistwidgetitem3 = listIdentObjects->item(3);
        ___qlistwidgetitem3->setText(tr2i18n("Class", "@item:inlistbox"));
        QListWidgetItem *___qlistwidgetitem4 = listIdentObjects->item(4);
        ___qlistwidgetitem4->setText(tr2i18n("Labels", "@item:inlistbox"));
        QListWidgetItem *___qlistwidgetitem5 = listIdentObjects->item(5);
        ___qlistwidgetitem5->setText(tr2i18n("Namespaces", "@item:inlistbox"));
        QListWidgetItem *___qlistwidgetitem6 = listIdentObjects->item(6);
        ___qlistwidgetitem6->setText(tr2i18n("Preprocessor directives", "@item:inlistbox"));
        QListWidgetItem *___qlistwidgetitem7 = listIdentObjects->item(7);
        ___qlistwidgetitem7->setText(tr2i18n("Switches", "@item:inlistbox"));
        listIdentObjects->setSortingEnabled(__sortingEnabled);

#if QT_CONFIG(tooltip)
        inpMaxStatement->setToolTip(tr2i18n("Indent a maximal # spaces in a continuous statement,\n"
"relative to the previous line.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        TextLabel3_2->setToolTip(tr2i18n("Indent a minimal # spaces in a continuous conditional\n"
"belonging to a conditional header.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        TextLabel3_2->setText(tr2i18n("Minimum in conditional:", "@label:spinbox"));
#if QT_CONFIG(tooltip)
        inpMinConditional->setToolTip(tr2i18n("Indent a minimal # spaces in a continuous conditional\n"
"belonging to a conditional header.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        inpMinConditional->setSpecialValueText(tr2i18n("Twice current", "@item"));
#if QT_CONFIG(tooltip)
        TextLabel2_2->setToolTip(tr2i18n("Indent a maximal # spaces in a continuous statement,\n"
"relative to the previous line.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        TextLabel2_2->setText(tr2i18n("Maximum in statement:", "@label:spinbox"));
#if QT_CONFIG(tooltip)
        inpContinuation->setToolTip(tr2i18n("Number of indents", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        chkAfterParens->setToolTip(tr2i18n("Indent, instead of align, continuation lines following lines that contain an opening paren '(' or an assignment '='.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkAfterParens->setText(tr2i18n("Continuation lines:", "@option:check"));
        tabWidget->setTabText(tabWidget->indexOf(tabIndentqtion), tr2i18n("Indentation", "@title:tab"));
        gpBrackets->setTitle(tr2i18n("Brackets", "@title:group"));
        lblBrackets->setText(tr2i18n("Type:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        chkBracketsCloseHeaders->setToolTip(tr2i18n("Break brackets before closing headers (e.g. 'else', 'catch', ...)\n"
"from their immediately preceding closing brackets.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkBracketsCloseHeaders->setText(tr2i18n("Brea&k closing headers", "@option:check"));
        cbBrackets->setItemText(0, tr2i18n("No change", "@item:inlistbox brackets style"));
        cbBrackets->setItemText(1, tr2i18n("Attach", "@item:inlistbox brackets style"));
        cbBrackets->setItemText(2, tr2i18n("Break", "@item:inlistbox brackets style"));
        cbBrackets->setItemText(3, tr2i18n("Linux", "@item:inlistbox brackets style"));
        cbBrackets->setItemText(4, tr2i18n("Run-In", "@item:inlistbox brackets style"));

#if QT_CONFIG(tooltip)
        chkBracesAdd->setToolTip(tr2i18n("Add braces to unbraced one-line conditional statements (e.g. 'if', 'for', 'while')", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkBracesAdd->setText(tr2i18n("Add b&races", "@option:check add braces to unbraced one-line conditional statements"));
        gpBlocks->setTitle(tr2i18n("Blocks", "@title:group"));
#if QT_CONFIG(tooltip)
        chkBlockBreak->setToolTip(tr2i18n("Insert empty lines around unrelated blocks, labels, classes,...\n"
"Known problems:\n"
"\n"
"1. If a statement is NOT part of a block, \n"
"the following statements are all double spaced. \n"
"Statements enclosed in a block are formatted \n"
"correctly.\n"
"\n"
"2. Comments are broken from the block.\n"
"", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkBlockBreak->setText(tr2i18n("&Break blocks", "@option:check break unrelated blocks by a newline"));
#if QT_CONFIG(tooltip)
        chkBlockBreakAll->setToolTip(tr2i18n("Like --break-blocks, except also insert empty lines \n"
"around closing headers (e.g. 'else', 'catch', ...).\n"
"\n"
"Known problems:\n"
"\n"
"1. If a statement is NOT part of a block, \n"
"the following statements are all double spaced. \n"
"Statements enclosed in a block are formatted \n"
"correctly.\n"
"\n"
"2. Comments are broken from the block.\n"
"", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkBlockBreakAll->setText(tr2i18n("Break all bl&ocks", "@option:check break all blocks with a newline"));
#if QT_CONFIG(tooltip)
        chkBlockIfElse->setToolTip(tr2i18n("Break 'else if()' statements into two different lines.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkBlockIfElse->setText(tr2i18n("Break i&f-else", "@option:check break else if() into separate lines"));
        gpPadding->setTitle(tr2i18n("Padding", "@title:group"));
        cbParenthesisPadding->setItemText(0, tr2i18n("No change", "@item:inlistbox parenthesis padding"));
        cbParenthesisPadding->setItemText(1, tr2i18n("Unpad", "@item:inlistbox parenthesis padding"));
        cbParenthesisPadding->setItemText(2, tr2i18n("Inside only", "@item:inlistbox parenthesis padding"));
        cbParenthesisPadding->setItemText(3, tr2i18n("Outside only", "@item:inlistbox parenthesis padding"));
        cbParenthesisPadding->setItemText(4, tr2i18n("Inside and outside", "@item:inlistbox parenthesis padding"));

#if QT_CONFIG(tooltip)
        chkPadOperators->setToolTip(tr2i18n("Insert space padding around operators.\n"
"Once padded, operators stay padded.\n"
"There is no unpad operator option.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkPadOperators->setText(tr2i18n("&Add spaces around operators", "@option:check"));
        lblParenthesis->setText(tr2i18n("Pad parenthesis:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        chkPadParenthesisHeader->setToolTip(tr2i18n("Insert space padding after parenthesis headers (e.g. 'if', 'for', 'while', ...)", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkPadParenthesisHeader->setText(tr2i18n("Add spaces after parenthesis &headers", "@option:check"));
        gpOneLiners->setTitle(tr2i18n("One Liners", "@title:group"));
#if QT_CONFIG(tooltip)
        chkKeepStatements->setToolTip(tr2i18n("Do not break lines containing multiple statements into\n"
"multiple single-statement lines.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkKeepStatements->setText(tr2i18n("&Keep one-line statements", "@option:check"));
#if QT_CONFIG(tooltip)
        chkKeepBlocks->setToolTip(tr2i18n("Do not break blocks residing completely on one line.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkKeepBlocks->setText(tr2i18n("Keep o&ne-line blocks", "@option:check"));
        gpOther->setTitle(tr2i18n("Other", "@title:group"));
        lblPointerAlign->setText(tr2i18n("Pointer Alignment:", "@label:listbox"));
        cbPointerAlign->setItemText(0, tr2i18n("No change", "@item:inlistbox pointer alignment"));
        cbPointerAlign->setItemText(1, tr2i18n("Name", "@item:inlistbox pointer alignment"));
        cbPointerAlign->setItemText(2, tr2i18n("Middle", "@item:inlistbox pointer alignment"));
        cbPointerAlign->setItemText(3, tr2i18n("Type", "@item:inlistbox pointer alignment"));

        tabWidget->setTabText(tabWidget->indexOf(tabOther), tr2i18n("Other", "@title:tab"));
        (void)AStylePreferences;
    } // retranslateUi

};

namespace Ui {
    class AStylePreferences: public Ui_AStylePreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ASTYLE_PREFERENCES_H

