/****************************************************************************
** Meta object code from reading C++ file 'grepoutputview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/plugins/grepview/grepoutputview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'grepoutputview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14GrepOutputViewE_t {};
} // unnamed namespace

template <> constexpr inline auto GrepOutputView::qt_create_metaobjectdata<qt_meta_tag_ZN14GrepOutputViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GrepOutputView",
        "outputViewIsClosed",
        "",
        "showErrorMessage",
        "errorMessage",
        "showMessage",
        "KDevelop::IStatus*",
        "message",
        "updateApplyState",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "changeModel",
        "index",
        "replacementTextChanged",
        "selectPreviousItem",
        "selectNextItem",
        "collapseAllItems",
        "expandAllItems",
        "onApply",
        "showDialog",
        "refresh",
        "expandElements",
        "parent",
        "updateButtonState",
        "enable",
        "rowsRemoved",
        "clearSearchHistory",
        "modelSelectorContextMenu",
        "QPoint",
        "pos",
        "updateScrollArea",
        "updateCheckable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'outputViewIsClosed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showErrorMessage'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'showMessage'
        QtMocHelpers::SlotData<void(KDevelop::IStatus *, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'updateApplyState'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 9, 11 },
        }}),
        // Slot 'changeModel'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'replacementTextChanged'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectPreviousItem'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectNextItem'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'collapseAllItems'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'expandAllItems'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onApply'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showDialog'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'expandElements'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 23 },
        }}),
        // Slot 'updateButtonState'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'rowsRemoved'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'clearSearchHistory'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'modelSelectorContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'updateScrollArea'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateCheckable'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GrepOutputView, qt_meta_tag_ZN14GrepOutputViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GrepOutputView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GrepOutputViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GrepOutputViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14GrepOutputViewE_t>.metaTypes,
    nullptr
} };

void GrepOutputView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GrepOutputView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->outputViewIsClosed(); break;
        case 1: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->showMessage((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->updateApplyState((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 4: _t->changeModel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->replacementTextChanged(); break;
        case 6: _t->selectPreviousItem(); break;
        case 7: _t->selectNextItem(); break;
        case 8: _t->collapseAllItems(); break;
        case 9: _t->expandAllItems(); break;
        case 10: _t->onApply(); break;
        case 11: _t->showDialog(); break;
        case 12: _t->refresh(); break;
        case 13: _t->expandElements((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 14: _t->updateButtonState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->rowsRemoved(); break;
        case 16: _t->clearSearchHistory(); break;
        case 17: _t->modelSelectorContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 18: _t->updateScrollArea(); break;
        case 19: _t->updateCheckable(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GrepOutputView::*)()>(_a, &GrepOutputView::outputViewIsClosed, 0))
            return;
    }
}

const QMetaObject *GrepOutputView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GrepOutputView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GrepOutputViewE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::GrepOutputView"))
        return static_cast< Ui::GrepOutputView*>(this);
    if (!strcmp(_clname, "KDevelop::IToolViewActionListener"))
        return static_cast< KDevelop::IToolViewActionListener*>(this);
    if (!strcmp(_clname, "org.kdevelop.IToolViewActionListener"))
        return static_cast< KDevelop::IToolViewActionListener*>(this);
    return QWidget::qt_metacast(_clname);
}

int GrepOutputView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void GrepOutputView::outputViewIsClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
