// This file is generated by kconfig_compiler_kf6 from projectsettings.kcfg.
// All changes you do to this file will be lost.

#include "projectsettings.h"

using namespace Clazy;

ProjectSettings::ProjectSettings( )
  : KConfigSkeleton()
{
  setCurrentGroup( QStringLiteral( "Clazy" ) );

  KConfigSkeleton::ItemString  *itemCheckSetSelection;
  itemCheckSetSelection = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CheckSetSelection" ), mCheckSetSelection );
  addItem( itemCheckSetSelection, QStringLiteral( "checkSetSelection" ) );
  KConfigSkeleton::ItemString  *itemChecks;
  itemChecks = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "checks" ), mChecks, ChecksDB::defaultChecks() );
  addItem( itemChecks, QStringLiteral( "checks" ) );
  KConfigSkeleton::ItemBool  *itemOnlyQt;
  itemOnlyQt = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "onlyQt" ), mOnlyQt, false );
  addItem( itemOnlyQt, QStringLiteral( "onlyQt" ) );
  KConfigSkeleton::ItemBool  *itemQtDeveloper;
  itemQtDeveloper = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "qtDeveloper" ), mQtDeveloper, false );
  addItem( itemQtDeveloper, QStringLiteral( "qtDeveloper" ) );
  KConfigSkeleton::ItemBool  *itemQt4Compat;
  itemQt4Compat = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "qt4Compat" ), mQt4Compat, false );
  addItem( itemQt4Compat, QStringLiteral( "qt4Compat" ) );
  KConfigSkeleton::ItemBool  *itemVisitImplicitCode;
  itemVisitImplicitCode = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "visitImplicitCode" ), mVisitImplicitCode, false );
  addItem( itemVisitImplicitCode, QStringLiteral( "visitImplicitCode" ) );
  KConfigSkeleton::ItemBool  *itemIgnoreIncludedFiles;
  itemIgnoreIncludedFiles = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ignoreIncludedFiles" ), mIgnoreIncludedFiles, false );
  addItem( itemIgnoreIncludedFiles, QStringLiteral( "ignoreIncludedFiles" ) );
  KConfigSkeleton::ItemString  *itemHeaderFilter;
  itemHeaderFilter = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "headerFilter" ), mHeaderFilter );
  addItem( itemHeaderFilter, QStringLiteral( "headerFilter" ) );
  KConfigSkeleton::ItemBool  *itemEnableAllFixits;
  itemEnableAllFixits = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "enableAllFixits" ), mEnableAllFixits, false );
  addItem( itemEnableAllFixits, QStringLiteral( "enableAllFixits" ) );
  KConfigSkeleton::ItemBool  *itemNoInplaceFixits;
  itemNoInplaceFixits = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "noInplaceFixits" ), mNoInplaceFixits, false );
  addItem( itemNoInplaceFixits, QStringLiteral( "noInplaceFixits" ) );
  KConfigSkeleton::ItemString  *itemExtraAppend;
  itemExtraAppend = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "extraAppend" ), mExtraAppend );
  addItem( itemExtraAppend, QStringLiteral( "extraAppend" ) );
  KConfigSkeleton::ItemString  *itemExtraPrepend;
  itemExtraPrepend = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "extraPrepend" ), mExtraPrepend );
  addItem( itemExtraPrepend, QStringLiteral( "extraPrepend" ) );
  KConfigSkeleton::ItemString  *itemExtraClazy;
  itemExtraClazy = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "extraClazy" ), mExtraClazy );
  addItem( itemExtraClazy, QStringLiteral( "extraClazy" ) );
}

ProjectSettings::~ProjectSettings()
{
}

