/********************************************************************************
** Form generated from reading UI file 'clangtidyprojectconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLANGTIDYPROJECTCONFIGPAGE_H
#define UI_CLANGTIDYPROJECTCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "config/checkselection.h"
#include "config/checksetselectioncombobox.h"
#include "config/customchecksetconfigproxywidget.h"

namespace ClangTidy {

class Ui_ProjectConfigPage
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_useConfigFile;
    QTabWidget *tabWidget;
    QWidget *checksTab;
    QVBoxLayout *verticalLayout_2;
    ClangTidy::CheckSetSelectionComboBox *kcfg_checkSetSelection;
    ClangTidy::CheckSelection *enabledChecks;
    ClangTidy::CustomCheckSetConfigProxyWidget *kcfg_enabledChecks;
    QWidget *tab_3;
    QFormLayout *formLayout_2;
    QLabel *label_3;
    QCheckBox *kcfg_checkSystemHeaders;
    QLabel *headerFilterLabel;
    QLineEdit *kcfg_headerFilter;
    QWidget *tab_2;
    QFormLayout *formLayout;
    QLabel *label_2;
    QLineEdit *kcfg_additionalParameters;

    void setupUi(QWidget *ClangTidy__ProjectConfigPage)
    {
        if (ClangTidy__ProjectConfigPage->objectName().isEmpty())
            ClangTidy__ProjectConfigPage->setObjectName("ClangTidy__ProjectConfigPage");
        ClangTidy__ProjectConfigPage->resize(574, 379);
        verticalLayout = new QVBoxLayout(ClangTidy__ProjectConfigPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_useConfigFile = new QCheckBox(ClangTidy__ProjectConfigPage);
        kcfg_useConfigFile->setObjectName("kcfg_useConfigFile");
        kcfg_useConfigFile->setChecked(true);

        verticalLayout->addWidget(kcfg_useConfigFile);

        tabWidget = new QTabWidget(ClangTidy__ProjectConfigPage);
        tabWidget->setObjectName("tabWidget");
        checksTab = new QWidget();
        checksTab->setObjectName("checksTab");
        checksTab->setEnabled(false);
        verticalLayout_2 = new QVBoxLayout(checksTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_checkSetSelection = new ClangTidy::CheckSetSelectionComboBox(checksTab);
        kcfg_checkSetSelection->setObjectName("kcfg_checkSetSelection");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_checkSetSelection->sizePolicy().hasHeightForWidth());
        kcfg_checkSetSelection->setSizePolicy(sizePolicy);

        verticalLayout_2->addWidget(kcfg_checkSetSelection);

        enabledChecks = new ClangTidy::CheckSelection(checksTab);
        enabledChecks->setObjectName("enabledChecks");

        verticalLayout_2->addWidget(enabledChecks);

        kcfg_enabledChecks = new ClangTidy::CustomCheckSetConfigProxyWidget(checksTab);
        kcfg_enabledChecks->setObjectName("kcfg_enabledChecks");
        kcfg_enabledChecks->setVisible(false);

        verticalLayout_2->addWidget(kcfg_enabledChecks);

        tabWidget->addTab(checksTab, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        formLayout_2 = new QFormLayout(tab_3);
        formLayout_2->setObjectName("formLayout_2");
        label_3 = new QLabel(tab_3);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_checkSystemHeaders = new QCheckBox(tab_3);
        kcfg_checkSystemHeaders->setObjectName("kcfg_checkSystemHeaders");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_checkSystemHeaders);

        headerFilterLabel = new QLabel(tab_3);
        headerFilterLabel->setObjectName("headerFilterLabel");
        headerFilterLabel->setEnabled(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, headerFilterLabel);

        kcfg_headerFilter = new QLineEdit(tab_3);
        kcfg_headerFilter->setObjectName("kcfg_headerFilter");
        kcfg_headerFilter->setClearButtonEnabled(true);
        kcfg_headerFilter->setEnabled(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_headerFilter);

        tabWidget->addTab(tab_3, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        formLayout = new QFormLayout(tab_2);
        formLayout->setObjectName("formLayout");
        label_2 = new QLabel(tab_2);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_additionalParameters = new QLineEdit(tab_2);
        kcfg_additionalParameters->setObjectName("kcfg_additionalParameters");
        kcfg_additionalParameters->setClearButtonEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_additionalParameters);

        tabWidget->addTab(tab_2, QString());

        verticalLayout->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(kcfg_checkSystemHeaders);
        headerFilterLabel->setBuddy(kcfg_headerFilter);
        label_2->setBuddy(kcfg_additionalParameters);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ClangTidy__ProjectConfigPage);
        QObject::connect(kcfg_useConfigFile, &QCheckBox::toggled, checksTab, &QWidget::setDisabled);
        QObject::connect(kcfg_useConfigFile, &QCheckBox::toggled, kcfg_headerFilter, &QLineEdit::setDisabled);
        QObject::connect(kcfg_useConfigFile, &QCheckBox::toggled, headerFilterLabel, &QLabel::setDisabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ClangTidy__ProjectConfigPage);
    } // setupUi

    void retranslateUi(QWidget *ClangTidy__ProjectConfigPage)
    {
        kcfg_useConfigFile->setText(tr2i18n("&Use .clang-tidy file(s)", "@option:check"));
        tabWidget->setTabText(tabWidget->indexOf(checksTab), tr2i18n("Checks", "@title:tab"));
        label_3->setText(tr2i18n("&Check system headers:", "@option:check"));
        headerFilterLabel->setText(tr2i18n("Header fi&lter:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_headerFilter->setToolTip(tr2i18n("Regular expression matching the names of the headers to output diagnostics from. Diagnostics from the main file of each translation unit are always displayed. Can be used together with -line-filter.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Includes", "@title:tab"));
        label_2->setText(tr2i18n("E&xtra parameters:", "@label.textbox"));
#if QT_CONFIG(tooltip)
        kcfg_additionalParameters->setToolTip(tr2i18n("Additional command line options to pass to Clang-Tidy.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Extra Parameters", "@title:tab"));
        (void)ClangTidy__ProjectConfigPage;
    } // retranslateUi

};

} // namespace ClangTidy

namespace ClangTidy {
namespace Ui {
    class ProjectConfigPage: public Ui_ProjectConfigPage {};
} // namespace Ui
} // namespace ClangTidy

#endif // CLANGTIDYPROJECTCONFIGPAGE_H

