/********************************************************************************
** Form generated from reading UI file 'cmakebuilderpreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CMAKEBUILDERPREFERENCES_H
#define UI_CMAKEBUILDERPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_CMakeBuilderPreferences
{
public:
    QFormLayout *formLayout;
    QLabel *label1;
    KUrlRequester *kcfg_cmakeExecutable;
    QLabel *label2;
    QComboBox *kcfg_generator;

    void setupUi(QWidget *CMakeBuilderPreferences)
    {
        if (CMakeBuilderPreferences->objectName().isEmpty())
            CMakeBuilderPreferences->setObjectName("CMakeBuilderPreferences");
        CMakeBuilderPreferences->resize(549, 363);
        formLayout = new QFormLayout(CMakeBuilderPreferences);
        formLayout->setContentsMargins(0, 0, 0, 0);
        formLayout->setObjectName("formLayout");
        label1 = new QLabel(CMakeBuilderPreferences);
        label1->setObjectName("label1");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label1);

        kcfg_cmakeExecutable = new KUrlRequester(CMakeBuilderPreferences);
        kcfg_cmakeExecutable->setObjectName("kcfg_cmakeExecutable");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_cmakeExecutable->sizePolicy().hasHeightForWidth());
        kcfg_cmakeExecutable->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_cmakeExecutable);

        label2 = new QLabel(CMakeBuilderPreferences);
        label2->setObjectName("label2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label2);

        kcfg_generator = new QComboBox(CMakeBuilderPreferences);
        kcfg_generator->setObjectName("kcfg_generator");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_generator);


        retranslateUi(CMakeBuilderPreferences);

        QMetaObject::connectSlotsByName(CMakeBuilderPreferences);
    } // setupUi

    void retranslateUi(QWidget *CMakeBuilderPreferences)
    {
        label1->setText(tr2i18n("Default CMake executable:", "@label:chooser"));
        label2->setText(tr2i18n("Default generator:", "@label:listbox"));
        (void)CMakeBuilderPreferences;
    } // retranslateUi

};

namespace Ui {
    class CMakeBuilderPreferences: public Ui_CMakeBuilderPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CMAKEBUILDERPREFERENCES_H

