/********************************************************************************
** Form generated from reading UI file 'mesonconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONCONFIGPAGE_H
#define UI_MESONCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "settings/mesonadvancedsettings.h"
#include "settings/mesonoptionsview.h"

QT_BEGIN_NAMESPACE

class Ui_MesonConfigPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hl_buildDir;
    QComboBox *i_buildDirs;
    QToolButton *b_addDir;
    QToolButton *b_rmDir;
    MesonOptionsView *options;
    MesonAdvancedSettings *advanced;
    QHBoxLayout *hl_status;
    QLabel *l_status;
    QLabel *l_changed;

    void setupUi(QWidget *MesonConfigPage)
    {
        if (MesonConfigPage->objectName().isEmpty())
            MesonConfigPage->setObjectName("MesonConfigPage");
        MesonConfigPage->resize(670, 500);
        verticalLayout = new QVBoxLayout(MesonConfigPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        hl_buildDir = new QHBoxLayout();
        hl_buildDir->setObjectName("hl_buildDir");
        i_buildDirs = new QComboBox(MesonConfigPage);
        i_buildDirs->setObjectName("i_buildDirs");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(i_buildDirs->sizePolicy().hasHeightForWidth());
        i_buildDirs->setSizePolicy(sizePolicy);

        hl_buildDir->addWidget(i_buildDirs);

        b_addDir = new QToolButton(MesonConfigPage);
        b_addDir->setObjectName("b_addDir");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        b_addDir->setIcon(icon);

        hl_buildDir->addWidget(b_addDir);

        b_rmDir = new QToolButton(MesonConfigPage);
        b_rmDir->setObjectName("b_rmDir");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        b_rmDir->setIcon(icon1);

        hl_buildDir->addWidget(b_rmDir);


        verticalLayout->addLayout(hl_buildDir);

        options = new MesonOptionsView(MesonConfigPage);
        options->setObjectName("options");

        verticalLayout->addWidget(options);

        advanced = new MesonAdvancedSettings(MesonConfigPage);
        advanced->setObjectName("advanced");

        verticalLayout->addWidget(advanced);

        hl_status = new QHBoxLayout();
        hl_status->setObjectName("hl_status");
        l_status = new QLabel(MesonConfigPage);
        l_status->setObjectName("l_status");

        hl_status->addWidget(l_status);

        l_changed = new QLabel(MesonConfigPage);
        l_changed->setObjectName("l_changed");
        l_changed->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hl_status->addWidget(l_changed);


        verticalLayout->addLayout(hl_status);


        retranslateUi(MesonConfigPage);
        QObject::connect(b_addDir, SIGNAL(clicked()), MesonConfigPage, SLOT(addBuildDir()));
        QObject::connect(b_rmDir, SIGNAL(clicked()), MesonConfigPage, SLOT(removeBuildDir()));
        QObject::connect(i_buildDirs, SIGNAL(currentIndexChanged(int)), MesonConfigPage, SLOT(changeBuildDirIndex(int)));
        QObject::connect(i_buildDirs, SIGNAL(currentIndexChanged(int)), MesonConfigPage, SLOT(emitChanged()));
        QObject::connect(advanced, SIGNAL(configChanged()), MesonConfigPage, SLOT(emitChanged()));
        QObject::connect(options, SIGNAL(configChanged()), MesonConfigPage, SLOT(emitChanged()));

        QMetaObject::connectSlotsByName(MesonConfigPage);
    } // setupUi

    void retranslateUi(QWidget *MesonConfigPage)
    {
        b_addDir->setText(tr2i18n("...", nullptr));
        b_rmDir->setText(tr2i18n("...", nullptr));
        l_status->setText(tr2i18n("Status message...", nullptr));
        l_changed->setText(tr2i18n("Num changed", nullptr));
        (void)MesonConfigPage;
    } // retranslateUi

};

namespace Ui {
    class MesonConfigPage: public Ui_MesonConfigPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONCONFIGPAGE_H

