/****************************************************************************
** Meta object code from reading C++ file 'patchhighlighter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/plugins/patchreview/patchhighlighter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'patchhighlighter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16PatchHighlighterE_t {};
} // unnamed namespace

template <> constexpr inline auto PatchHighlighter::qt_create_metaobjectdata<qt_meta_tag_ZN16PatchHighlighterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PatchHighlighter",
        "documentReloaded",
        "",
        "KTextEditor::Document*",
        "documentDestroyed",
        "aboutToDeleteMovingInterfaceContent",
        "markToolTipRequested",
        "KTextEditor::Mark",
        "QPoint",
        "bool&",
        "showToolTipForMark",
        "arg1",
        "KTextEditor::MovingRange*",
        "arg2",
        "isRemoval",
        "const KompareDiff2::Difference*",
        "isInsertion",
        "markClicked",
        "textInserted",
        "doc",
        "KTextEditor::Cursor",
        "cursor",
        "text",
        "newlineInserted",
        "textRemoved",
        "KTextEditor::Range",
        "oldText",
        "newlineRemoved",
        "line"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'documentReloaded'
        QtMocHelpers::SlotData<void(KTextEditor::Document *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'documentDestroyed'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToDeleteMovingInterfaceContent'
        QtMocHelpers::SlotData<void(KTextEditor::Document *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'markToolTipRequested'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, const KTextEditor::Mark &, QPoint, bool &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 7, 2 }, { 0x80000000 | 8, 2 }, { 0x80000000 | 9, 2 },
        }}),
        // Slot 'showToolTipForMark'
        QtMocHelpers::SlotData<void(const QPoint &, KTextEditor::MovingRange *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'isRemoval'
        QtMocHelpers::SlotData<bool(const KompareDiff2::Difference *)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'isInsertion'
        QtMocHelpers::SlotData<bool(const KompareDiff2::Difference *)>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'markClicked'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, const KTextEditor::Mark &, bool &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 7, 2 }, { 0x80000000 | 9, 2 },
        }}),
        // Slot 'textInserted'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, const KTextEditor::Cursor &, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 19 }, { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'newlineInserted'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, const KTextEditor::Cursor &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'textRemoved'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, const KTextEditor::Range &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 25, 2 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'newlineRemoved'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Int, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PatchHighlighter, qt_meta_tag_ZN16PatchHighlighterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PatchHighlighter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PatchHighlighterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PatchHighlighterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16PatchHighlighterE_t>.metaTypes,
    nullptr
} };

void PatchHighlighter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PatchHighlighter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentReloaded((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 1: _t->documentDestroyed(); break;
        case 2: _t->aboutToDeleteMovingInterfaceContent((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 3: _t->markToolTipRequested((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Mark>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4]))); break;
        case 4: _t->showToolTipForMark((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::MovingRange*>>(_a[2]))); break;
        case 5: { bool _r = _t->isRemoval((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isInsertion((*reinterpret_cast<std::add_pointer_t<const KompareDiff2::Difference*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->markClicked((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Mark>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[3]))); break;
        case 8: _t->textInserted((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->newlineInserted((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2]))); break;
        case 10: _t->textRemoved((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 11: _t->newlineRemoved((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *PatchHighlighter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PatchHighlighter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16PatchHighlighterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PatchHighlighter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
