/****************************************************************************
** Meta object code from reading C++ file 'breakpointmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/debugger/breakpoint/breakpointmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'breakpointmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop15BreakpointModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::BreakpointModel::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop15BreakpointModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::BreakpointModel",
        "hit",
        "",
        "row",
        "save",
        "load",
        "markChanged",
        "KTextEditor::Document*",
        "document",
        "KTextEditor::Mark",
        "mark",
        "KTextEditor::Document::MarkChangeAction",
        "action",
        "textDocumentCreated",
        "KDevelop::IDocument*",
        "documentUrlChanged",
        "QUrl",
        "previousUrl",
        "aboutToReload",
        "aboutToInvalidateMovingInterfaceContent",
        "reloaded",
        "documentSaved",
        "markContextMenuRequested",
        "QPoint",
        "pos",
        "bool&",
        "handled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hit'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'markChanged'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, KTextEditor::Mark, KTextEditor::Document::MarkChangeAction)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'textDocumentCreated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'documentUrlChanged'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *, const QUrl &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 8 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'aboutToReload'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'aboutToInvalidateMovingInterfaceContent'
        QtMocHelpers::SlotData<void(KTextEditor::Document *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'reloaded'
        QtMocHelpers::SlotData<void(KTextEditor::Document *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'documentSaved'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'markContextMenuRequested'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, KTextEditor::Mark, QPoint, bool &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BreakpointModel, qt_meta_tag_ZN8KDevelop15BreakpointModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::BreakpointModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractTableModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15BreakpointModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15BreakpointModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop15BreakpointModelE_t>.metaTypes,
    nullptr
} };

void KDevelop::BreakpointModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BreakpointModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->hit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->save(); break;
        case 2: _t->load(); break;
        case 3: _t->markChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Mark>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Document::MarkChangeAction>>(_a[3]))); break;
        case 4: _t->textDocumentCreated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 5: _t->documentUrlChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 6: _t->aboutToReload(); break;
        case 7: _t->aboutToInvalidateMovingInterfaceContent((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 8: _t->reloaded((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 9: _t->documentSaved((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 10: _t->markContextMenuRequested((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Mark>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Document* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BreakpointModel::*)(int )>(_a, &BreakpointModel::hit, 0))
            return;
    }
}

const QMetaObject *KDevelop::BreakpointModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::BreakpointModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15BreakpointModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int KDevelop::BreakpointModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::BreakpointModel::hit(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
