/****************************************************************************
** Meta object code from reading C++ file 'projectfilequickopen.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/plugins/quickopen/projectfilequickopen.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projectfilequickopen.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20BaseFileDataProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto BaseFileDataProvider::qt_create_metaobjectdata<qt_meta_tag_ZN20BaseFileDataProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BaseFileDataProvider"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BaseFileDataProvider, qt_meta_tag_ZN20BaseFileDataProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BaseFileDataProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::QuickOpenDataProviderBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20BaseFileDataProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20BaseFileDataProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20BaseFileDataProviderE_t>.metaTypes,
    nullptr
} };

void BaseFileDataProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BaseFileDataProvider *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *BaseFileDataProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BaseFileDataProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20BaseFileDataProviderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KDevelop::PathFilter<ProjectFile,BaseFileDataProvider>"))
        return static_cast< KDevelop::PathFilter<ProjectFile,BaseFileDataProvider>*>(this);
    if (!strcmp(_clname, "KDevelop::QuickOpenFileSetInterface"))
        return static_cast< KDevelop::QuickOpenFileSetInterface*>(this);
    if (!strcmp(_clname, "org.kdevelop.QuickOpenFileSetInterface"))
        return static_cast< KDevelop::QuickOpenFileSetInterface*>(this);
    return KDevelop::QuickOpenDataProviderBase::qt_metacast(_clname);
}

int BaseFileDataProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::QuickOpenDataProviderBase::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23ProjectFileDataProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto ProjectFileDataProvider::qt_create_metaobjectdata<qt_meta_tag_ZN23ProjectFileDataProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProjectFileDataProvider",
        "projectClosing",
        "",
        "KDevelop::IProject*",
        "projectOpened",
        "fileAddedToSet",
        "KDevelop::ProjectFileItem*",
        "fileRemovedFromSet"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'projectClosing'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'projectOpened'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'fileAddedToSet'
        QtMocHelpers::SlotData<void(KDevelop::ProjectFileItem *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'fileRemovedFromSet'
        QtMocHelpers::SlotData<void(KDevelop::ProjectFileItem *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectFileDataProvider, qt_meta_tag_ZN23ProjectFileDataProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProjectFileDataProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseFileDataProvider::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ProjectFileDataProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ProjectFileDataProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ProjectFileDataProviderE_t>.metaTypes,
    nullptr
} };

void ProjectFileDataProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectFileDataProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->projectClosing((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 1: _t->projectOpened((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 2: _t->fileAddedToSet((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[1]))); break;
        case 3: _t->fileRemovedFromSet((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *ProjectFileDataProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProjectFileDataProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ProjectFileDataProviderE_t>.strings))
        return static_cast<void*>(this);
    return BaseFileDataProvider::qt_metacast(_clname);
}

int ProjectFileDataProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseFileDataProvider::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN21OpenFilesDataProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenFilesDataProvider::qt_create_metaobjectdata<qt_meta_tag_ZN21OpenFilesDataProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenFilesDataProvider"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenFilesDataProvider, qt_meta_tag_ZN21OpenFilesDataProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenFilesDataProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseFileDataProvider::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21OpenFilesDataProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21OpenFilesDataProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21OpenFilesDataProviderE_t>.metaTypes,
    nullptr
} };

void OpenFilesDataProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpenFilesDataProvider *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *OpenFilesDataProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenFilesDataProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21OpenFilesDataProviderE_t>.strings))
        return static_cast<void*>(this);
    return BaseFileDataProvider::qt_metacast(_clname);
}

int OpenFilesDataProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseFileDataProvider::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
