/****************************************************************************
** Meta object code from reading C++ file 'outputmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/outputview/outputmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'outputmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop11OutputModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::OutputModel::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop11OutputModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::OutputModel",
        "progress",
        "",
        "KDevelop::IFilterStrategy::Progress",
        "allDone",
        "appendLine",
        "appendLines",
        "ensureAllDone",
        "clear",
        "OutputFilterStrategy",
        "NoFilter",
        "CompilerFilter",
        "ScriptErrorFilter",
        "NativeAppErrorFilter",
        "StaticAnalysisFilter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progress'
        QtMocHelpers::SignalData<void(const KDevelop::IFilterStrategy::Progress &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 1 },
        }}),
        // Signal 'allDone'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appendLine'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'appendLines'
        QtMocHelpers::SlotData<void(const QStringList &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Slot 'ensureAllDone'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'OutputFilterStrategy'
        QtMocHelpers::EnumData<enum OutputFilterStrategy>(9, 9, QMC::EnumFlags{}).add({
            {   10, OutputFilterStrategy::NoFilter },
            {   11, OutputFilterStrategy::CompilerFilter },
            {   12, OutputFilterStrategy::ScriptErrorFilter },
            {   13, OutputFilterStrategy::NativeAppErrorFilter },
            {   14, OutputFilterStrategy::StaticAnalysisFilter },
        }),
    };
    return QtMocHelpers::metaObjectData<OutputModel, qt_meta_tag_ZN8KDevelop11OutputModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::OutputModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop11OutputModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop11OutputModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop11OutputModelE_t>.metaTypes,
    nullptr
} };

void KDevelop::OutputModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OutputModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progress((*reinterpret_cast<std::add_pointer_t<KDevelop::IFilterStrategy::Progress>>(_a[1]))); break;
        case 1: _t->allDone(); break;
        case 2: _t->appendLine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->appendLines((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->ensureAllDone(); break;
        case 5: _t->clear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IFilterStrategy::Progress >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OutputModel::*)(const KDevelop::IFilterStrategy::Progress & )>(_a, &OutputModel::progress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OutputModel::*)()>(_a, &OutputModel::allDone, 1))
            return;
    }
}

const QMetaObject *KDevelop::OutputModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::OutputModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop11OutputModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KDevelop::IOutputViewModel"))
        return static_cast< KDevelop::IOutputViewModel*>(this);
    if (!strcmp(_clname, "org.kdevelop.IOutputViewModel"))
        return static_cast< KDevelop::IOutputViewModel*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int KDevelop::OutputModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::OutputModel::progress(const KDevelop::IFilterStrategy::Progress & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevelop::OutputModel::allDone()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
