/********************************************************************************
** Form generated from reading UI file 'qthelpconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QTHELPCONFIG_H
#define UI_QTHELPCONFIG_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_QtHelpConfigUI
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *boxAutoLoad;
    QFormLayout *formLayout;
    QLabel *labelLoadQtApiDocs;
    QCheckBox *loadQtDocsCheckBox;
    QLabel *labelLoadFromDirectory;
    KUrlRequester *qchSearchDir;
    KMessageWidget *messageAvailabilityQtDocs;
    QGroupBox *boxQchManage;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout_5;
    QTreeWidget *qchTable;
    QHBoxLayout *tableCtrlLayout;
    QPushButton *addButton;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *QtHelpConfigUI)
    {
        if (QtHelpConfigUI->objectName().isEmpty())
            QtHelpConfigUI->setObjectName("QtHelpConfigUI");
        QtHelpConfigUI->resize(560, 443);
        QtHelpConfigUI->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        verticalLayout_2 = new QVBoxLayout(QtHelpConfigUI);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        boxAutoLoad = new QGroupBox(QtHelpConfigUI);
        boxAutoLoad->setObjectName("boxAutoLoad");
        formLayout = new QFormLayout(boxAutoLoad);
        formLayout->setObjectName("formLayout");
        labelLoadQtApiDocs = new QLabel(boxAutoLoad);
        labelLoadQtApiDocs->setObjectName("labelLoadQtApiDocs");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelLoadQtApiDocs);

        loadQtDocsCheckBox = new QCheckBox(boxAutoLoad);
        loadQtDocsCheckBox->setObjectName("loadQtDocsCheckBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, loadQtDocsCheckBox);

        labelLoadFromDirectory = new QLabel(boxAutoLoad);
        labelLoadFromDirectory->setObjectName("labelLoadFromDirectory");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelLoadFromDirectory);

        qchSearchDir = new KUrlRequester(boxAutoLoad);
        qchSearchDir->setObjectName("qchSearchDir");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, qchSearchDir);

        messageAvailabilityQtDocs = new KMessageWidget(boxAutoLoad);
        messageAvailabilityQtDocs->setObjectName("messageAvailabilityQtDocs");
        messageAvailabilityQtDocs->setEnabled(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, messageAvailabilityQtDocs);


        verticalLayout_2->addWidget(boxAutoLoad);

        boxQchManage = new QGroupBox(QtHelpConfigUI);
        boxQchManage->setObjectName("boxQchManage");
        verticalLayout_3 = new QVBoxLayout(boxQchManage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(1);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, -1, -1, -1);
        qchTable = new QTreeWidget(boxQchManage);
        qchTable->headerItem()->setText(4, QString());
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(3, QString::fromUtf8("Ghns"));
        __qtreewidgetitem->setText(2, QString::fromUtf8("IconName"));
        qchTable->setHeaderItem(__qtreewidgetitem);
        qchTable->setObjectName("qchTable");
        qchTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        qchTable->setRootIsDecorated(false);
        qchTable->setWordWrap(false);
        qchTable->setColumnCount(5);
        qchTable->setProperty("showGrid", QVariant(false));
        qchTable->header()->setVisible(true);

        verticalLayout_5->addWidget(qchTable);

        tableCtrlLayout = new QHBoxLayout();
        tableCtrlLayout->setObjectName("tableCtrlLayout");
        addButton = new QPushButton(boxQchManage);
        addButton->setObjectName("addButton");

        tableCtrlLayout->addWidget(addButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        tableCtrlLayout->addItem(horizontalSpacer);


        verticalLayout_5->addLayout(tableCtrlLayout);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(-1, 0, -1, -1);

        verticalLayout_5->addLayout(horizontalLayout_3);


        horizontalLayout_2->addLayout(verticalLayout_5);


        verticalLayout_3->addLayout(horizontalLayout_2);


        verticalLayout_2->addWidget(boxQchManage);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        labelLoadQtApiDocs->setBuddy(loadQtDocsCheckBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(QtHelpConfigUI);

        QMetaObject::connectSlotsByName(QtHelpConfigUI);
    } // setupUi

    void retranslateUi(QWidget *QtHelpConfigUI)
    {
        boxAutoLoad->setTitle(tr2i18n("Load Qt Help Documentation from System Locations", "@title:group"));
        labelLoadQtApiDocs->setText(tr2i18n("&Load Qt API documentation:", "@option:check"));
        loadQtDocsCheckBox->setText(QString());
        labelLoadFromDirectory->setText(tr2i18n("Load Qt Help files from directory:", "@label:textbox"));
        messageAvailabilityQtDocs->setProperty("text", QVariant(QString()));
        boxQchManage->setTitle(tr2i18n("Install Additional Documentation Files", "@title:group"));
        QTreeWidgetItem *___qtreewidgetitem = qchTable->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Path", "@title:column"));
        ___qtreewidgetitem->setText(0, tr2i18n("Name", "@title:column"));
        addButton->setText(tr2i18n("Add", "@action:button"));
        (void)QtHelpConfigUI;
    } // retranslateUi

};

namespace Ui {
    class QtHelpConfigUI: public Ui_QtHelpConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QTHELPCONFIG_H

