/********************************************************************************
** Form generated from reading UI file 'grepwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GREPWIDGET_H
#define UI_GREPWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_GrepWidget
{
public:
    QGridLayout *gridLayout;
    QComboBox *patternCombo;
    QLabel *label_9;
    KComboBox *templateEdit;
    QPushButton *syncButton;
    QLabel *depthLabel;
    QSpinBox *depthSpin;
    QLabel *label_8;
    QLabel *label;
    QLabel *label_11;
    QCheckBox *caseSensitiveCheck;
    QLabel *label_5;
    KComboBox *filesCombo;
    QLabel *label_2;
    KComboBox *excludeCombo;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QSpacerItem *spacerItem3;
    KComboBox *templateTypeCombo;
    QLabel *label_10;
    QCheckBox *regexCheck;
    QLabel *limitToProjectLabel;
    QCheckBox *limitToProjectCheck;
    KComboBox *replacementTemplateEdit;
    QLabel *label_4;
    KComboBox *searchPaths;
    QPushButton *directorySelector;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *GrepWidget)
    {
        if (GrepWidget->objectName().isEmpty())
            GrepWidget->setObjectName("GrepWidget");
        GrepWidget->resize(730, 330);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(GrepWidget->sizePolicy().hasHeightForWidth());
        GrepWidget->setSizePolicy(sizePolicy);
        GrepWidget->setMaximumSize(QSize(16777215, 16777215));
        gridLayout = new QGridLayout(GrepWidget);
        gridLayout->setObjectName("gridLayout");
        patternCombo = new QComboBox(GrepWidget);
        patternCombo->setObjectName("patternCombo");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(patternCombo->sizePolicy().hasHeightForWidth());
        patternCombo->setSizePolicy(sizePolicy1);
        patternCombo->setEditable(true);

        gridLayout->addWidget(patternCombo, 0, 1, 1, 5);

        label_9 = new QLabel(GrepWidget);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_9, 1, 0, 1, 1);

        templateEdit = new KComboBox(GrepWidget);
        templateEdit->setObjectName("templateEdit");

        gridLayout->addWidget(templateEdit, 1, 1, 1, 3);

        syncButton = new QPushButton(GrepWidget);
        syncButton->setObjectName("syncButton");

        gridLayout->addWidget(syncButton, 5, 5, 1, 1);

        depthLabel = new QLabel(GrepWidget);
        depthLabel->setObjectName("depthLabel");
        depthLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(depthLabel, 6, 0, 1, 1);

        depthSpin = new QSpinBox(GrepWidget);
        depthSpin->setObjectName("depthSpin");
        depthSpin->setMinimum(-1);
        depthSpin->setValue(-1);

        gridLayout->addWidget(depthSpin, 6, 1, 1, 1);

        label_8 = new QLabel(GrepWidget);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_8, 0, 0, 1, 1);

        label = new QLabel(GrepWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 7, 0, 1, 1);

        label_11 = new QLabel(GrepWidget);
        label_11->setObjectName("label_11");
        label_11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_11, 3, 2, 1, 1);

        caseSensitiveCheck = new QCheckBox(GrepWidget);
        caseSensitiveCheck->setObjectName("caseSensitiveCheck");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(caseSensitiveCheck->sizePolicy().hasHeightForWidth());
        caseSensitiveCheck->setSizePolicy(sizePolicy2);
        caseSensitiveCheck->setChecked(true);

        gridLayout->addWidget(caseSensitiveCheck, 3, 3, 1, 1);

        label_5 = new QLabel(GrepWidget);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 5, 0, 1, 1);

        filesCombo = new KComboBox(GrepWidget);
        filesCombo->setObjectName("filesCombo");
        filesCombo->setEditable(true);
        filesCombo->setAutoCompletion(false);

        gridLayout->addWidget(filesCombo, 7, 1, 1, 5);

        label_2 = new QLabel(GrepWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 8, 0, 1, 1);

        excludeCombo = new KComboBox(GrepWidget);
        excludeCombo->setObjectName("excludeCombo");
        excludeCombo->setEditable(true);
        excludeCombo->setAutoCompletion(false);

        gridLayout->addWidget(excludeCombo, 8, 1, 1, 5);

        spacerItem = new QSpacerItem(141, 16, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 9, 0, 1, 1);

        spacerItem1 = new QSpacerItem(41, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem1, 9, 1, 1, 1);

        spacerItem2 = new QSpacerItem(151, 31, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem2, 9, 2, 1, 1);

        spacerItem3 = new QSpacerItem(361, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem3, 9, 3, 1, 3);

        templateTypeCombo = new KComboBox(GrepWidget);
        templateTypeCombo->setObjectName("templateTypeCombo");

        gridLayout->addWidget(templateTypeCombo, 1, 4, 1, 2);

        label_10 = new QLabel(GrepWidget);
        label_10->setObjectName("label_10");
        label_10->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_10, 3, 0, 1, 1);

        regexCheck = new QCheckBox(GrepWidget);
        regexCheck->setObjectName("regexCheck");
        regexCheck->setChecked(true);

        gridLayout->addWidget(regexCheck, 3, 1, 1, 1);

        limitToProjectLabel = new QLabel(GrepWidget);
        limitToProjectLabel->setObjectName("limitToProjectLabel");
        limitToProjectLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(limitToProjectLabel, 6, 2, 1, 1);

        limitToProjectCheck = new QCheckBox(GrepWidget);
        limitToProjectCheck->setObjectName("limitToProjectCheck");
        sizePolicy2.setHeightForWidth(limitToProjectCheck->sizePolicy().hasHeightForWidth());
        limitToProjectCheck->setSizePolicy(sizePolicy2);
        limitToProjectCheck->setChecked(true);

        gridLayout->addWidget(limitToProjectCheck, 6, 3, 1, 1);

        replacementTemplateEdit = new KComboBox(GrepWidget);
        replacementTemplateEdit->setObjectName("replacementTemplateEdit");

        gridLayout->addWidget(replacementTemplateEdit, 2, 1, 1, 3);

        label_4 = new QLabel(GrepWidget);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        searchPaths = new KComboBox(GrepWidget);
        searchPaths->setObjectName("searchPaths");
        searchPaths->setEditable(true);
        searchPaths->setAutoCompletion(false);

        gridLayout->addWidget(searchPaths, 5, 1, 1, 3);

        directorySelector = new QPushButton(GrepWidget);
        directorySelector->setObjectName("directorySelector");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(directorySelector->sizePolicy().hasHeightForWidth());
        directorySelector->setSizePolicy(sizePolicy3);
        directorySelector->setMaximumSize(QSize(30, 30));

        gridLayout->addWidget(directorySelector, 5, 4, 1, 1);

        buttonBox = new QDialogButtonBox(GrepWidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 10, 3, 1, 3);

#if QT_CONFIG(shortcut)
        label_9->setBuddy(templateEdit);
        depthLabel->setBuddy(depthSpin);
        label_8->setBuddy(patternCombo);
        label->setBuddy(filesCombo);
        label_11->setBuddy(caseSensitiveCheck);
        label_5->setBuddy(searchPaths);
        label_2->setBuddy(excludeCombo);
        label_10->setBuddy(regexCheck);
        limitToProjectLabel->setBuddy(limitToProjectCheck);
        label_4->setBuddy(replacementTemplateEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(patternCombo, templateEdit);
        QWidget::setTabOrder(templateEdit, templateTypeCombo);
        QWidget::setTabOrder(templateTypeCombo, replacementTemplateEdit);
        QWidget::setTabOrder(replacementTemplateEdit, regexCheck);
        QWidget::setTabOrder(regexCheck, caseSensitiveCheck);
        QWidget::setTabOrder(caseSensitiveCheck, searchPaths);
        QWidget::setTabOrder(searchPaths, directorySelector);
        QWidget::setTabOrder(directorySelector, syncButton);
        QWidget::setTabOrder(syncButton, depthSpin);
        QWidget::setTabOrder(depthSpin, limitToProjectCheck);
        QWidget::setTabOrder(limitToProjectCheck, filesCombo);
        QWidget::setTabOrder(filesCombo, excludeCombo);

        retranslateUi(GrepWidget);

        QMetaObject::connectSlotsByName(GrepWidget);
    } // setupUi

    void retranslateUi(QWidget *GrepWidget)
    {
#if QT_CONFIG(tooltip)
        patternCombo->setToolTip(tr2i18n("Enter the regular expression you want to search for", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        patternCombo->setWhatsThis(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Enter the regular expression you want to search for here.</p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">If you do not check \"Regular Expression\" below, this is considered a raw string. That means, all meta characters are escaped.</p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Possible meta characters are:</p>\n"
"<ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: "
                        "0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">.</span> - Matches any character</li>\n"
"<li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">^</span> - Matches the beginning of a line</li>\n"
"<li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">$</span> - Matches the end of a line</li>\n"
"<li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">\\b</span> - Matches a word boundary</li>\n"
"<li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">\\s</span> - Matches any white"
                        "space character</li></ul>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">The following repetition operators exist:</p>\n"
"<ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">?</span> - The preceding item is matched at most once</li>\n"
"<li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">*</span> - The preceding item is matched zero or more times</li>\n"
"<li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">+</span> - The preceding item is matched one or more times</li>\n"
"<li style=\" margin-top:0px; margin-bottom:0px;"
                        " margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">{</span><span style=\" font-weight:600; font-style:italic;\">n</span><span style=\" font-weight:600;\">}</span> - The preceding item is matched exactly <span style=\" font-style:italic;\">n</span> times</li>\n"
"<li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">{</span><span style=\" font-weight:600; font-style:italic;\">n</span><span style=\" font-weight:600;\">,}</span> - The preceding item is matched <span style=\" font-style:italic;\">n</span> or more times</li>\n"
"<li style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">{,</span><span style=\" font-weight:600; font-style:italic;\">n</span><span style=\" font-weight:600;\">}</span> - The preceding item is matched at most <span style=\" font-style:"
                        "italic;\">n</span> times</li>\n"
"<li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600;\">{</span><span style=\" font-weight:600; font-style:italic;\">n</span><span style=\" font-weight:600;\">,</span><span style=\" font-weight:600; font-style:italic;\">m</span><span style=\" font-weight:600;\">}</span> - The preceding item is matched at least <span style=\" font-style:italic;\">n</span>, but at most <span style=\" font-style:italic;\">m</span> times.</li></ul>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Furthermore, backreferences to bracketed subexpressions are available via the notation \\<span style=\" font-style:italic;\">n</span>.</p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">For further reference, look at <a href=\"https://www.pcre.org/\"><s"
                        "pan style=\" text-decoration: underline; color:#0057ae;\">www.pcre.org</span></a> or <span style=\" font-style:italic;\">man pcresyntax.</span></p></body></html>", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label_9->setText(tr2i18n("Template:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        templateEdit->setToolTip(tr2i18n("This is the regular expression template.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        templateEdit->setWhatsThis(tr2i18n("This is the regular expression template. <i>%s</i> will be replaced by the pattern, while <i>%%</i> will be replaced by <i>%</i>.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        syncButton->setToolTip(tr2i18n("Quickly select location from a set of directories", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        syncButton->setText(tr2i18n("Quick Select", "@action:button"));
        depthLabel->setText(tr2i18n("Depth:", "@label:spinbox"));
#if QT_CONFIG(tooltip)
        depthSpin->setToolTip(tr2i18n("Maximum level of subdirectory recursion", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        depthSpin->setWhatsThis(tr2i18n("For each search location, descend at most Depth levels of directories. Depth=0 means searching only in files directly inside selected search locations. Full Depth means no recursion limit.", nullptr));
#endif // QT_CONFIG(whatsthis)
        depthSpin->setSpecialValueText(tr2i18n("Full", "@item full recursion"));
        label_8->setText(tr2i18n("Pattern:", "@label:listbox"));
        label->setText(tr2i18n("Files:", "@label:listbox"));
        label_11->setText(tr2i18n("Case sensitive:", "@option:check"));
#if QT_CONFIG(tooltip)
        caseSensitiveCheck->setToolTip(tr2i18n("Case-sensitive searching.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        caseSensitiveCheck->setText(QString());
        label_5->setText(tr2i18n("Location(s):", "@label:listbox"));
#if QT_CONFIG(tooltip)
        filesCombo->setToolTip(tr2i18n("Files filter", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        filesCombo->setWhatsThis(tr2i18n("Enter the file name pattern of the files to search here. You may give several patterns separated by commas or spaces.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Exclude:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        excludeCombo->setToolTip(tr2i18n("Files pattern to exclude", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        excludeCombo->setWhatsThis(tr2i18n("Enter the file name pattern of the files to exclude from the search here. You may give several patterns separated by commas or spaces.<p>Every pattern is internally surrounded by asterisks, so that each pattern can match parts of the file paths.</p>", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label_10->setText(tr2i18n("Regular expression:", "@option:check"));
#if QT_CONFIG(tooltip)
        regexCheck->setToolTip(tr2i18n("Enable or disable regular expression.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        regexCheck->setText(QString());
        limitToProjectLabel->setText(tr2i18n("Limit to project files:", "@option:check"));
        limitToProjectCheck->setText(QString());
#if QT_CONFIG(tooltip)
        replacementTemplateEdit->setToolTip(tr2i18n("Enter the replacement template", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Replacement template:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        searchPaths->setToolTip(tr2i18n("Select the location where you want to search. It can be a directory, a file, or a semicolon separated (without spaces) list of directories/files.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        directorySelector->setToolTip(tr2i18n("Select a directory to search in", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        directorySelector->setText(QString());
        (void)GrepWidget;
    } // retranslateUi

};

namespace Ui {
    class GrepWidget: public Ui_GrepWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GREPWIDGET_H

