/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kdevquickopen.rc
  0x0,0x0,0x1,0x48,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x81,0x3,0xf5,0x9,0x0,0x42,0xe,0x2d,0x19,0x40,0x79,0x3,
  0x59,0xcb,0xd2,0x3a,0x8d,0xa1,0x62,0x24,0x73,0x8a,0x2b,0x35,0xf3,0xf,0xff,0xc3,
  0xc8,0x3d,0x8a,0x93,0xeb,0x5,0x41,0x62,0xc9,0x8e,0x20,0x8e,0xcf,0xdf,0x22,0x34,
  0xce,0x4f,0x11,0x87,0xf6,0x8c,0xd2,0x64,0x9b,0xbf,0xeb,0xfd,0x1c,0x69,0x5f,0x40,
  0x8c,0xab,0x23,0x20,0x8e,0x20,0x21,0xe,0x7b,0x2d,0x97,0x43,0xcf,0xb5,0x83,0xda,
  0x6f,0x58,0xe,0x49,0xef,0xaf,0x5,0x37,0x89,0xb7,0xf9,0xd7,0xe4,0xca,0xd7,0xf9,
  0xdc,0xfc,0x35,0xe8,0x97,0x1c,0x47,0x7,0xb5,0x7,0x2d,0x87,0x5,0x9,0x51,0x7f,
  0xc3,0x1a,0x96,0x49,0xac,0x3b,0x20,0xc0,0x34,0xa5,0x76,0xb6,0xf4,0x4b,0x69,0x90,
  0x68,0x5f,0xc8,0xfb,0x90,0x58,0xfe,0xf6,0x59,0xf,0x71,0xb3,0x1d,0x1c,0xaf,0xeb,
  0x4d,0x6b,0x61,0x54,0xe4,0x62,0x3b,0xea,0x2f,0x69,0xbd,0x9f,0xf1,0xa7,0x59,0x72,
  0x2a,0xbf,0x79,0x2a,0xf2,0xa1,0xdf,0x23,0x48,0xea,0xb6,0xb7,0x61,0x6b,0xcf,0x5f,
  0xa5,0x90,0x53,0x51,0x17,0x45,0x2d,0xd9,0x51,0x47,0xba,0x2a,0x26,0x6a,0x84,0x23,
  0x36,0x20,0x10,0x18,0x1,0x71,0x6c,0xbb,0x1,0x27,0x12,0xa0,0x5a,0xd8,0xc4,0x51,
  0x35,0x7a,0x4e,0x14,0xe2,0x46,0x8,0x5a,0x1,0xc6,0x22,0xa6,0x78,0x80,0x67,0xa,
  0x36,0xf6,0x68,0xe2,0xb9,0x34,0x15,0x2c,0xc1,0x74,0x96,0xc7,0xe2,0xe7,0xab,0x14,
  0x59,0x6a,0x80,0x41,0x4b,0x22,0x72,0x68,0x5c,0x7f,0x27,0x79,0x40,0xcd,0x56,0x47,
  0x7,0xe,0xc8,0xe9,0xb4,0x41,0x30,0x40,0xc6,0x98,0x3a,0x82,0x4,0x5a,0x6,0x89,
  0x42,0xe0,0x59,0xc0,0x71,0x66,0x54,0x20,0xa0,0xd3,0xe2,0x2a,0x90,0x34,0xd,0x92,
  0xe,0x72,0x1f,0xfd,0xac,0x33,0x3c,0x6a,0x6c,0x50,0x98,0x30,0x43,0xcc,0x42,0x30,
  0x84,0x23,0x6e,0xff,0xaa,0x36,0x32,0xdc,0xf6,0xe6,0x15,0x24,0x5f,0xad,0x1,0x68,
  0x1,0xca,0x1b,0xc4,0x9,0xc0,0x78,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kdevquickopen
  0x0,0xd,
  0xc,0xfb,0xd6,0x1e,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,0x0,0x76,0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x6f,0x0,0x70,0x0,0x65,0x0,0x6e,
    // kdevquickopen.rc
  0x0,0x10,
  0xd,0x63,0x8a,0xe3,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,0x0,0x76,0x0,0x71,0x0,0x75,0x0,0x69,0x0,0x63,0x0,0x6b,0x0,0x6f,0x0,0x70,0x0,0x65,0x0,0x6e,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x1a,0x75,0x2,0x18,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x1a,0x75,0x2,0x18,
  // :/kxmlgui5/kdevquickopen
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x1a,0x75,0x2,0x18,
  // :/kxmlgui5/kdevquickopen/kdevquickopen.rc
  0x0,0x0,0x0,0x36,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x1a,0x75,0x2,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kdevquickopen)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kdevquickopen)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kdevquickopen)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kdevquickopen)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kdevquickopen)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kdevquickopen)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
