/********************************************************************************
** Form generated from reading UI file 'branchmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BRANCHMANAGER_H
#define UI_BRANCHMANAGER_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BranchDialogBase
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QPushButton *newButton;
    QPushButton *deleteButton;
    QPushButton *renameButton;
    QSpacerItem *verticalSpacer_2;
    QPushButton *diffButton;
    QSpacerItem *verticalSpacer_3;
    QPushButton *checkoutButton;
    QPushButton *mergeButton;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *verticalLayout_2;
    QLineEdit *branchFilterEdit;
    QListView *branchView;

    void setupUi(QWidget *BranchDialogBase)
    {
        if (BranchDialogBase->objectName().isEmpty())
            BranchDialogBase->setObjectName("BranchDialogBase");
        BranchDialogBase->resize(438, 352);
        gridLayout = new QGridLayout(BranchDialogBase);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        newButton = new QPushButton(BranchDialogBase);
        newButton->setObjectName("newButton");

        verticalLayout->addWidget(newButton);

        deleteButton = new QPushButton(BranchDialogBase);
        deleteButton->setObjectName("deleteButton");

        verticalLayout->addWidget(deleteButton);

        renameButton = new QPushButton(BranchDialogBase);
        renameButton->setObjectName("renameButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-rename")));
        renameButton->setIcon(icon);

        verticalLayout->addWidget(renameButton);

        verticalSpacer_2 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_2);

        diffButton = new QPushButton(BranchDialogBase);
        diffButton->setObjectName("diffButton");

        verticalLayout->addWidget(diffButton);

        verticalSpacer_3 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_3);

        checkoutButton = new QPushButton(BranchDialogBase);
        checkoutButton->setObjectName("checkoutButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("dialog-ok-apply")));
        checkoutButton->setIcon(icon1);

        verticalLayout->addWidget(checkoutButton);

        mergeButton = new QPushButton(BranchDialogBase);
        mergeButton->setObjectName("mergeButton");

        verticalLayout->addWidget(mergeButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 0, 2, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        branchFilterEdit = new QLineEdit(BranchDialogBase);
        branchFilterEdit->setObjectName("branchFilterEdit");

        verticalLayout_2->addWidget(branchFilterEdit);

        branchView = new QListView(BranchDialogBase);
        branchView->setObjectName("branchView");
        branchView->setEditTriggers(QAbstractItemView::EditKeyPressed);

        verticalLayout_2->addWidget(branchView);


        gridLayout->addLayout(verticalLayout_2, 0, 1, 1, 1);


        retranslateUi(BranchDialogBase);

        QMetaObject::connectSlotsByName(BranchDialogBase);
    } // setupUi

    void retranslateUi(QWidget *BranchDialogBase)
    {
#if QT_CONFIG(tooltip)
        newButton->setToolTip(tr2i18n("Creates new branch based on the selected branch", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        newButton->setText(tr2i18n("New", "@action:button new branch"));
#if QT_CONFIG(tooltip)
        deleteButton->setToolTip(tr2i18n("The same as git branch -D", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        deleteButton->setText(tr2i18n("Delete", "@action:button"));
        renameButton->setText(tr2i18n("Rename", "@action:button"));
#if QT_CONFIG(tooltip)
        diffButton->setToolTip(tr2i18n("<p>Show changes between the current branch (or staging area, if not empty) and the last commit on the selected branch.</p>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        diffButton->setText(tr2i18n("Compare to Branch", "@action:button"));
#if QT_CONFIG(tooltip)
        checkoutButton->setToolTip(tr2i18n("Checkout to the selected branch", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        checkoutButton->setText(tr2i18n("Checkout", "@action:button checkout a version"));
        mergeButton->setText(tr2i18n("Merge", "@action:button merge a branch"));
        branchFilterEdit->setText(QString());
        branchFilterEdit->setPlaceholderText(tr2i18n("Search...", "@info:placeholder"));
        (void)BranchDialogBase;
    } // retranslateUi

};

namespace Ui {
    class BranchDialogBase: public Ui_BranchDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BRANCHMANAGER_H

