/********************************************************************************
** Form generated from reading UI file 'scriptappconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRIPTAPPCONFIG_H
#define UI_SCRIPTAPPCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KUrlRequester"
#include "shell/environmentconfigurebutton.h"
#include "util/environmentselectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ScriptAppPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout_3;
    QLabel *label_7;
    QComboBox *interpreter;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *runCurrentFile;
    QRadioButton *runFixedFile;
    QHBoxLayout *horizontalLayout_2;
    QLabel *scriptLabel;
    KUrlRequester *executablePath;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QLabel *label_3;
    QLineEdit *arguments;
    QLabel *label_4;
    KUrlRequester *workingDirectory;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    KDevelop::EnvironmentSelectionWidget *environment;
    KDevelop::EnvironmentConfigureButton *configureEnvironment;
    QLabel *label_6;
    QComboBox *outputFilteringMode;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *remoteHostCheckbox;
    QHBoxLayout *horizontalLayout_3;
    QLabel *remoteHostLabel;
    QLineEdit *remoteHost;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ScriptAppPage)
    {
        if (ScriptAppPage->objectName().isEmpty())
            ScriptAppPage->setObjectName("ScriptAppPage");
        ScriptAppPage->resize(675, 510);
        verticalLayout = new QVBoxLayout(ScriptAppPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(ScriptAppPage);
        groupBox->setObjectName("groupBox");
        formLayout_3 = new QFormLayout(groupBox);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout_3->setLabelAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        formLayout_3->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        interpreter = new QComboBox(groupBox);
        interpreter->addItem(QString());
        interpreter->addItem(QString::fromUtf8("python"));
        interpreter->addItem(QString::fromUtf8("ruby"));
        interpreter->addItem(QString::fromUtf8("bash"));
        interpreter->addItem(QString::fromUtf8("php"));
        interpreter->setObjectName("interpreter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(interpreter->sizePolicy().hasHeightForWidth());
        interpreter->setSizePolicy(sizePolicy);
        interpreter->setEditable(true);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, interpreter);


        verticalLayout->addWidget(groupBox);

        groupBox_4 = new QGroupBox(ScriptAppPage);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_2 = new QVBoxLayout(groupBox_4);
        verticalLayout_2->setObjectName("verticalLayout_2");
        runCurrentFile = new QRadioButton(groupBox_4);
        runCurrentFile->setObjectName("runCurrentFile");
        runCurrentFile->setChecked(true);

        verticalLayout_2->addWidget(runCurrentFile);

        runFixedFile = new QRadioButton(groupBox_4);
        runFixedFile->setObjectName("runFixedFile");

        verticalLayout_2->addWidget(runFixedFile);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        scriptLabel = new QLabel(groupBox_4);
        scriptLabel->setObjectName("scriptLabel");
        scriptLabel->setEnabled(false);

        horizontalLayout_2->addWidget(scriptLabel);

        executablePath = new KUrlRequester(groupBox_4);
        executablePath->setObjectName("executablePath");
        executablePath->setEnabled(false);

        horizontalLayout_2->addWidget(executablePath);


        verticalLayout_2->addLayout(horizontalLayout_2);


        verticalLayout->addWidget(groupBox_4);

        groupBox_2 = new QGroupBox(ScriptAppPage);
        groupBox_2->setObjectName("groupBox_2");
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setLabelAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        arguments = new QLineEdit(groupBox_2);
        arguments->setObjectName("arguments");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, arguments);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        workingDirectory = new KUrlRequester(groupBox_2);
        workingDirectory->setObjectName("workingDirectory");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, workingDirectory);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        environment = new KDevelop::EnvironmentSelectionWidget(groupBox_2);
        environment->setObjectName("environment");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(environment->sizePolicy().hasHeightForWidth());
        environment->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(environment);

        configureEnvironment = new KDevelop::EnvironmentConfigureButton(groupBox_2);
        configureEnvironment->setObjectName("configureEnvironment");

        horizontalLayout->addWidget(configureEnvironment);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_6 = new QLabel(groupBox_2);
        label_6->setObjectName("label_6");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_6);

        outputFilteringMode = new QComboBox(groupBox_2);
        outputFilteringMode->addItem(QString());
        outputFilteringMode->addItem(QString());
        outputFilteringMode->addItem(QString());
        outputFilteringMode->addItem(QString());
        outputFilteringMode->setObjectName("outputFilteringMode");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, outputFilteringMode);


        verticalLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(ScriptAppPage);
        groupBox_3->setObjectName("groupBox_3");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy2);
        verticalLayout_3 = new QVBoxLayout(groupBox_3);
        verticalLayout_3->setObjectName("verticalLayout_3");
        remoteHostCheckbox = new QCheckBox(groupBox_3);
        remoteHostCheckbox->setObjectName("remoteHostCheckbox");

        verticalLayout_3->addWidget(remoteHostCheckbox);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        remoteHostLabel = new QLabel(groupBox_3);
        remoteHostLabel->setObjectName("remoteHostLabel");
        remoteHostLabel->setEnabled(false);

        horizontalLayout_3->addWidget(remoteHostLabel);

        remoteHost = new QLineEdit(groupBox_3);
        remoteHost->setObjectName("remoteHost");
        remoteHost->setEnabled(false);

        horizontalLayout_3->addWidget(remoteHost);


        verticalLayout_3->addLayout(horizontalLayout_3);


        verticalLayout->addWidget(groupBox_3);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(arguments);
        label_4->setBuddy(workingDirectory);
        label_5->setBuddy(environment);
        remoteHostLabel->setBuddy(remoteHost);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(arguments, workingDirectory);
        QWidget::setTabOrder(workingDirectory, environment);
        QWidget::setTabOrder(environment, outputFilteringMode);
        QWidget::setTabOrder(outputFilteringMode, remoteHost);

        retranslateUi(ScriptAppPage);
        QObject::connect(runFixedFile, SIGNAL(toggled(bool)), executablePath, SLOT(setEnabled(bool)));
        QObject::connect(remoteHostCheckbox, &QCheckBox::toggled, remoteHostLabel, &QLabel::setEnabled);
        QObject::connect(remoteHostCheckbox, &QCheckBox::toggled, remoteHost, &QLineEdit::setEnabled);
        QObject::connect(runFixedFile, &QRadioButton::toggled, scriptLabel, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(ScriptAppPage);
    } // setupUi

    void retranslateUi(QWidget *ScriptAppPage)
    {
        groupBox->setTitle(tr2i18n("Interpreter", "@title:group"));
        label_7->setText(tr2i18n("Script interpreter:", "@label:listbox"));
        interpreter->setItemText(0, QString());

        groupBox_4->setTitle(tr2i18n("Script file", "@title:group"));
        runCurrentFile->setText(tr2i18n("Run the file currently open in the editor", "@option:radio"));
        runFixedFile->setText(tr2i18n("Always run the same file", "@option:radio"));
        scriptLabel->setText(tr2i18n("Script file:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        executablePath->setToolTip(tr2i18n("Enter the absolute path to the script to run", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        executablePath->setPlaceholderText(tr2i18n("/path/to/script", "@info:placeholder"));
        groupBox_2->setTitle(tr2i18n("Behavior", "@title:group"));
        label_3->setText(tr2i18n("Arguments:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        arguments->setToolTip(tr2i18n("Enter arguments to give to the executable", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Working directory:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        workingDirectory->setToolTip(tr2i18n("Select a working directory for the executable", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Environment:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        environment->setToolTip(tr2i18n("Select an environment to be used", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Output filter:", "@label:listbox"));
        outputFilteringMode->setItemText(0, tr2i18n("No Filter", "@item:inlistbox output filter"));
        outputFilteringMode->setItemText(1, tr2i18n("Compiler Filter", "@item:inlistbox output filter"));
        outputFilteringMode->setItemText(2, tr2i18n("Script Error Filter", "@item:inlistbox output filter"));
        outputFilteringMode->setItemText(3, tr2i18n("Static Analysis Filter", "@item:inlistbox output filter"));

#if QT_CONFIG(tooltip)
        outputFilteringMode->setToolTip(tr2i18n("Select the filter to applied to the output. E.g. to mark errors with red text", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        groupBox_3->setTitle(tr2i18n("Execute on Host", "@title:group"));
        remoteHostCheckbox->setText(tr2i18n("Execute on remote host", "@option:check"));
        remoteHostLabel->setText(tr2i18n("Remote host (ssh):", "@label:textbox"));
        remoteHost->setPlaceholderText(tr2i18n("user@host", "@info:placeholder"));
#if QT_CONFIG(tooltip)
        remoteHost->setToolTip(tr2i18n("Enter a remote host (user@host)", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        (void)ScriptAppPage;
    } // retranslateUi

};

namespace Ui {
    class ScriptAppPage: public Ui_ScriptAppPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRIPTAPPCONFIG_H

