/********************************************************************************
** Form generated from reading UI file 'gitnameemaildialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GITNAMEEMAILDIALOG_H
#define UI_GITNAMEEMAILDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GitNameEmailDialog
{
public:
    QVBoxLayout *_2;
    QLabel *descriptionLabel;
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *nameEdit;
    QLabel *label_2;
    QLineEdit *emailEdit;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QCheckBox *globalCheckBox;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *GitNameEmailDialog)
    {
        if (GitNameEmailDialog->objectName().isEmpty())
            GitNameEmailDialog->setObjectName("GitNameEmailDialog");
        GitNameEmailDialog->setWindowModality(Qt::WindowModal);
        GitNameEmailDialog->resize(446, 282);
        _2 = new QVBoxLayout(GitNameEmailDialog);
        _2->setObjectName("_2");
        descriptionLabel = new QLabel(GitNameEmailDialog);
        descriptionLabel->setObjectName("descriptionLabel");
        descriptionLabel->setWordWrap(true);

        _2->addWidget(descriptionLabel);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(GitNameEmailDialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        nameEdit = new QLineEdit(GitNameEmailDialog);
        nameEdit->setObjectName("nameEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, nameEdit);

        label_2 = new QLabel(GitNameEmailDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        emailEdit = new QLineEdit(GitNameEmailDialog);
        emailEdit->setObjectName("emailEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, emailEdit);


        _2->addLayout(formLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        _2->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        globalCheckBox = new QCheckBox(GitNameEmailDialog);
        globalCheckBox->setObjectName("globalCheckBox");

        horizontalLayout->addWidget(globalCheckBox);

        horizontalSpacer = new QSpacerItem(40, 1, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(GitNameEmailDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Save);

        horizontalLayout->addWidget(buttonBox);


        _2->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        label->setBuddy(nameEdit);
        label_2->setBuddy(emailEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(GitNameEmailDialog);

        QMetaObject::connectSlotsByName(GitNameEmailDialog);
    } // setupUi

    void retranslateUi(QDialog *GitNameEmailDialog)
    {
        GitNameEmailDialog->setWindowTitle(tr2i18n("Configure Name and Email for Git", "@title:window"));
        descriptionLabel->setText(tr2i18n("<html><head/><body><p>You have not yet configured the name and email to be associated with your Git commits.<br/>The values you enter here will be written to the Git configuration, either locally for the current project only, or globally for all Git projects.</p></body></html>", nullptr));
        label->setText(tr2i18n("&Name:", "@label:textbox"));
        label_2->setText(tr2i18n("Emai&l:", "@label:textbox"));
        globalCheckBox->setText(tr2i18n("Write to global config", "@option:check"));
    } // retranslateUi

};

namespace Ui {
    class GitNameEmailDialog: public Ui_GitNameEmailDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GITNAMEEMAILDIALOG_H

