/********************************************************************************
** Form generated from reading UI file 'selectaddressdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTADDRESSDIALOG_H
#define UI_SELECTADDRESSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KHistoryComboBox"

QT_BEGIN_NAMESPACE

class Ui_SelectAddressDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    KHistoryComboBox *comboBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SelectAddressDialog)
    {
        if (SelectAddressDialog->objectName().isEmpty())
            SelectAddressDialog->setObjectName("SelectAddressDialog");
        SelectAddressDialog->resize(291, 94);
        verticalLayout = new QVBoxLayout(SelectAddressDialog);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(SelectAddressDialog);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        comboBox = new KHistoryComboBox(SelectAddressDialog);
        comboBox->setObjectName("comboBox");
        comboBox->setInsertPolicy(QComboBox::InsertAtTop);
        comboBox->setProperty("urlDropsEnabled", QVariant(false));

        verticalLayout->addWidget(comboBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(SelectAddressDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(SelectAddressDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SelectAddressDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SelectAddressDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SelectAddressDialog);
    } // setupUi

    void retranslateUi(QDialog *SelectAddressDialog)
    {
        SelectAddressDialog->setWindowTitle(tr2i18n("Address Selector", "@title:window"));
#if QT_CONFIG(tooltip)
        SelectAddressDialog->setToolTip(tr2i18n("Select the address to disassemble around", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Address to disassemble around:", "@label:listbox"));
    } // retranslateUi

};

namespace Ui {
    class SelectAddressDialog: public Ui_SelectAddressDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTADDRESSDIALOG_H

