/********************************************************************************
** Form generated from reading UI file 'globalconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GLOBALCONFIGPAGE_H
#define UI_GLOBALCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

namespace Heaptrack {

class Ui_GlobalConfigPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *pathsGroupBox;
    QFormLayout *formLayout;
    QLabel *heaptrackExecutableLabel;
    KUrlRequester *kcfg_heaptrackExecutable;
    QLabel *heaptrackGuiExecutableLabel;
    KUrlRequester *kcfg_heaptrackGuiExecutable;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Heaptrack__GlobalConfigPage)
    {
        if (Heaptrack__GlobalConfigPage->objectName().isEmpty())
            Heaptrack__GlobalConfigPage->setObjectName("Heaptrack__GlobalConfigPage");
        Heaptrack__GlobalConfigPage->resize(450, 213);
        verticalLayout = new QVBoxLayout(Heaptrack__GlobalConfigPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        pathsGroupBox = new QGroupBox(Heaptrack__GlobalConfigPage);
        pathsGroupBox->setObjectName("pathsGroupBox");
        formLayout = new QFormLayout(pathsGroupBox);
        formLayout->setObjectName("formLayout");
        heaptrackExecutableLabel = new QLabel(pathsGroupBox);
        heaptrackExecutableLabel->setObjectName("heaptrackExecutableLabel");
        heaptrackExecutableLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, heaptrackExecutableLabel);

        kcfg_heaptrackExecutable = new KUrlRequester(pathsGroupBox);
        kcfg_heaptrackExecutable->setObjectName("kcfg_heaptrackExecutable");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_heaptrackExecutable);

        heaptrackGuiExecutableLabel = new QLabel(pathsGroupBox);
        heaptrackGuiExecutableLabel->setObjectName("heaptrackGuiExecutableLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, heaptrackGuiExecutableLabel);

        kcfg_heaptrackGuiExecutable = new KUrlRequester(pathsGroupBox);
        kcfg_heaptrackGuiExecutable->setObjectName("kcfg_heaptrackGuiExecutable");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_heaptrackGuiExecutable);


        verticalLayout->addWidget(pathsGroupBox);

        verticalSpacer = new QSpacerItem(20, 68, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        heaptrackExecutableLabel->setBuddy(kcfg_heaptrackExecutable);
#endif // QT_CONFIG(shortcut)

        retranslateUi(Heaptrack__GlobalConfigPage);

        QMetaObject::connectSlotsByName(Heaptrack__GlobalConfigPage);
    } // setupUi

    void retranslateUi(QWidget *Heaptrack__GlobalConfigPage)
    {
        pathsGroupBox->setTitle(tr2i18n("Executables", "@title:group"));
        heaptrackExecutableLabel->setText(tr2i18n("Heaptrack:", "@label:chooser"));
        heaptrackGuiExecutableLabel->setText(tr2i18n("Visualizer:", "@label:chooser"));
        (void)Heaptrack__GlobalConfigPage;
    } // retranslateUi

};

} // namespace Heaptrack

namespace Heaptrack {
namespace Ui {
    class GlobalConfigPage: public Ui_GlobalConfigPage {};
} // namespace Ui
} // namespace Heaptrack

#endif // GLOBALCONFIGPAGE_H

