/********************************************************************************
** Form generated from reading UI file 'projectsourcepage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTSOURCEPAGE_H
#define UI_PROJECTSOURCEPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_ProjectSourcePage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_2;
    QComboBox *sources;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    KUrlRequester *workingDir;
    QGroupBox *sourceBox;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *remoteWidgetLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *get;
    QProgressBar *creationProgress;
    KMessageWidget *status;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ProjectSourcePage)
    {
        if (ProjectSourcePage->objectName().isEmpty())
            ProjectSourcePage->setObjectName("ProjectSourcePage");
        ProjectSourcePage->resize(420, 353);
        verticalLayout = new QVBoxLayout(ProjectSourcePage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_2 = new QLabel(ProjectSourcePage);
        label_2->setObjectName("label_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);

        horizontalLayout_3->addWidget(label_2);

        sources = new QComboBox(ProjectSourcePage);
        sources->setObjectName("sources");

        horizontalLayout_3->addWidget(sources);


        verticalLayout->addLayout(horizontalLayout_3);

        groupBox_2 = new QGroupBox(ProjectSourcePage);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_2 = new QHBoxLayout(groupBox_2);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);

        workingDir = new KUrlRequester(groupBox_2);
        workingDir->setObjectName("workingDir");

        horizontalLayout_2->addWidget(workingDir);


        verticalLayout->addWidget(groupBox_2);

        sourceBox = new QGroupBox(ProjectSourcePage);
        sourceBox->setObjectName("sourceBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sourceBox->sizePolicy().hasHeightForWidth());
        sourceBox->setSizePolicy(sizePolicy1);
        verticalLayout_2 = new QVBoxLayout(sourceBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        remoteWidgetLayout = new QVBoxLayout();
        remoteWidgetLayout->setObjectName("remoteWidgetLayout");
        remoteWidgetLayout->setContentsMargins(0, 0, 0, 0);

        verticalLayout_2->addLayout(remoteWidgetLayout);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        get = new QPushButton(sourceBox);
        get->setObjectName("get");
        get->setEnabled(false);

        horizontalLayout->addWidget(get);

        creationProgress = new QProgressBar(sourceBox);
        creationProgress->setObjectName("creationProgress");
        creationProgress->setEnabled(false);
        creationProgress->setValue(0);

        horizontalLayout->addWidget(creationProgress);


        verticalLayout_2->addLayout(horizontalLayout);

        status = new KMessageWidget(sourceBox);
        status->setObjectName("status");

        verticalLayout_2->addWidget(status);


        verticalLayout->addWidget(sourceBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ProjectSourcePage);

        QMetaObject::connectSlotsByName(ProjectSourcePage);
    } // setupUi

    void retranslateUi(QWidget *ProjectSourcePage)
    {
        label_2->setText(tr2i18n("Source:", "@label:listbox"));
        groupBox_2->setTitle(tr2i18n("Destination", "@title:group"));
        label->setText(tr2i18n("Directory:", "@label:textbox"));
        workingDir->setProperty("placeholderText", QVariant(tr2i18n("Select the directory to use...", "@info:placeholder")));
        sourceBox->setTitle(tr2i18n("Source", "@title:group"));
        get->setText(tr2i18n("Get", "@action:button"));
        (void)ProjectSourcePage;
    } // retranslateUi

};

namespace Ui {
    class ProjectSourcePage: public Ui_ProjectSourcePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTSOURCEPAGE_H

