/********************************************************************************
** Form generated from reading UI file 'projectinfopage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTINFOPAGE_H
#define UI_PROJECTINFOPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProjectInfoPage
{
public:
    QFormLayout *formLayout;
    QLabel *label_2;
    QLabel *label;
    QLineEdit *nameEdit;
    QComboBox *managerCombo;

    void setupUi(QWidget *ProjectInfoPage)
    {
        if (ProjectInfoPage->objectName().isEmpty())
            ProjectInfoPage->setObjectName("ProjectInfoPage");
        ProjectInfoPage->resize(651, 416);
        formLayout = new QFormLayout(ProjectInfoPage);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(ProjectInfoPage);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        label = new QLabel(ProjectInfoPage);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        nameEdit = new QLineEdit(ProjectInfoPage);
        nameEdit->setObjectName("nameEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, nameEdit);

        managerCombo = new QComboBox(ProjectInfoPage);
        managerCombo->setObjectName("managerCombo");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, managerCombo);


        retranslateUi(ProjectInfoPage);

        QMetaObject::connectSlotsByName(ProjectInfoPage);
    } // setupUi

    void retranslateUi(QWidget *ProjectInfoPage)
    {
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Select the Management Plugin to use for this project", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Project manager:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Provide a name for the project", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Name:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        nameEdit->setToolTip(tr2i18n("Provide a name for the project", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        managerCombo->setToolTip(tr2i18n("Select the Management Plugin to use for this project", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        (void)ProjectInfoPage;
    } // retranslateUi

};

namespace Ui {
    class ProjectInfoPage: public Ui_ProjectInfoPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTINFOPAGE_H

