/********************************************************************************
** Form generated from reading UI file 'externalscriptview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTERNALSCRIPTVIEW_H
#define UI_EXTERNALSCRIPTVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ExternalScriptViewBase
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLineEdit *filterText;
    QTreeView *scriptTree;

    void setupUi(QWidget *ExternalScriptViewBase)
    {
        if (ExternalScriptViewBase->objectName().isEmpty())
            ExternalScriptViewBase->setObjectName("ExternalScriptViewBase");
        ExternalScriptViewBase->resize(210, 377);
        vboxLayout = new QVBoxLayout(ExternalScriptViewBase);
        vboxLayout->setSpacing(2);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(0);
        hboxLayout->setObjectName("hboxLayout");
        filterText = new QLineEdit(ExternalScriptViewBase);
        filterText->setObjectName("filterText");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(filterText->sizePolicy().hasHeightForWidth());
        filterText->setSizePolicy(sizePolicy);
        filterText->setClearButtonEnabled(true);

        hboxLayout->addWidget(filterText);


        vboxLayout->addLayout(hboxLayout);

        scriptTree = new QTreeView(ExternalScriptViewBase);
        scriptTree->setObjectName("scriptTree");

        vboxLayout->addWidget(scriptTree);

        QWidget::setTabOrder(filterText, scriptTree);

        retranslateUi(ExternalScriptViewBase);

        QMetaObject::connectSlotsByName(ExternalScriptViewBase);
    } // setupUi

    void retranslateUi(QWidget *ExternalScriptViewBase)
    {
        filterText->setPlaceholderText(tr2i18n("Filter...", "@info:placeholder"));
        (void)ExternalScriptViewBase;
    } // retranslateUi

};

namespace Ui {
    class ExternalScriptViewBase: public Ui_ExternalScriptViewBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXTERNALSCRIPTVIEW_H

