/********************************************************************************
** Form generated from reading UI file 'projectselectionpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTSELECTIONPAGE_H
#define UI_PROJECTSELECTIONPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "KUrlRequester"
#include "util/multilevellistview.h"

QT_BEGIN_NAMESPACE

class Ui_ProjectSelectionPage
{
public:
    QGridLayout *gridLayout;
    QGroupBox *propertiesBox;
    QFormLayout *formLayout;
    QLabel *projectNameLabel;
    QLineEdit *projectNameEdit;
    QLabel *locationLabel;
    KUrlRequester *locationUrl;
    KMessageWidget *locationValidWidget;
    KDevelop::MultiLevelListView *listView;
    QFrame *descriptionFrame;
    QVBoxLayout *verticalLayout_2;
    QWidget *descriptionContent;
    QVBoxLayout *verticalLayout;
    QLabel *header;
    QComboBox *templateType;
    QLabel *icon;
    QLabel *description;

    void setupUi(QWidget *ProjectSelectionPage)
    {
        if (ProjectSelectionPage->objectName().isEmpty())
            ProjectSelectionPage->setObjectName("ProjectSelectionPage");
        ProjectSelectionPage->resize(807, 598);
        gridLayout = new QGridLayout(ProjectSelectionPage);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        propertiesBox = new QGroupBox(ProjectSelectionPage);
        propertiesBox->setObjectName("propertiesBox");
        propertiesBox->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(propertiesBox->sizePolicy().hasHeightForWidth());
        propertiesBox->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(propertiesBox);
        formLayout->setObjectName("formLayout");
        projectNameLabel = new QLabel(propertiesBox);
        projectNameLabel->setObjectName("projectNameLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, projectNameLabel);

        projectNameEdit = new QLineEdit(propertiesBox);
        projectNameEdit->setObjectName("projectNameEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, projectNameEdit);

        locationLabel = new QLabel(propertiesBox);
        locationLabel->setObjectName("locationLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, locationLabel);

        locationUrl = new KUrlRequester(propertiesBox);
        locationUrl->setObjectName("locationUrl");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, locationUrl);

        locationValidWidget = new KMessageWidget(propertiesBox);
        locationValidWidget->setObjectName("locationValidWidget");

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, locationValidWidget);


        gridLayout->addWidget(propertiesBox, 1, 0, 1, 2);

        listView = new KDevelop::MultiLevelListView(ProjectSelectionPage);
        listView->setObjectName("listView");

        gridLayout->addWidget(listView, 0, 0, 1, 1);

        descriptionFrame = new QFrame(ProjectSelectionPage);
        descriptionFrame->setObjectName("descriptionFrame");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(descriptionFrame->sizePolicy().hasHeightForWidth());
        descriptionFrame->setSizePolicy(sizePolicy1);
        descriptionFrame->setMinimumSize(QSize(300, 400));
        descriptionFrame->setAutoFillBackground(false);
        descriptionFrame->setFrameShape(QFrame::StyledPanel);
        descriptionFrame->setFrameShadow(QFrame::Sunken);
        verticalLayout_2 = new QVBoxLayout(descriptionFrame);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        descriptionContent = new QWidget(descriptionFrame);
        descriptionContent->setObjectName("descriptionContent");
        descriptionContent->setAutoFillBackground(true);
        verticalLayout = new QVBoxLayout(descriptionContent);
        verticalLayout->setObjectName("verticalLayout");
        header = new QLabel(descriptionContent);
        header->setObjectName("header");
        header->setText(QString::fromUtf8(""));
        header->setAlignment(Qt::AlignHCenter|Qt::AlignTop);
        header->setWordWrap(true);

        verticalLayout->addWidget(header);

        templateType = new QComboBox(descriptionContent);
        templateType->setObjectName("templateType");

        verticalLayout->addWidget(templateType);

        icon = new QLabel(descriptionContent);
        icon->setObjectName("icon");
        icon->setText(QString::fromUtf8(""));
        icon->setAlignment(Qt::AlignHCenter|Qt::AlignTop);

        verticalLayout->addWidget(icon);

        description = new QLabel(descriptionContent);
        description->setObjectName("description");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(description->sizePolicy().hasHeightForWidth());
        description->setSizePolicy(sizePolicy2);
        description->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        description->setWordWrap(true);

        verticalLayout->addWidget(description);


        verticalLayout_2->addWidget(descriptionContent);


        gridLayout->addWidget(descriptionFrame, 0, 1, 1, 1);


        retranslateUi(ProjectSelectionPage);

        QMetaObject::connectSlotsByName(ProjectSelectionPage);
    } // setupUi

    void retranslateUi(QWidget *ProjectSelectionPage)
    {
        propertiesBox->setTitle(tr2i18n("Properties", "@title:group"));
        projectNameLabel->setText(tr2i18n("Project name:", "@label:textbox"));
        locationLabel->setText(tr2i18n("Location:", "@label:textbox"));
        (void)ProjectSelectionPage;
    } // retranslateUi

};

namespace Ui {
    class ProjectSelectionPage: public Ui_ProjectSelectionPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTSELECTIONPAGE_H

