/****************************************************************************
** Meta object code from reading C++ file 'container.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/sublime/container.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'container.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Sublime9ContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto Sublime::Container::qt_create_metaobjectdata<qt_meta_tag_ZN7Sublime9ContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Sublime::Container",
        "activateView",
        "",
        "Sublime::View*",
        "view",
        "requestClose",
        "QWidget*",
        "w",
        "newTabRequested",
        "tabContextMenuRequested",
        "QMenu*",
        "menu",
        "tabToolTipRequested",
        "Sublime::Container*",
        "container",
        "idx",
        "tabDoubleClicked",
        "widgetActivated",
        "documentTitleChanged",
        "Sublime::Document*",
        "doc",
        "statusIconChanged",
        "statusChanged",
        "tabMoved",
        "from",
        "to",
        "contextMenu",
        "QPoint",
        "doubleClickTriggered",
        "tab",
        "documentListActionTriggered",
        "QAction*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activateView'
        QtMocHelpers::SignalData<void(Sublime::View *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'requestClose'
        QtMocHelpers::SignalData<void(QWidget *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'newTabRequested'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabContextMenuRequested'
        QtMocHelpers::SignalData<void(Sublime::View *, QMenu *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'tabToolTipRequested'
        QtMocHelpers::SignalData<void(Sublime::View *, Sublime::Container *, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 13, 14 }, { QMetaType::Int, 15 },
        }}),
        // Signal 'tabDoubleClicked'
        QtMocHelpers::SignalData<void(Sublime::View *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'widgetActivated'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'documentTitleChanged'
        QtMocHelpers::SlotData<void(Sublime::Document *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'statusIconChanged'
        QtMocHelpers::SlotData<void(Sublime::Document *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 2 },
        }}),
        // Slot 'statusChanged'
        QtMocHelpers::SlotData<void(Sublime::View *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'requestClose'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'tabMoved'
        QtMocHelpers::SlotData<void(int, int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'contextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 2 },
        }}),
        // Slot 'doubleClickTriggered'
        QtMocHelpers::SlotData<void(int)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Slot 'documentListActionTriggered'
        QtMocHelpers::SlotData<void(QAction *)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Container, qt_meta_tag_ZN7Sublime9ContainerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Sublime::Container::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime9ContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime9ContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Sublime9ContainerE_t>.metaTypes,
    nullptr
} };

void Sublime::Container::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Container *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activateView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 1: _t->requestClose((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 2: _t->newTabRequested(); break;
        case 3: _t->tabContextMenuRequested((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 4: _t->tabToolTipRequested((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Container*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 5: _t->tabDoubleClicked((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 6: _t->widgetActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->documentTitleChanged((*reinterpret_cast<std::add_pointer_t<Sublime::Document*>>(_a[1]))); break;
        case 8: _t->statusIconChanged((*reinterpret_cast<std::add_pointer_t<Sublime::Document*>>(_a[1]))); break;
        case 9: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 10: _t->requestClose((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->tabMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->contextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 13: _t->doubleClickTriggered((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->documentListActionTriggered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Sublime::Container* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Container::*)(Sublime::View * )>(_a, &Container::activateView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Container::*)(QWidget * )>(_a, &Container::requestClose, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Container::*)()>(_a, &Container::newTabRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Container::*)(Sublime::View * , QMenu * )>(_a, &Container::tabContextMenuRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Container::*)(Sublime::View * , Sublime::Container * , int )>(_a, &Container::tabToolTipRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Container::*)(Sublime::View * )>(_a, &Container::tabDoubleClicked, 5))
            return;
    }
}

const QMetaObject *Sublime::Container::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sublime::Container::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime9ContainerE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Sublime::Container::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Sublime::Container::activateView(Sublime::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Sublime::Container::requestClose(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Sublime::Container::newTabRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Sublime::Container::tabContextMenuRequested(Sublime::View * _t1, QMenu * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Sublime::Container::tabToolTipRequested(Sublime::View * _t1, Sublime::Container * _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void Sublime::Container::tabDoubleClicked(Sublime::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
