// This file is generated by kconfig_compiler_kf6 from projectfiltersettings.kcfg.
// All changes you do to this file will be lost.
#ifndef PROJECTFILTERSETTINGS_H
#define PROJECTFILTERSETTINGS_H

#include <project/projectconfigskeleton.h>

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class ProjectFilterSettings : public KDevelop::ProjectConfigSkeleton
{
  public:
    static ProjectFilterSettings *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~ProjectFilterSettings() override;

  protected:
    ProjectFilterSettings(KSharedConfig::Ptr config);
    friend class ProjectFilterSettingsHelper;


  private:
};

#endif

