/********************************************************************************
** Form generated from reading UI file 'patchreview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PATCHREVIEW_H
#define UI_PATCHREVIEW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EditPatch
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *buttonsLayout;
    QHBoxLayout *horizontalLayout;
    QToolButton *previousFile;
    QToolButton *previousHunk;
    QToolButton *nextHunk;
    QToolButton *nextFile;
    QSpacerItem *horizontalSpacer;
    QToolButton *updateButton;
    QToolButton *testsButton;
    QSpacerItem *buttonsSpacer;
    QHBoxLayout *horizontalLayout_3;
    QToolButton *exportReview;
    QToolButton *cancelReview;
    QToolButton *finishReview;
    QHBoxLayout *contentLayout;
    QGroupBox *filesGroup;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *verticalLayout;
    QProgressBar *testProgressBar;
    QTreeView *filesList;

    void setupUi(QWidget *EditPatch)
    {
        if (EditPatch->objectName().isEmpty())
            EditPatch->setObjectName("EditPatch");
        EditPatch->resize(703, 357);
        verticalLayout_2 = new QVBoxLayout(EditPatch);
        verticalLayout_2->setObjectName("verticalLayout_2");
        buttonsLayout = new QHBoxLayout();
        buttonsLayout->setObjectName("buttonsLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        previousFile = new QToolButton(EditPatch);
        previousFile->setObjectName("previousFile");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("arrow-left")));
        previousFile->setIcon(icon);

        horizontalLayout->addWidget(previousFile);

        previousHunk = new QToolButton(EditPatch);
        previousHunk->setObjectName("previousHunk");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("arrow-up")));
        previousHunk->setIcon(icon1);

        horizontalLayout->addWidget(previousHunk);

        nextHunk = new QToolButton(EditPatch);
        nextHunk->setObjectName("nextHunk");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("arrow-down")));
        nextHunk->setIcon(icon2);

        horizontalLayout->addWidget(nextHunk);

        nextFile = new QToolButton(EditPatch);
        nextFile->setObjectName("nextFile");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("arrow-right")));
        nextFile->setIcon(icon3);

        horizontalLayout->addWidget(nextFile);

        horizontalSpacer = new QSpacerItem(60, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        updateButton = new QToolButton(EditPatch);
        updateButton->setObjectName("updateButton");
        updateButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("view-refresh")));
        updateButton->setIcon(icon4);

        horizontalLayout->addWidget(updateButton);

        testsButton = new QToolButton(EditPatch);
        testsButton->setObjectName("testsButton");
        testsButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("preflight-verifier")));
        testsButton->setIcon(icon5);

        horizontalLayout->addWidget(testsButton);


        buttonsLayout->addLayout(horizontalLayout);

        buttonsSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        buttonsLayout->addItem(buttonsSpacer);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        exportReview = new QToolButton(EditPatch);
        exportReview->setObjectName("exportReview");
        exportReview->setPopupMode(QToolButton::InstantPopup);
        exportReview->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("document-share")));
        exportReview->setIcon(icon6);

        horizontalLayout_3->addWidget(exportReview);

        cancelReview = new QToolButton(EditPatch);
        cancelReview->setObjectName("cancelReview");
        cancelReview->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("dialog-cancel")));
        cancelReview->setIcon(icon7);

        horizontalLayout_3->addWidget(cancelReview);

        finishReview = new QToolButton(EditPatch);
        finishReview->setObjectName("finishReview");
        finishReview->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
        finishReview->setAutoRaise(false);

        horizontalLayout_3->addWidget(finishReview);


        buttonsLayout->addLayout(horizontalLayout_3);


        verticalLayout_2->addLayout(buttonsLayout);

        contentLayout = new QHBoxLayout();
        contentLayout->setObjectName("contentLayout");
        filesGroup = new QGroupBox(EditPatch);
        filesGroup->setObjectName("filesGroup");
        horizontalLayout_2 = new QHBoxLayout(filesGroup);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        testProgressBar = new QProgressBar(filesGroup);
        testProgressBar->setObjectName("testProgressBar");
        testProgressBar->setValue(0);

        verticalLayout->addWidget(testProgressBar);

        filesList = new QTreeView(filesGroup);
        filesList->setObjectName("filesList");
        filesList->setEditTriggers(QAbstractItemView::NoEditTriggers);
        filesList->setUniformRowHeights(true);

        verticalLayout->addWidget(filesList);


        horizontalLayout_2->addLayout(verticalLayout);


        contentLayout->addWidget(filesGroup);


        verticalLayout_2->addLayout(contentLayout);


        retranslateUi(EditPatch);

        QMetaObject::connectSlotsByName(EditPatch);
    } // setupUi

    void retranslateUi(QWidget *EditPatch)
    {
#if QT_CONFIG(tooltip)
        previousFile->setToolTip(tr2i18n("Previous file", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        previousHunk->setToolTip(tr2i18n("Previous difference", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        nextHunk->setToolTip(tr2i18n("Next difference", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        nextFile->setToolTip(tr2i18n("Next file", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        updateButton->setText(tr2i18n("Update", "@action:button"));
        testsButton->setText(tr2i18n("Run Tests", "@action:button"));
        exportReview->setText(tr2i18n("Export Diff...", "@action:button"));
        cancelReview->setText(tr2i18n("Cancel Review", "@action:button"));
        finishReview->setText(tr2i18n("Finish Review", "@action:button"));
        filesGroup->setTitle(tr2i18n("Changes", "@title:group"));
        (void)EditPatch;
    } // retranslateUi

};

namespace Ui {
    class EditPatch: public Ui_EditPatch {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PATCHREVIEW_H

