/********************************************************************************
** Form generated from reading UI file 'quickopenwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QUICKOPENWIDGET_H
#define UI_QUICKOPENWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "expandingtree/expandingtree.h"

QT_BEGIN_NAMESPACE

class Ui_QuickOpenWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *searchLabel;
    QLineEdit *searchLine;
    QPushButton *okButton;
    QPushButton *cancelButton;
    ExpandingTree *list;
    QFormLayout *formLayout;
    QLabel *label;
    QPushButton *scopesButton;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_2;
    QPushButton *itemsButton;

    void setupUi(QWidget *QuickOpenWidget)
    {
        if (QuickOpenWidget->objectName().isEmpty())
            QuickOpenWidget->setObjectName("QuickOpenWidget");
        QuickOpenWidget->resize(476, 381);
        gridLayout = new QGridLayout(QuickOpenWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(2, 2, 2, 2);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, -1, 0, -1);
        searchLabel = new QLabel(QuickOpenWidget);
        searchLabel->setObjectName("searchLabel");
        searchLabel->setMargin(2);

        horizontalLayout->addWidget(searchLabel);

        searchLine = new QLineEdit(QuickOpenWidget);
        searchLine->setObjectName("searchLine");

        horizontalLayout->addWidget(searchLine);

        okButton = new QPushButton(QuickOpenWidget);
        okButton->setObjectName("okButton");

        horizontalLayout->addWidget(okButton);

        cancelButton = new QPushButton(QuickOpenWidget);
        cancelButton->setObjectName("cancelButton");

        horizontalLayout->addWidget(cancelButton);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        list = new ExpandingTree(QuickOpenWidget);
        list->setObjectName("list");
        list->setFocusPolicy(Qt::NoFocus);
        list->setFrameShape(QFrame::NoFrame);
        list->setFrameShadow(QFrame::Plain);

        gridLayout->addWidget(list, 1, 0, 1, 1);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(QuickOpenWidget);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setMargin(2);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        scopesButton = new QPushButton(QuickOpenWidget);
        scopesButton->setObjectName("scopesButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(scopesButton->sizePolicy().hasHeightForWidth());
        scopesButton->setSizePolicy(sizePolicy1);
        scopesButton->setAutoDefault(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, scopesButton);


        gridLayout->addLayout(formLayout, 2, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, -1, 0, -1);
        label_2 = new QLabel(QuickOpenWidget);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);
        label_2->setMargin(2);

        horizontalLayout_3->addWidget(label_2);

        itemsButton = new QPushButton(QuickOpenWidget);
        itemsButton->setObjectName("itemsButton");
        sizePolicy1.setHeightForWidth(itemsButton->sizePolicy().hasHeightForWidth());
        itemsButton->setSizePolicy(sizePolicy1);
        itemsButton->setAutoDefault(false);

        horizontalLayout_3->addWidget(itemsButton);


        gridLayout->addLayout(horizontalLayout_3, 3, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(scopesButton);
        label_2->setBuddy(itemsButton);
#endif // QT_CONFIG(shortcut)

        retranslateUi(QuickOpenWidget);

        QMetaObject::connectSlotsByName(QuickOpenWidget);
    } // setupUi

    void retranslateUi(QWidget *QuickOpenWidget)
    {
        searchLabel->setText(tr2i18n("Search:", "@label:textbox"));
        searchLine->setPlaceholderText(tr2i18n("Quick Open...", "@info:placeholder"));
        okButton->setText(tr2i18n("Open", "@action:button"));
        cancelButton->setText(tr2i18n("Cancel", "@action:button"));
        label->setText(tr2i18n("&Scopes:", "@label:listbox"));
        scopesButton->setText(QString());
        label_2->setText(tr2i18n("&Items:", "@label:listbox"));
        itemsButton->setText(QString());
        (void)QuickOpenWidget;
    } // retranslateUi

};

namespace Ui {
    class QuickOpenWidget: public Ui_QuickOpenWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QUICKOPENWIDGET_H

