/********************************************************************************
** Form generated from reading UI file 'parserwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PARSERWIDGET_H
#define UI_PARSERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ParserWidget
{
public:
    QGridLayout *gridLayout;
    QCheckBox *parseHeadersInPlainC;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label_2;
    QComboBox *languageStandardsCpp;
    QLabel *argumentsLabel;
    QLineEdit *parserOptionsCpp;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_3;
    QComboBox *languageStandardsC;
    QLabel *argumentsLabel_2;
    QLineEdit *parserOptionsC;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_4;
    QComboBox *languageStandardsOpenCl;
    QLabel *argumentsLabel_3;
    QLineEdit *parserOptionsOpenCl;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_5;
    QComboBox *languageStandardsCuda;
    QLabel *argumentsLabel_4;
    QLineEdit *parserOptionsCuda;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ParserWidget)
    {
        if (ParserWidget->objectName().isEmpty())
            ParserWidget->setObjectName("ParserWidget");
        ParserWidget->resize(579, 407);
        gridLayout = new QGridLayout(ParserWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        parseHeadersInPlainC = new QCheckBox(ParserWidget);
        parseHeadersInPlainC->setObjectName("parseHeadersInPlainC");

        gridLayout->addWidget(parseHeadersInPlainC, 1, 0, 1, 1);

        groupBox = new QGroupBox(ParserWidget);
        groupBox->setObjectName("groupBox");
        groupBox->setTitle(QString::fromUtf8(""));
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        languageStandardsCpp = new QComboBox(groupBox);
        languageStandardsCpp->addItem(QString());
        languageStandardsCpp->addItem(QString::fromUtf8("c++03"));
        languageStandardsCpp->addItem(QString::fromUtf8("c++11"));
        languageStandardsCpp->addItem(QString::fromUtf8("c++14"));
        languageStandardsCpp->addItem(QString::fromUtf8("c++17"));
        languageStandardsCpp->addItem(QString::fromUtf8("c++20"));
        languageStandardsCpp->addItem(QString::fromUtf8("c++23"));
        languageStandardsCpp->addItem(QString::fromUtf8("c++2c"));
        languageStandardsCpp->setObjectName("languageStandardsCpp");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(languageStandardsCpp->sizePolicy().hasHeightForWidth());
        languageStandardsCpp->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, languageStandardsCpp);

        argumentsLabel = new QLabel(groupBox);
        argumentsLabel->setObjectName("argumentsLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, argumentsLabel);

        parserOptionsCpp = new QLineEdit(groupBox);
        parserOptionsCpp->setObjectName("parserOptionsCpp");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, parserOptionsCpp);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(2, QFormLayout::ItemRole::LabelRole, verticalSpacer_2);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        languageStandardsC = new QComboBox(groupBox);
        languageStandardsC->addItem(QString());
        languageStandardsC->addItem(QString::fromUtf8("c89"));
        languageStandardsC->addItem(QString::fromUtf8("gnu89"));
        languageStandardsC->addItem(QString::fromUtf8("c99"));
        languageStandardsC->addItem(QString::fromUtf8("gnu99"));
        languageStandardsC->addItem(QString::fromUtf8("c11"));
        languageStandardsC->addItem(QString::fromUtf8("gnu11"));
        languageStandardsC->addItem(QString::fromUtf8("c17"));
        languageStandardsC->addItem(QString::fromUtf8("gnu17"));
        languageStandardsC->addItem(QString::fromUtf8("c23"));
        languageStandardsC->addItem(QString::fromUtf8("gnu23"));
        languageStandardsC->addItem(QString::fromUtf8("c2y"));
        languageStandardsC->addItem(QString::fromUtf8("gnu2y"));
        languageStandardsC->setObjectName("languageStandardsC");
        sizePolicy.setHeightForWidth(languageStandardsC->sizePolicy().hasHeightForWidth());
        languageStandardsC->setSizePolicy(sizePolicy);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, languageStandardsC);

        argumentsLabel_2 = new QLabel(groupBox);
        argumentsLabel_2->setObjectName("argumentsLabel_2");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, argumentsLabel_2);

        parserOptionsC = new QLineEdit(groupBox);
        parserOptionsC->setObjectName("parserOptionsC");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, parserOptionsC);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(5, QFormLayout::ItemRole::LabelRole, verticalSpacer_3);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_4);

        languageStandardsOpenCl = new QComboBox(groupBox);
        languageStandardsOpenCl->addItem(QString());
        languageStandardsOpenCl->addItem(QString::fromUtf8("CL1.1"));
        languageStandardsOpenCl->addItem(QString::fromUtf8("CL1.2"));
        languageStandardsOpenCl->addItem(QString::fromUtf8("CL2.0"));
        languageStandardsOpenCl->setObjectName("languageStandardsOpenCl");
        sizePolicy.setHeightForWidth(languageStandardsOpenCl->sizePolicy().hasHeightForWidth());
        languageStandardsOpenCl->setSizePolicy(sizePolicy);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, languageStandardsOpenCl);

        argumentsLabel_3 = new QLabel(groupBox);
        argumentsLabel_3->setObjectName("argumentsLabel_3");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, argumentsLabel_3);

        parserOptionsOpenCl = new QLineEdit(groupBox);
        parserOptionsOpenCl->setObjectName("parserOptionsOpenCl");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, parserOptionsOpenCl);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(8, QFormLayout::ItemRole::LabelRole, verticalSpacer_4);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label_5);

        languageStandardsCuda = new QComboBox(groupBox);
        languageStandardsCuda->addItem(QString());
        languageStandardsCuda->addItem(QString::fromUtf8("c++03"));
        languageStandardsCuda->addItem(QString::fromUtf8("c++11"));
        languageStandardsCuda->addItem(QString::fromUtf8("c++14"));
        languageStandardsCuda->addItem(QString::fromUtf8("c++17"));
        languageStandardsCuda->addItem(QString::fromUtf8("c++20"));
        languageStandardsCuda->addItem(QString::fromUtf8("c99"));
        languageStandardsCuda->setObjectName("languageStandardsCuda");
        sizePolicy.setHeightForWidth(languageStandardsCuda->sizePolicy().hasHeightForWidth());
        languageStandardsCuda->setSizePolicy(sizePolicy);

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, languageStandardsCuda);

        argumentsLabel_4 = new QLabel(groupBox);
        argumentsLabel_4->setObjectName("argumentsLabel_4");

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, argumentsLabel_4);

        parserOptionsCuda = new QLineEdit(groupBox);
        parserOptionsCuda->setObjectName("parserOptionsCuda");

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, parserOptionsCuda);


        gridLayout->addWidget(groupBox, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 406, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(languageStandardsCpp);
        argumentsLabel->setBuddy(parserOptionsCpp);
        label_3->setBuddy(languageStandardsC);
        argumentsLabel_2->setBuddy(parserOptionsC);
        label_4->setBuddy(languageStandardsOpenCl);
        argumentsLabel_3->setBuddy(parserOptionsOpenCl);
        label_5->setBuddy(languageStandardsCuda);
        argumentsLabel_4->setBuddy(parserOptionsCuda);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ParserWidget);

        QMetaObject::connectSlotsByName(ParserWidget);
    } // setupUi

    void retranslateUi(QWidget *ParserWidget)
    {
#if QT_CONFIG(tooltip)
        parseHeadersInPlainC->setToolTip(tr2i18n("<html><head/><body><p>Check this if you want <code>*.h</code> headers to be parsed in plain C mode. By default they are parsed as C++ headers.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        parseHeadersInPlainC->setText(tr2i18n("Parse *.h headers in plain C", "@option:check"));
        label_2->setText(tr2i18n("C++ profi&le:", "@label:listbox"));
        languageStandardsCpp->setItemText(0, tr2i18n("Custom", "@item:inlistbox language standard"));

#if QT_CONFIG(tooltip)
        languageStandardsCpp->setToolTip(tr2i18n("<html><head/><body><p>Choose language profile. </p><p>Use &quot;Custom&quot; profile to modify parser command-line arguments</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        argumentsLabel->setText(tr2i18n("C++ co&mmand-line arguments:", "@label:textbox"));
        label_3->setText(tr2i18n("C profi&le:", "@label:listbox"));
        languageStandardsC->setItemText(0, tr2i18n("Custom", "@item:inlistbox language standard"));

#if QT_CONFIG(tooltip)
        languageStandardsC->setToolTip(tr2i18n("<html><head/><body><p>Choose language profile. </p><p>Use &quot;Custom&quot; profile to modify parser command-line arguments</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        argumentsLabel_2->setText(tr2i18n("C co&mmand-line arguments:", "@label:textbox"));
        label_4->setText(tr2i18n("OpenCL C &profile:", "@label:listbox"));
        languageStandardsOpenCl->setItemText(0, tr2i18n("Custom", "@item:inlistbox language standard"));

#if QT_CONFIG(tooltip)
        languageStandardsOpenCl->setToolTip(tr2i18n("<html><head/><body><p>Choose language profile. </p><p>Use &quot;Custom&quot; profile to modify parser command-line arguments</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        argumentsLabel_3->setText(tr2i18n("OpenCL C comma&nd-line arguments:", "@label:textbox"));
        label_5->setText(tr2i18n("CUDA C P&rofile:", "@label:listbox"));
        languageStandardsCuda->setItemText(0, tr2i18n("Custom", "@item:inlistbox language standard"));

#if QT_CONFIG(tooltip)
        languageStandardsCuda->setToolTip(tr2i18n("<html><head/><body><p>Choose language profile. </p><p>Use &quot;Custom&quot; profile to modify parser command-line arguments</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        argumentsLabel_4->setText(tr2i18n("CUDA C comman&d-line arguments:", "@label:textbox"));
        (void)ParserWidget;
    } // retranslateUi

};

namespace Ui {
    class ParserWidget: public Ui_ParserWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PARSERWIDGET_H

