// This file is generated by kconfig_compiler_kf6 from uiconfig.kcfg.
// All changes you do to this file will be lost.

#include "uiconfig.h"

#include <qglobal.h>
#include <QFile>

class UiConfigHelper
{
  public:
    UiConfigHelper() noexcept : q(nullptr) {}
    ~UiConfigHelper() noexcept { delete q; q = nullptr; }
    UiConfigHelper(const UiConfigHelper&) = delete;
    UiConfigHelper& operator=(const UiConfigHelper&) = delete;
    UiConfig *q;
};
Q_GLOBAL_STATIC(UiConfigHelper, s_globalUiConfig)
UiConfig *UiConfig::self()
{
  if (!s_globalUiConfig()->q) {
    new UiConfig;
    s_globalUiConfig()->q->read();
  }

  return s_globalUiConfig()->q;
}

UiConfig::UiConfig( )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalUiConfig()->q);
  s_globalUiConfig()->q = this;
  setCurrentGroup( QStringLiteral( "UiSettings" ) );

  mBottomLeftCornerOwnerItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "BottomLeftCornerOwner" ), mBottomLeftCornerOwner );
  mBottomLeftCornerOwnerItem->setLabel( QCoreApplication::translate("UiConfig", "BottomLeftCornerOwner") );
  addItem( mBottomLeftCornerOwnerItem, QStringLiteral( "BottomLeftCornerOwner" ) );
  mBottomRightCornerOwnerItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "BottomRightCornerOwner" ), mBottomRightCornerOwner );
  mBottomRightCornerOwnerItem->setLabel( QCoreApplication::translate("UiConfig", "BottomRightCornerOwner") );
  addItem( mBottomRightCornerOwnerItem, QStringLiteral( "BottomRightCornerOwner" ) );
  mTabBarVisibilityItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TabBarVisibility" ), mTabBarVisibility, 1 );
  mTabBarVisibilityItem->setLabel( QCoreApplication::translate("UiConfig", "TabBarVisibility") );
  addItem( mTabBarVisibilityItem, QStringLiteral( "TabBarVisibility" ) );
  mCloseButtonsOnTabsItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "CloseButtonsOnTabs" ), mCloseButtonsOnTabs, 1 );
  mCloseButtonsOnTabsItem->setLabel( QCoreApplication::translate("UiConfig", "CloseButtonsOnTabs") );
  addItem( mCloseButtonsOnTabsItem, QStringLiteral( "CloseButtonsOnTabs" ) );
  mTabBarOpenAfterCurrentItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TabBarOpenAfterCurrent" ), mTabBarOpenAfterCurrent, 1 );
  mTabBarOpenAfterCurrentItem->setLabel( QCoreApplication::translate("UiConfig", "TabBarOpenAfterCurrent") );
  addItem( mTabBarOpenAfterCurrentItem, QStringLiteral( "TabBarOpenAfterCurrent" ) );
  mTabBarArrangeBuddiesItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "TabBarArrangeBuddies" ), mTabBarArrangeBuddies, 1 );
  mTabBarArrangeBuddiesItem->setLabel( QCoreApplication::translate("UiConfig", "TabBarArrangeBuddies") );
  addItem( mTabBarArrangeBuddiesItem, QStringLiteral( "TabBarArrangeBuddies" ) );
  mColorizeByProjectItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ColorizeByProject" ), mColorizeByProject, true );
  mColorizeByProjectItem->setLabel( QCoreApplication::translate("UiConfig", "ColorizeByProject") );
  addItem( mColorizeByProjectItem, QStringLiteral( "ColorizeByProject" ) );
}

UiConfig::~UiConfig()
{
  if (s_globalUiConfig.exists() && !s_globalUiConfig.isDestroyed()) {
    s_globalUiConfig()->q = nullptr;
  }
}

