/****************************************************************************
** Meta object code from reading C++ file 'projectmanagerviewplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/plugins/projectmanagerview/projectmanagerviewplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projectmanagerviewplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24ProjectManagerViewPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto ProjectManagerViewPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN24ProjectManagerViewPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProjectManagerViewPlugin",
        "buildProjectItems",
        "",
        "installProjectItems",
        "cleanProjectItems",
        "copyFromContextMenu",
        "pasteFromContextMenu",
        "closeProjects",
        "buildItemsFromContextMenu",
        "installItemsFromContextMenu",
        "cleanItemsFromContextMenu",
        "configureProjectItems",
        "pruneProjectItems",
        "buildAllProjects",
        "addItemsFromContextMenuToBuildset",
        "projectConfiguration",
        "runTargetsFromContextMenu",
        "reloadFromContextMenu",
        "createFolderFromContextMenu",
        "createFileFromContextMenu",
        "removeFromContextMenu",
        "cutFromContextMenu",
        "removeTargetFilesFromContextMenu",
        "renameItemFromContextMenu",
        "updateActionState",
        "KDevelop::Context*",
        "ctx",
        "updateFromBuildSetChange"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'buildProjectItems'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'installProjectItems'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanProjectItems'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyFromContextMenu'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pasteFromContextMenu'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeProjects'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'buildItemsFromContextMenu'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'installItemsFromContextMenu'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'cleanItemsFromContextMenu'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'configureProjectItems'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'pruneProjectItems'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'buildAllProjects'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'addItemsFromContextMenuToBuildset'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'projectConfiguration'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'runTargetsFromContextMenu'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'reloadFromContextMenu'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'createFolderFromContextMenu'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'createFileFromContextMenu'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'removeFromContextMenu'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'cutFromContextMenu'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'removeTargetFilesFromContextMenu'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'renameItemFromContextMenu'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateActionState'
        QtMocHelpers::SlotData<void(KDevelop::Context *)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'updateFromBuildSetChange'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectManagerViewPlugin, qt_meta_tag_ZN24ProjectManagerViewPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProjectManagerViewPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProjectManagerViewPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProjectManagerViewPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24ProjectManagerViewPluginE_t>.metaTypes,
    nullptr
} };

void ProjectManagerViewPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectManagerViewPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->buildProjectItems(); break;
        case 1: _t->installProjectItems(); break;
        case 2: _t->cleanProjectItems(); break;
        case 3: _t->copyFromContextMenu(); break;
        case 4: _t->pasteFromContextMenu(); break;
        case 5: _t->closeProjects(); break;
        case 6: _t->buildItemsFromContextMenu(); break;
        case 7: _t->installItemsFromContextMenu(); break;
        case 8: _t->cleanItemsFromContextMenu(); break;
        case 9: _t->configureProjectItems(); break;
        case 10: _t->pruneProjectItems(); break;
        case 11: _t->buildAllProjects(); break;
        case 12: _t->addItemsFromContextMenuToBuildset(); break;
        case 13: _t->projectConfiguration(); break;
        case 14: _t->runTargetsFromContextMenu(); break;
        case 15: _t->reloadFromContextMenu(); break;
        case 16: _t->createFolderFromContextMenu(); break;
        case 17: _t->createFileFromContextMenu(); break;
        case 18: _t->removeFromContextMenu(); break;
        case 19: _t->cutFromContextMenu(); break;
        case 20: _t->removeTargetFilesFromContextMenu(); break;
        case 21: _t->renameItemFromContextMenu(); break;
        case 22: _t->updateActionState((*reinterpret_cast<std::add_pointer_t<KDevelop::Context*>>(_a[1]))); break;
        case 23: _t->updateFromBuildSetChange(); break;
        default: ;
        }
    }
}

const QMetaObject *ProjectManagerViewPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProjectManagerViewPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProjectManagerViewPluginE_t>.strings))
        return static_cast<void*>(this);
    return KDevelop::IPlugin::qt_metacast(_clname);
}

int ProjectManagerViewPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}
QT_WARNING_POP
