/********************************************************************************
** Form generated from reading UI file 'sessionsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SESSIONSETTINGS_H
#define UI_SESSIONSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SessionSettings
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox_4;
    QGridLayout *gridLayout_4;
    QCheckBox *kcfg_macros;
    QCheckBox *kcfg_lookAhead;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_3;
    QCheckBox *kcfg_forwardDeclare;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SessionSettings)
    {
        if (SessionSettings->objectName().isEmpty())
            SessionSettings->setObjectName("SessionSettings");
        SessionSettings->resize(669, 489);
        gridLayout = new QGridLayout(SessionSettings);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        groupBox_4 = new QGroupBox(SessionSettings);
        groupBox_4->setObjectName("groupBox_4");
        gridLayout_4 = new QGridLayout(groupBox_4);
        gridLayout_4->setObjectName("gridLayout_4");
        kcfg_macros = new QCheckBox(groupBox_4);
        kcfg_macros->setObjectName("kcfg_macros");
        kcfg_macros->setChecked(true);

        gridLayout_4->addWidget(kcfg_macros, 0, 0, 1, 1);

        kcfg_lookAhead = new QCheckBox(groupBox_4);
        kcfg_lookAhead->setObjectName("kcfg_lookAhead");
        kcfg_lookAhead->setEnabled(true);
        kcfg_lookAhead->setChecked(false);

        gridLayout_4->addWidget(kcfg_lookAhead, 1, 0, 1, 1);


        gridLayout->addWidget(groupBox_4, 0, 0, 1, 1);

        groupBox_3 = new QGroupBox(SessionSettings);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_3 = new QGridLayout(groupBox_3);
        gridLayout_3->setObjectName("gridLayout_3");
        kcfg_forwardDeclare = new QCheckBox(groupBox_3);
        kcfg_forwardDeclare->setObjectName("kcfg_forwardDeclare");
        kcfg_forwardDeclare->setChecked(true);

        gridLayout_3->addWidget(kcfg_forwardDeclare, 0, 0, 1, 1);


        gridLayout->addWidget(groupBox_3, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);


        retranslateUi(SessionSettings);

        QMetaObject::connectSlotsByName(SessionSettings);
    } // setupUi

    void retranslateUi(QWidget *SessionSettings)
    {
        groupBox_4->setTitle(tr2i18n("Code Completion", "@title:group"));
#if QT_CONFIG(tooltip)
        kcfg_macros->setToolTip(tr2i18n("If disabled, macros will not be included in the code completion results. This can improve the responsiveness of code completion in some cases.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_macros->setText(tr2i18n("Add macros to code completion", "@option:check"));
        kcfg_lookAhead->setText(tr2i18n("Enable Look-ahead code completion", "@option:check"));
        groupBox_3->setTitle(tr2i18n("Assistants", "@title:group"));
        kcfg_forwardDeclare->setText(tr2i18n("Forward declare assistant", "@option:check"));
        (void)SessionSettings;
    } // retranslateUi

};

namespace Ui {
    class SessionSettings: public Ui_SessionSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SESSIONSETTINGS_H

