// This file is generated by kconfig_compiler_kf6 from dockerpreferencessettings.kcfg.
// All changes you do to this file will be lost.

#include "dockerpreferencessettings.h"

DockerPreferencesSettings::DockerPreferencesSettings( )
  : KConfigSkeleton()
{
  setCurrentGroup( QStringLiteral( "Docker" ) );

  KConfigSkeleton::ItemString  *itemExtraArguments;
  itemExtraArguments = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "extraArguments" ), mExtraArguments );
  addItem( itemExtraArguments, QStringLiteral( "extraArguments" ) );
  KConfigSkeleton::ItemString  *itemProjectsVolume;
  itemProjectsVolume = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "projectsVolume" ), mProjectsVolume, QStringLiteral( "/src" ) );
  addItem( itemProjectsVolume, QStringLiteral( "projectsVolume" ) );
  KConfigSkeleton::ItemString  *itemBuildDirsVolume;
  itemBuildDirsVolume = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "buildDirsVolume" ), mBuildDirsVolume, QStringLiteral( "/build" ) );
  addItem( itemBuildDirsVolume, QStringLiteral( "buildDirsVolume" ) );
}

DockerPreferencesSettings::~DockerPreferencesSettings()
{
}

