/****************************************************************************
** Meta object code from reading C++ file 'dbgglobal.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/plugins/debuggercommon/dbgglobal.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbgglobal.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KDevMIE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevMI::qt_create_metaobjectdata<qt_meta_tag_ZN6KDevMIE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevMI",
        "DBGStateFlag",
        "s_none",
        "s_dbgNotStarted",
        "s_appNotStarted",
        "s_programExited",
        "s_attached",
        "s_core",
        "s_shuttingDown",
        "s_dbgBusy",
        "s_appRunning",
        "s_dbgNotListening",
        "s_interruptSent",
        "s_userInterruptSent",
        "s_automaticContinue",
        "s_dbgFailedStart"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DBGStateFlag'
        QtMocHelpers::EnumData<DBGStateFlag>(1, 1, QMC::EnumFlags{}).add({
            {    2, DBGStateFlag::s_none },
            {    3, DBGStateFlag::s_dbgNotStarted },
            {    4, DBGStateFlag::s_appNotStarted },
            {    5, DBGStateFlag::s_programExited },
            {    6, DBGStateFlag::s_attached },
            {    7, DBGStateFlag::s_core },
            {    8, DBGStateFlag::s_shuttingDown },
            {    9, DBGStateFlag::s_dbgBusy },
            {   10, DBGStateFlag::s_appRunning },
            {   11, DBGStateFlag::s_dbgNotListening },
            {   12, DBGStateFlag::s_interruptSent },
            {   13, DBGStateFlag::s_userInterruptSent },
            {   14, DBGStateFlag::s_automaticContinue },
            {   15, DBGStateFlag::s_dbgFailedStart },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6KDevMIE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6KDevMIE =
    KDevMI::qt_create_metaobjectdata<qt_meta_tag_ZN6KDevMIE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6KDevMIE =
    qt_staticMetaObjectContent_ZN6KDevMIE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6KDevMIE =
    qt_staticMetaObjectContent_ZN6KDevMIE.relocatingData;

Q_CONSTINIT const QMetaObject KDevMI::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6KDevMIE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6KDevMIE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6KDevMIE.metaTypes,
    nullptr
} };

QT_WARNING_POP
