/********************************************************************************
** Form generated from reading UI file 'projectconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTCONFIGPAGE_H
#define UI_PROJECTCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "config/checksetselectioncombobox.h"
#include "config/checkswidget.h"
#include "config/commandlinewidget.h"
#include "config/customchecksetconfigproxywidget.h"

namespace Clazy {

class Ui_ProjectConfigPage
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *checksTab;
    QVBoxLayout *vboxLayout;
    Clazy::CheckSetSelectionComboBox *kcfg_checkSetSelection;
    Clazy::ChecksWidget *checks;
    Clazy::CustomCheckSetConfigProxyWidget *kcfg_checks;
    QWidget *optionsTab;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *commonBox;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_onlyQt;
    QCheckBox *kcfg_qt4Compat;
    QCheckBox *kcfg_qtDeveloper;
    QCheckBox *kcfg_visitImplicitCode;
    QGroupBox *headersBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_ignoreIncludedFiles;
    QHBoxLayout *horizontalLayout;
    QLabel *headerFilterLabel;
    QLineEdit *kcfg_headerFilter;
    QGroupBox *fixitsBox;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *fixitsHLayout;
    QCheckBox *kcfg_enableAllFixits;
    QCheckBox *kcfg_noInplaceFixits;
    KMessageWidget *kmessagewidget;
    QWidget *extraTab;
    QFormLayout *formLayout;
    QLabel *extraAppendLabel;
    QLineEdit *kcfg_extraAppend;
    QLabel *extraPrependLabel;
    QLineEdit *kcfg_extraPrepend;
    QLineEdit *kcfg_extraClazy;
    QLabel *extraClazyLabel;
    CommandLineWidget *commandLineWidget;
    KMessageWidget *dbError;

    void setupUi(QWidget *Clazy__ProjectConfigPage)
    {
        if (Clazy__ProjectConfigPage->objectName().isEmpty())
            Clazy__ProjectConfigPage->setObjectName("Clazy__ProjectConfigPage");
        Clazy__ProjectConfigPage->resize(723, 396);
        verticalLayout = new QVBoxLayout(Clazy__ProjectConfigPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(Clazy__ProjectConfigPage);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        checksTab = new QWidget();
        checksTab->setObjectName("checksTab");
        vboxLayout = new QVBoxLayout(checksTab);
        vboxLayout->setObjectName("vboxLayout");
        kcfg_checkSetSelection = new Clazy::CheckSetSelectionComboBox(checksTab);
        kcfg_checkSetSelection->setObjectName("kcfg_checkSetSelection");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_checkSetSelection->sizePolicy().hasHeightForWidth());
        kcfg_checkSetSelection->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(kcfg_checkSetSelection);

        checks = new Clazy::ChecksWidget(checksTab);
        checks->setObjectName("checks");

        vboxLayout->addWidget(checks);

        kcfg_checks = new Clazy::CustomCheckSetConfigProxyWidget(checksTab);
        kcfg_checks->setObjectName("kcfg_checks");
        kcfg_checks->setVisible(false);

        vboxLayout->addWidget(kcfg_checks);

        tabWidget->addTab(checksTab, QString());
        optionsTab = new QWidget();
        optionsTab->setObjectName("optionsTab");
        verticalLayout_4 = new QVBoxLayout(optionsTab);
        verticalLayout_4->setObjectName("verticalLayout_4");
        commonBox = new QGroupBox(optionsTab);
        commonBox->setObjectName("commonBox");
        commonBox->setTitle(QString::fromUtf8(""));
        gridLayout = new QGridLayout(commonBox);
        gridLayout->setObjectName("gridLayout");
        kcfg_onlyQt = new QCheckBox(commonBox);
        kcfg_onlyQt->setObjectName("kcfg_onlyQt");

        gridLayout->addWidget(kcfg_onlyQt, 0, 0, 1, 1);

        kcfg_qt4Compat = new QCheckBox(commonBox);
        kcfg_qt4Compat->setObjectName("kcfg_qt4Compat");

        gridLayout->addWidget(kcfg_qt4Compat, 0, 1, 1, 1);

        kcfg_qtDeveloper = new QCheckBox(commonBox);
        kcfg_qtDeveloper->setObjectName("kcfg_qtDeveloper");

        gridLayout->addWidget(kcfg_qtDeveloper, 1, 0, 1, 1);

        kcfg_visitImplicitCode = new QCheckBox(commonBox);
        kcfg_visitImplicitCode->setObjectName("kcfg_visitImplicitCode");

        gridLayout->addWidget(kcfg_visitImplicitCode, 1, 1, 1, 1);


        verticalLayout_4->addWidget(commonBox);

        headersBox = new QGroupBox(optionsTab);
        headersBox->setObjectName("headersBox");
        headersBox->setTitle(QString::fromUtf8(""));
        verticalLayout_2 = new QVBoxLayout(headersBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_ignoreIncludedFiles = new QCheckBox(headersBox);
        kcfg_ignoreIncludedFiles->setObjectName("kcfg_ignoreIncludedFiles");

        verticalLayout_2->addWidget(kcfg_ignoreIncludedFiles);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        headerFilterLabel = new QLabel(headersBox);
        headerFilterLabel->setObjectName("headerFilterLabel");

        horizontalLayout->addWidget(headerFilterLabel);

        kcfg_headerFilter = new QLineEdit(headersBox);
        kcfg_headerFilter->setObjectName("kcfg_headerFilter");
        kcfg_headerFilter->setClearButtonEnabled(true);

        horizontalLayout->addWidget(kcfg_headerFilter);


        verticalLayout_2->addLayout(horizontalLayout);


        verticalLayout_4->addWidget(headersBox);

        fixitsBox = new QGroupBox(optionsTab);
        fixitsBox->setObjectName("fixitsBox");
        fixitsBox->setTitle(QString::fromUtf8(""));
        verticalLayout_3 = new QVBoxLayout(fixitsBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        fixitsHLayout = new QHBoxLayout();
        fixitsHLayout->setObjectName("fixitsHLayout");
        kcfg_enableAllFixits = new QCheckBox(fixitsBox);
        kcfg_enableAllFixits->setObjectName("kcfg_enableAllFixits");

        fixitsHLayout->addWidget(kcfg_enableAllFixits);

        kcfg_noInplaceFixits = new QCheckBox(fixitsBox);
        kcfg_noInplaceFixits->setObjectName("kcfg_noInplaceFixits");

        fixitsHLayout->addWidget(kcfg_noInplaceFixits);


        verticalLayout_3->addLayout(fixitsHLayout);

        kmessagewidget = new KMessageWidget(fixitsBox);
        kmessagewidget->setObjectName("kmessagewidget");
        kmessagewidget->setCloseButtonVisible(false);
        kmessagewidget->setMessageType(KMessageWidget::Warning);

        verticalLayout_3->addWidget(kmessagewidget);


        verticalLayout_4->addWidget(fixitsBox);

        tabWidget->addTab(optionsTab, QString());
        extraTab = new QWidget();
        extraTab->setObjectName("extraTab");
        formLayout = new QFormLayout(extraTab);
        formLayout->setObjectName("formLayout");
        extraAppendLabel = new QLabel(extraTab);
        extraAppendLabel->setObjectName("extraAppendLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, extraAppendLabel);

        kcfg_extraAppend = new QLineEdit(extraTab);
        kcfg_extraAppend->setObjectName("kcfg_extraAppend");
        kcfg_extraAppend->setClearButtonEnabled(true);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_extraAppend);

        extraPrependLabel = new QLabel(extraTab);
        extraPrependLabel->setObjectName("extraPrependLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, extraPrependLabel);

        kcfg_extraPrepend = new QLineEdit(extraTab);
        kcfg_extraPrepend->setObjectName("kcfg_extraPrepend");
        kcfg_extraPrepend->setClearButtonEnabled(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_extraPrepend);

        kcfg_extraClazy = new QLineEdit(extraTab);
        kcfg_extraClazy->setObjectName("kcfg_extraClazy");
        kcfg_extraClazy->setClearButtonEnabled(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_extraClazy);

        extraClazyLabel = new QLabel(extraTab);
        extraClazyLabel->setObjectName("extraClazyLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, extraClazyLabel);

        tabWidget->addTab(extraTab, QString());

        verticalLayout->addWidget(tabWidget);

        commandLineWidget = new CommandLineWidget(Clazy__ProjectConfigPage);
        commandLineWidget->setObjectName("commandLineWidget");

        verticalLayout->addWidget(commandLineWidget);

        dbError = new KMessageWidget(Clazy__ProjectConfigPage);
        dbError->setObjectName("dbError");
        dbError->setText(QString::fromUtf8("dbError"));
        dbError->setWordWrap(true);
        dbError->setCloseButtonVisible(false);
        dbError->setMessageType(KMessageWidget::Error);

        verticalLayout->addWidget(dbError);


        retranslateUi(Clazy__ProjectConfigPage);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Clazy__ProjectConfigPage);
    } // setupUi

    void retranslateUi(QWidget *Clazy__ProjectConfigPage)
    {
        tabWidget->setTabText(tabWidget->indexOf(checksTab), tr2i18n("Checks", "@title:tab"));
#if QT_CONFIG(tooltip)
        kcfg_onlyQt->setToolTip(tr2i18n("Do not emit warnings for non-Qt files, or in other words, if -DQT_CORE_LIB is missing.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_onlyQt->setText(tr2i18n("Only Qt", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_qt4Compat->setToolTip(tr2i18n("Disable checks not compatible with Qt 4.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_qt4Compat->setText(tr2i18n("Qt4 compatible", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_qtDeveloper->setToolTip(tr2i18n("For running clazy on Qt itself, optional, but honors specific guidelines.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_qtDeveloper->setText(tr2i18n("Qt developer", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_visitImplicitCode->setToolTip(tr2i18n("For visiting implicit code like compiler generated constructors.\n"
"None of the built-in checks benefit from this, but can be useful for custom checks.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_visitImplicitCode->setText(tr2i18n("Visit implicit code", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_ignoreIncludedFiles->setToolTip(tr2i18n("Only emit warnings for the current file being compiled and ignore any includes.\n"
"Useful for performance reasons.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_ignoreIncludedFiles->setText(tr2i18n("Ignore included files", "@option:check"));
        headerFilterLabel->setText(tr2i18n("Header filter:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_headerFilter->setToolTip(tr2i18n("Regular expression matching the names of the headers to output diagnostics from.\n"
"Diagnostics from the main file of each translation unit are always displayed.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_enableAllFixits->setText(tr2i18n("Enable all fix-its", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_noInplaceFixits->setToolTip(tr2i18n("Fix-its will be applied to a separate file (for unit-test use only).", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_noInplaceFixits->setText(tr2i18n("No-inplace fix-its", "@option:check"));
        kmessagewidget->setText(tr2i18n("Please backup your code before fix-its applying. For better results also disable \n"
"parallel checking, which can lead to multiple fix-it applying for header files.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(optionsTab), tr2i18n("Options", "@title:tab"));
        extraAppendLabel->setText(tr2i18n("Compiler append:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_extraAppend->setToolTip(tr2i18n("Additional parameters to append to the compiler command line.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        extraPrependLabel->setText(tr2i18n("Compiler prepend:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_extraPrepend->setToolTip(tr2i18n("Additional parameters to prepend to the compiler command line.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_extraClazy->setToolTip(tr2i18n("Additional parameters to clazy-standalone.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        extraClazyLabel->setText(tr2i18n("Extra parameters:", "@label:textbox"));
        tabWidget->setTabText(tabWidget->indexOf(extraTab), tr2i18n("Extra Parameters", "@title:tab"));
        (void)Clazy__ProjectConfigPage;
    } // retranslateUi

};

} // namespace Clazy

namespace Clazy {
namespace Ui {
    class ProjectConfigPage: public Ui_ProjectConfigPage {};
} // namespace Ui
} // namespace Clazy

#endif // PROJECTCONFIGPAGE_H

