/********************************************************************************
** Form generated from reading UI file 'includeswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INCLUDESWIDGET_H
#define UI_INCLUDESWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_IncludesWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    KUrlRequester *includePathRequester;
    QPushButton *addIncludePath;
    QPushButton *removeIncludePath;
    QListView *includePaths;
    KMessageWidget *errorWidget;

    void setupUi(QWidget *IncludesWidget)
    {
        if (IncludesWidget->objectName().isEmpty())
            IncludesWidget->setObjectName("IncludesWidget");
        IncludesWidget->resize(545, 298);
        verticalLayout = new QVBoxLayout(IncludesWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        includePathRequester = new KUrlRequester(IncludesWidget);
        includePathRequester->setObjectName("includePathRequester");

        horizontalLayout->addWidget(includePathRequester);

        addIncludePath = new QPushButton(IncludesWidget);
        addIncludePath->setObjectName("addIncludePath");
        addIncludePath->setEnabled(true);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addIncludePath->setIcon(icon);

        horizontalLayout->addWidget(addIncludePath);

        removeIncludePath = new QPushButton(IncludesWidget);
        removeIncludePath->setObjectName("removeIncludePath");
        removeIncludePath->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        removeIncludePath->setIcon(icon1);

        horizontalLayout->addWidget(removeIncludePath);


        verticalLayout->addLayout(horizontalLayout);

        includePaths = new QListView(IncludesWidget);
        includePaths->setObjectName("includePaths");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(8);
        sizePolicy.setHeightForWidth(includePaths->sizePolicy().hasHeightForWidth());
        includePaths->setSizePolicy(sizePolicy);
        includePaths->setSelectionBehavior(QAbstractItemView::SelectRows);

        verticalLayout->addWidget(includePaths);

        errorWidget = new KMessageWidget(IncludesWidget);
        errorWidget->setObjectName("errorWidget");

        verticalLayout->addWidget(errorWidget);


        retranslateUi(IncludesWidget);

        QMetaObject::connectSlotsByName(IncludesWidget);
    } // setupUi

    void retranslateUi(QWidget *IncludesWidget)
    {
#if QT_CONFIG(tooltip)
        includePathRequester->setToolTip(tr2i18n("Add the currently displayed URL to the list of includes if it is not in the list yet.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        includePathRequester->setPlaceholderText(tr2i18n("A new include path/file to use for parsing files under given directory", "@info:placeholder"));
#if QT_CONFIG(tooltip)
        addIncludePath->setToolTip(tr2i18n("Create a new include path entry from this URL", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        addIncludePath->setText(QString());
#if QT_CONFIG(tooltip)
        removeIncludePath->setToolTip(tr2i18n("Delete current include path entry", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        removeIncludePath->setText(QString());
        (void)IncludesWidget;
    } // retranslateUi

};

namespace Ui {
    class IncludesWidget: public Ui_IncludesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INCLUDESWIDGET_H

