/********************************************************************************
** Form generated from reading UI file 'importmetadatawidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTMETADATAWIDGET_H
#define UI_IMPORTMETADATAWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KTextEdit"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_SvnImportMetadataWidget
{
public:
    QFormLayout *formLayout;
    QLabel *labelForSrc;
    QLabel *label_2;
    QLineEdit *dest;
    KUrlRequester *srcEdit;
    KTextEdit *message;
    QLabel *label;

    void setupUi(QWidget *SvnImportMetadataWidget)
    {
        if (SvnImportMetadataWidget->objectName().isEmpty())
            SvnImportMetadataWidget->setObjectName("SvnImportMetadataWidget");
        SvnImportMetadataWidget->resize(549, 280);
        formLayout = new QFormLayout(SvnImportMetadataWidget);
        formLayout->setContentsMargins(0, 0, 0, 0);
        formLayout->setObjectName("formLayout");
        labelForSrc = new QLabel(SvnImportMetadataWidget);
        labelForSrc->setObjectName("labelForSrc");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelForSrc);

        label_2 = new QLabel(SvnImportMetadataWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        dest = new QLineEdit(SvnImportMetadataWidget);
        dest->setObjectName("dest");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, dest);

        srcEdit = new KUrlRequester(SvnImportMetadataWidget);
        srcEdit->setObjectName("srcEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, srcEdit);

        message = new KTextEdit(SvnImportMetadataWidget);
        message->setObjectName("message");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(message->sizePolicy().hasHeightForWidth());
        message->setSizePolicy(sizePolicy);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, message);

        label = new QLabel(SvnImportMetadataWidget);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);


        retranslateUi(SvnImportMetadataWidget);

        QMetaObject::connectSlotsByName(SvnImportMetadataWidget);
    } // setupUi

    void retranslateUi(QWidget *SvnImportMetadataWidget)
    {
        labelForSrc->setText(tr2i18n("Source directory:", "@label:textbox"));
        label_2->setText(tr2i18n("Repository:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        dest->setToolTip(tr2i18n("Repository location", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        dest->setWhatsThis(tr2i18n("Choose the repository into which the source directory is imported", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Commit message:", "@label:textbox"));
        (void)SvnImportMetadataWidget;
    } // retranslateUi

};

namespace Ui {
    class SvnImportMetadataWidget: public Ui_SvnImportMetadataWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTMETADATAWIDGET_H

