// This file is generated by kconfig_compiler_kf6 from kcfg_custombuildsystemconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef CUSTOMBUILDSYSTEMSETTINGS_H
#define CUSTOMBUILDSYSTEMSETTINGS_H

#include <project/projectconfigskeleton.h>

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class CustomBuildSystemSettings : public KDevelop::ProjectConfigSkeleton
{
  public:
    static CustomBuildSystemSettings *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~CustomBuildSystemSettings() override;

  protected:
    CustomBuildSystemSettings(KSharedConfig::Ptr config);
    friend class CustomBuildSystemSettingsHelper;

};

#endif

