/********************************************************************************
** Form generated from reading UI file 'languagepreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LANGUAGEPREFERENCES_H
#define UI_LANGUAGEPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_LanguagePreferences
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QFormLayout *formLayout_2;
    QLabel *label_6;
    QCheckBox *kcfg_automaticInvocation;
    QLabel *label_7;
    QCheckBox *kcfg_showMultiLineSelectionInformation;
    QLabel *label;
    QComboBox *kcfg_completionDetail;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QLabel *localColorizationLabel;
    QSlider *kcfg_localColorization;
    QComboBox *kcfg_globalColorSource;
    QLabel *label_9;
    QSlider *kcfg_globalColorization;
    QLabel *globalColorizationLabel;
    QLabel *label_4;
    QCheckBox *kcfg_highlightSemanticProblems;
    QLabel *label_5;
    QCheckBox *kcfg_highlightProblematicLines;
    QLabel *boldDeclarationsLabel;
    QCheckBox *kcfg_boldDeclarations;
    QLabel *label_8;
    QComboBox *kcfg_problemInlineNotesLevel;
    QLabel *label_3;
    QLineEdit *kcfg_todoMarkerWords;
    QGroupBox *groupBox_3;
    QFormLayout *formLayout_3;
    QLabel *label_2;
    KPluralHandlingSpinBox *kcfg_minFilesForSimplifiedParsing;
    QGroupBox *groupBox_4;
    QFormLayout *formLayout_4;
    QLabel *label_precompiledPreambleStorage;
    QComboBox *kcfg_precompiledPreambleStorage;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *LanguagePreferences)
    {
        if (LanguagePreferences->objectName().isEmpty())
            LanguagePreferences->setObjectName("LanguagePreferences");
        LanguagePreferences->resize(599, 709);
        verticalLayout_2 = new QVBoxLayout(LanguagePreferences);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(LanguagePreferences);
        groupBox->setObjectName("groupBox");
        formLayout_2 = new QFormLayout(groupBox);
        formLayout_2->setObjectName("formLayout_2");
        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_6);

        kcfg_automaticInvocation = new QCheckBox(groupBox);
        kcfg_automaticInvocation->setObjectName("kcfg_automaticInvocation");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_automaticInvocation);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_7);

        kcfg_showMultiLineSelectionInformation = new QCheckBox(groupBox);
        kcfg_showMultiLineSelectionInformation->setObjectName("kcfg_showMultiLineSelectionInformation");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_showMultiLineSelectionInformation);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        kcfg_completionDetail = new QComboBox(groupBox);
        kcfg_completionDetail->addItem(QString());
        kcfg_completionDetail->addItem(QString());
        kcfg_completionDetail->addItem(QString());
        kcfg_completionDetail->setObjectName("kcfg_completionDetail");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_completionDetail);


        verticalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(LanguagePreferences);
        groupBox_2->setObjectName("groupBox_2");
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        localColorizationLabel = new QLabel(groupBox_2);
        localColorizationLabel->setObjectName("localColorizationLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, localColorizationLabel);

        kcfg_localColorization = new QSlider(groupBox_2);
        kcfg_localColorization->setObjectName("kcfg_localColorization");
        kcfg_localColorization->setMaximum(255);
        kcfg_localColorization->setSingleStep(3);
        kcfg_localColorization->setPageStep(25);
        kcfg_localColorization->setValue(170);
        kcfg_localColorization->setOrientation(Qt::Horizontal);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_localColorization);

        kcfg_globalColorSource = new QComboBox(groupBox_2);
        kcfg_globalColorSource->addItem(QString());
        kcfg_globalColorSource->addItem(QString());
        kcfg_globalColorSource->setObjectName("kcfg_globalColorSource");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_globalColorSource);

        label_9 = new QLabel(groupBox_2);
        label_9->setObjectName("label_9");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_9);

        kcfg_globalColorization = new QSlider(groupBox_2);
        kcfg_globalColorization->setObjectName("kcfg_globalColorization");
        kcfg_globalColorization->setMaximum(255);
        kcfg_globalColorization->setSingleStep(3);
        kcfg_globalColorization->setPageStep(25);
        kcfg_globalColorization->setValue(255);
        kcfg_globalColorization->setOrientation(Qt::Horizontal);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_globalColorization);

        globalColorizationLabel = new QLabel(groupBox_2);
        globalColorizationLabel->setObjectName("globalColorizationLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, globalColorizationLabel);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        kcfg_highlightSemanticProblems = new QCheckBox(groupBox_2);
        kcfg_highlightSemanticProblems->setObjectName("kcfg_highlightSemanticProblems");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_highlightSemanticProblems);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_highlightProblematicLines = new QCheckBox(groupBox_2);
        kcfg_highlightProblematicLines->setObjectName("kcfg_highlightProblematicLines");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_highlightProblematicLines);

        boldDeclarationsLabel = new QLabel(groupBox_2);
        boldDeclarationsLabel->setObjectName("boldDeclarationsLabel");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, boldDeclarationsLabel);

        kcfg_boldDeclarations = new QCheckBox(groupBox_2);
        kcfg_boldDeclarations->setObjectName("kcfg_boldDeclarations");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_boldDeclarations);

        label_8 = new QLabel(groupBox_2);
        label_8->setObjectName("label_8");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_8);

        kcfg_problemInlineNotesLevel = new QComboBox(groupBox_2);
        kcfg_problemInlineNotesLevel->addItem(QString());
        kcfg_problemInlineNotesLevel->addItem(QString());
        kcfg_problemInlineNotesLevel->addItem(QString());
        kcfg_problemInlineNotesLevel->addItem(QString());
        kcfg_problemInlineNotesLevel->setObjectName("kcfg_problemInlineNotesLevel");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, kcfg_problemInlineNotesLevel);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_todoMarkerWords = new QLineEdit(groupBox_2);
        kcfg_todoMarkerWords->setObjectName("kcfg_todoMarkerWords");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, kcfg_todoMarkerWords);

        kcfg_problemInlineNotesLevel->raise();
        kcfg_localColorization->raise();
        label_4->raise();
        kcfg_highlightSemanticProblems->raise();
        label_5->raise();
        kcfg_highlightProblematicLines->raise();
        label_3->raise();
        kcfg_todoMarkerWords->raise();
        kcfg_globalColorization->raise();
        globalColorizationLabel->raise();
        localColorizationLabel->raise();
        boldDeclarationsLabel->raise();
        kcfg_boldDeclarations->raise();
        label_8->raise();
        kcfg_globalColorSource->raise();
        label_9->raise();

        verticalLayout_2->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(LanguagePreferences);
        groupBox_3->setObjectName("groupBox_3");
        formLayout_3 = new QFormLayout(groupBox_3);
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_minFilesForSimplifiedParsing = new KPluralHandlingSpinBox(groupBox_3);
        kcfg_minFilesForSimplifiedParsing->setObjectName("kcfg_minFilesForSimplifiedParsing");
        kcfg_minFilesForSimplifiedParsing->setSizeIncrement(QSize(0, 0));
        kcfg_minFilesForSimplifiedParsing->setMaximum(99999999);
        kcfg_minFilesForSimplifiedParsing->setSingleStep(1000);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_minFilesForSimplifiedParsing);


        verticalLayout_2->addWidget(groupBox_3);

        groupBox_4 = new QGroupBox(LanguagePreferences);
        groupBox_4->setObjectName("groupBox_4");
        formLayout_4 = new QFormLayout(groupBox_4);
        formLayout_4->setObjectName("formLayout_4");
        label_precompiledPreambleStorage = new QLabel(groupBox_4);
        label_precompiledPreambleStorage->setObjectName("label_precompiledPreambleStorage");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_precompiledPreambleStorage);

        kcfg_precompiledPreambleStorage = new QComboBox(groupBox_4);
        kcfg_precompiledPreambleStorage->addItem(QString());
        kcfg_precompiledPreambleStorage->addItem(QString());
        kcfg_precompiledPreambleStorage->setObjectName("kcfg_precompiledPreambleStorage");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_precompiledPreambleStorage);


        verticalLayout_2->addWidget(groupBox_4);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        label_6->setBuddy(kcfg_automaticInvocation);
        label_7->setBuddy(kcfg_showMultiLineSelectionInformation);
        label->setBuddy(kcfg_completionDetail);
        localColorizationLabel->setBuddy(kcfg_localColorization);
        label_9->setBuddy(kcfg_globalColorSource);
        globalColorizationLabel->setBuddy(kcfg_globalColorization);
        label_4->setBuddy(kcfg_highlightSemanticProblems);
        label_5->setBuddy(kcfg_highlightProblematicLines);
        boldDeclarationsLabel->setBuddy(kcfg_boldDeclarations);
        label_8->setBuddy(kcfg_problemInlineNotesLevel);
        label_3->setBuddy(kcfg_todoMarkerWords);
        label_2->setBuddy(kcfg_minFilesForSimplifiedParsing);
        label_precompiledPreambleStorage->setBuddy(kcfg_precompiledPreambleStorage);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_automaticInvocation, kcfg_showMultiLineSelectionInformation);
        QWidget::setTabOrder(kcfg_showMultiLineSelectionInformation, kcfg_completionDetail);
        QWidget::setTabOrder(kcfg_completionDetail, kcfg_localColorization);
        QWidget::setTabOrder(kcfg_localColorization, kcfg_globalColorSource);
        QWidget::setTabOrder(kcfg_globalColorSource, kcfg_globalColorization);
        QWidget::setTabOrder(kcfg_globalColorization, kcfg_highlightSemanticProblems);
        QWidget::setTabOrder(kcfg_highlightSemanticProblems, kcfg_highlightProblematicLines);
        QWidget::setTabOrder(kcfg_highlightProblematicLines, kcfg_boldDeclarations);
        QWidget::setTabOrder(kcfg_boldDeclarations, kcfg_problemInlineNotesLevel);
        QWidget::setTabOrder(kcfg_problemInlineNotesLevel, kcfg_todoMarkerWords);
        QWidget::setTabOrder(kcfg_todoMarkerWords, kcfg_minFilesForSimplifiedParsing);

        retranslateUi(LanguagePreferences);

        kcfg_completionDetail->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(LanguagePreferences);
    } // setupUi

    void retranslateUi(QWidget *LanguagePreferences)
    {
        groupBox->setTitle(tr2i18n("Code Completion", "@title:group"));
#if QT_CONFIG(tooltip)
        label_6->setToolTip(tr2i18n("If disabled, the code completion widget will never show automatically.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_6->setText(tr2i18n("Enable automatic invocation:", "@label"));
#if QT_CONFIG(tooltip)
        kcfg_automaticInvocation->setToolTip(tr2i18n("If disabled, the code completion widget will never show automatically.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_automaticInvocation->setText(QString());
#if QT_CONFIG(tooltip)
        label_7->setToolTip(tr2i18n("Choose whether to display additional information for the currently selected codecompletion item.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_7->setText(tr2i18n("Additional information for current item:", "@label"));
#if QT_CONFIG(tooltip)
        kcfg_showMultiLineSelectionInformation->setToolTip(tr2i18n("Choose whether to display additional information for the currently selected code completion item.", "info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_showMultiLineSelectionInformation->setText(QString());
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("<p>The code completion UI has a minimal mode and a detailed mode.<br>Choose in what cases full code completion will be displayed.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Detailed completion:", "@label"));
        kcfg_completionDetail->setItemText(0, tr2i18n("Never", "@item:inlistbox"));
        kcfg_completionDetail->setItemText(1, tr2i18n("When Invoked Manually", "@item:inlistbox"));
        kcfg_completionDetail->setItemText(2, tr2i18n("Always", "@item:inlistbox"));

#if QT_CONFIG(tooltip)
        kcfg_completionDetail->setToolTip(tr2i18n("<p>The code completion UI has a minimal mode and a detailed mode.<br>Choose in what cases full code completion will be displayed.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_2->setTitle(tr2i18n("Semantic Code Highlighting", "@title:group"));
#if QT_CONFIG(tooltip)
        localColorizationLabel->setToolTip(tr2i18n("<p>This setting decides about the intensity of colors for local variables, for example function arguments, variables and the like.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        localColorizationLabel->setText(tr2i18n("Local colorization intensity:", "@label:slider"));
#if QT_CONFIG(tooltip)
        kcfg_localColorization->setToolTip(tr2i18n("<p>This setting decides about the intensity of colors for local variables, for example function arguments, variables and the like.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_globalColorSource->setItemText(0, tr2i18n("Auto-Generated", nullptr));
        kcfg_globalColorSource->setItemText(1, tr2i18n("From Editor Theme", nullptr));

#if QT_CONFIG(tooltip)
        kcfg_globalColorSource->setToolTip(tr2i18n("<p>By default, the global colors for types, functions, namespaces and so forth are auto-generated and will adapt to the selected editor theme based on the global colorization intensity. If you want to have full control over the colors, you can instead use the editor theme as color source. You can then fine tune the colors in the settings under Editor &gt; Color Themes &gt; Highlighting Text Styles &gt; KDevelop/Semantic Colors.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        label_9->setToolTip(tr2i18n("<p>By default, the global colors for types, functions, namespaces and so forth are auto-generated and will adapt to the selected editor theme based on the global colorization intensity. If you want to have full control over the colors, you can instead use the editor theme as color source. You can then fine tune the colors in the settings under Editor &gt; Color Themes &gt; Highlighting Text Styles &gt; KDevelop/Semantic Colors.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_9->setText(tr2i18n("Global colors:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_globalColorization->setToolTip(tr2i18n("<p>This settings lets you change the intensity of globally accessible types, for example classes, methods, functions etc.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        globalColorizationLabel->setToolTip(tr2i18n("<p>This settings lets you change the intensity of globally accessible types, for example classes, methods, functions etc.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        globalColorizationLabel->setText(tr2i18n("Global colorization intensity:", "@label:slider"));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("<p>Highlight semantic problems, such as non-existent or inaccessible declarations.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Highlight semantic problems:", "@label"));
#if QT_CONFIG(tooltip)
        kcfg_highlightSemanticProblems->setToolTip(tr2i18n("<p>Highlight semantic problems, such as non-existent or inaccessible declarations.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_highlightSemanticProblems->setText(QString());
#if QT_CONFIG(tooltip)
        label_5->setToolTip(tr2i18n("<p>When enabled, lines with errors will get additionally highlighted and their positions get marked in the scrollbar.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Highlight problematic lines:", "@label"));
#if QT_CONFIG(tooltip)
        kcfg_highlightProblematicLines->setToolTip(tr2i18n("<p>When enabled, lines with errors will get additionally highlighted and their positions get marked in the scrollbar.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_highlightProblematicLines->setText(QString());
#if QT_CONFIG(tooltip)
        boldDeclarationsLabel->setToolTip(tr2i18n("<html><head/><body><p>Use bold font for declarations such as classes, functions, local variables, etc.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        boldDeclarationsLabel->setText(tr2i18n("Bold font for declarations:", "@label"));
        label_8->setText(tr2i18n("Problems shown as inline notes:", "@label:listbox"));
        kcfg_problemInlineNotesLevel->setItemText(0, tr2i18n("None", "@item:inlistbox inline problems shown"));
        kcfg_problemInlineNotesLevel->setItemText(1, tr2i18n("Errors", "@item:inlistbox inline problems shown"));
        kcfg_problemInlineNotesLevel->setItemText(2, tr2i18n("Warnings and Errors", "@item:inlistbox inline problems shown"));
        kcfg_problemInlineNotesLevel->setItemText(3, tr2i18n("Hints, Warnings and Errors", "@item:inlistbox inline problems shown"));

#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("Space-separated list of words that make a comment represent a TODO item", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("TODO marker words:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_todoMarkerWords->setToolTip(tr2i18n("Space-separated list of words that make a comment represent a TODO item.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_todoMarkerWords->setPlaceholderText(QString());
        groupBox_3->setTitle(tr2i18n("Project Parsing", "@title:group"));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("<p>When a project contains more files than this number, the project will be\n"
"parsed in simplified mode, increasing the efficiency by gathering less information. Global code navigation and quickopen capabilities will be reduced.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Minimum project size for simplified parsing:", "@label:spinbox"));
#if QT_CONFIG(tooltip)
        kcfg_minFilesForSimplifiedParsing->setToolTip(tr2i18n("<p>When a project contains more files than this number, the project will be\n"
"parsed in simplified mode, increasing the efficiency by gathering less information. Global code navigation and quickopen capabilities will be reduced.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_4->setTitle(tr2i18n("Storage and Memory Use", "@title:group"));
        label_precompiledPreambleStorage->setText(tr2i18n("Store precompiled preambles in:", "@label"));
        kcfg_precompiledPreambleStorage->setItemText(0, tr2i18n("Memory", "@item:inlistbox"));
        kcfg_precompiledPreambleStorage->setItemText(1, tr2i18n("Session Temporary Directory", "@item:inlistbox"));

#if QT_CONFIG(tooltip)
        kcfg_precompiledPreambleStorage->setToolTip(tr2i18n("<p>Precompiled preambles remain in the temporary directory after KDevelop crashes and are deleted only when the same session is started again.<br>\n"
"When the preambles are stored in memory, they are guaranteed to disappear on exit even if KDevelop crashes.<br>\n"
"Choosing the Session Temporary Directory storage makes sense on systems where RAM is limited and the temporary directory does not use tmpfs, because the preamble files can occupy gigabytes of space.<br>\n"
"Changing this option takes effect after restarting KDevelop.<br>\n"
"This option has effect only if KDevelop has been built against Clang version 17 or later.\n"
"</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)LanguagePreferences;
    } // retranslateUi

};

namespace Ui {
    class LanguagePreferences: public Ui_LanguagePreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LANGUAGEPREFERENCES_H

