/****************************************************************************
** Meta object code from reading C++ file 'projectcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/shell/projectcontroller.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projectcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop22IProjectDialogProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::IProjectDialogProvider::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop22IProjectDialogProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::IProjectDialogProvider",
        "askProjectConfigLocation",
        "QUrl",
        "",
        "fetch",
        "startUrl",
        "repoUrl",
        "IPlugin*",
        "plugin",
        "userWantsReopen"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'askProjectConfigLocation'
        QtMocHelpers::SlotData<QUrl(bool, const QUrl &, const QUrl &, IPlugin *)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Bool, 4 }, { 0x80000000 | 2, 5 }, { 0x80000000 | 2, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'askProjectConfigLocation'
        QtMocHelpers::SlotData<QUrl(bool, const QUrl &, const QUrl &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::Bool, 4 }, { 0x80000000 | 2, 5 }, { 0x80000000 | 2, 6 },
        }}),
        // Slot 'askProjectConfigLocation'
        QtMocHelpers::SlotData<QUrl(bool, const QUrl &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::Bool, 4 }, { 0x80000000 | 2, 5 },
        }}),
        // Slot 'askProjectConfigLocation'
        QtMocHelpers::SlotData<QUrl(bool)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'userWantsReopen'
        QtMocHelpers::SlotData<bool()>(9, 3, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IProjectDialogProvider, qt_meta_tag_ZN8KDevelop22IProjectDialogProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::IProjectDialogProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop22IProjectDialogProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop22IProjectDialogProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop22IProjectDialogProviderE_t>.metaTypes,
    nullptr
} };

void KDevelop::IProjectDialogProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IProjectDialogProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QUrl _r = _t->askProjectConfigLocation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<IPlugin*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 1: { QUrl _r = _t->askProjectConfigLocation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 2: { QUrl _r = _t->askProjectConfigLocation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 3: { QUrl _r = _t->askProjectConfigLocation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->userWantsReopen();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::IProjectDialogProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::IProjectDialogProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop22IProjectDialogProviderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::IProjectDialogProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop17ProjectControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::ProjectController::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop17ProjectControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::ProjectController",
        "D-Bus Interface",
        "org.kdevelop.ProjectController",
        "initialized",
        "",
        "openProjectForUrl",
        "sourceUrl",
        "QUrl",
        "fetchProject",
        "openProject",
        "KDev4ProjectFile",
        "abortOpeningProject",
        "IProject*",
        "projectImportingFinished",
        "closeProject",
        "closeAllProjects",
        "configureProject",
        "reparseProject",
        "project",
        "forceUpdate",
        "forceAll",
        "eventuallyOpenProjectFile",
        "KIO::Job*",
        "job",
        "KIO::UDSEntryList",
        "entries",
        "openProjectForUrlSlot",
        "openProjects",
        "QList<QUrl>",
        "projects",
        "commitCurrentProject",
        "mapSourceBuild",
        "path",
        "reverse",
        "fallbackRoot"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'initialized'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openProjectForUrl'
        QtMocHelpers::SlotData<void(const QString &)>(5, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'openProjectForUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 6 },
        }}),
        // Slot 'fetchProject'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void(const QUrl &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 10 },
        }}),
        // Slot 'openProject'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'abortOpeningProject'
        QtMocHelpers::SlotData<void(IProject *)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 4 },
        }}),
        // Slot 'projectImportingFinished'
        QtMocHelpers::SlotData<void(IProject *)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 4 },
        }}),
        // Slot 'closeProject'
        QtMocHelpers::SlotData<void(IProject *)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 4 },
        }}),
        // Slot 'closeAllProjects'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configureProject'
        QtMocHelpers::SlotData<void(IProject *)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 4 },
        }}),
        // Slot 'reparseProject'
        QtMocHelpers::SlotData<void(IProject *, bool, bool)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 18 }, { QMetaType::Bool, 19 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'reparseProject'
        QtMocHelpers::SlotData<void(IProject *, bool)>(17, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 12, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'reparseProject'
        QtMocHelpers::SlotData<void(IProject *)>(17, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 12, 18 },
        }}),
        // Slot 'eventuallyOpenProjectFile'
        QtMocHelpers::SlotData<void(KIO::Job *, const KIO::UDSEntryList &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'openProjectForUrlSlot'
        QtMocHelpers::SlotData<void(bool)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'openProjects'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'commitCurrentProject'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mapSourceBuild'
        QtMocHelpers::SlotData<QString(const QString &, bool, bool) const>(31, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 32 }, { QMetaType::Bool, 33 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'mapSourceBuild'
        QtMocHelpers::SlotData<QString(const QString &, bool) const>(31, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 32 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'mapSourceBuild'
        QtMocHelpers::SlotData<QString(const QString &) const>(31, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ProjectController, qt_meta_tag_ZN8KDevelop17ProjectControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KDevelop::ProjectController::staticMetaObject = { {
    QMetaObject::SuperData::link<IProjectController::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17ProjectControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17ProjectControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop17ProjectControllerE_t>.metaTypes,
    nullptr
} };

void KDevelop::ProjectController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initialized(); break;
        case 1: _t->openProjectForUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->openProjectForUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->fetchProject(); break;
        case 4: _t->openProject((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->openProject(); break;
        case 6: _t->abortOpeningProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1]))); break;
        case 7: _t->projectImportingFinished((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1]))); break;
        case 8: _t->closeProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1]))); break;
        case 9: _t->closeAllProjects(); break;
        case 10: _t->configureProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1]))); break;
        case 11: _t->reparseProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 12: _t->reparseProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->reparseProject((*reinterpret_cast<std::add_pointer_t<IProject*>>(_a[1]))); break;
        case 14: _t->eventuallyOpenProjectFile((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::UDSEntryList>>(_a[2]))); break;
        case 15: _t->openProjectForUrlSlot((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->openProjects((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 17: _t->commitCurrentProject(); break;
        case 18: { QString _r = _t->mapSourceBuild((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QString _r = _t->mapSourceBuild((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->mapSourceBuild((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProjectController::*)()>(_a, &ProjectController::initialized, 0))
            return;
    }
}

const QMetaObject *KDevelop::ProjectController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::ProjectController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17ProjectControllerE_t>.strings))
        return static_cast<void*>(this);
    return IProjectController::qt_metacast(_clname);
}

int KDevelop::ProjectController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IProjectController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::ProjectController::initialized()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KDevelop21ProjectDialogProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::ProjectDialogProvider::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop21ProjectDialogProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::ProjectDialogProvider",
        "askProjectConfigLocation",
        "QUrl",
        "",
        "fetch",
        "startUrl",
        "repoUrl",
        "IPlugin*",
        "plugin",
        "userWantsReopen"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'askProjectConfigLocation'
        QtMocHelpers::SlotData<QUrl(bool, const QUrl &, const QUrl &, IPlugin *)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Bool, 4 }, { 0x80000000 | 2, 5 }, { 0x80000000 | 2, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'userWantsReopen'
        QtMocHelpers::SlotData<bool()>(9, 3, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectDialogProvider, qt_meta_tag_ZN8KDevelop21ProjectDialogProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::ProjectDialogProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<IProjectDialogProvider::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop21ProjectDialogProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop21ProjectDialogProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop21ProjectDialogProviderE_t>.metaTypes,
    nullptr
} };

void KDevelop::ProjectDialogProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectDialogProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QUrl _r = _t->askProjectConfigLocation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<IPlugin*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->userWantsReopen();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::ProjectDialogProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::ProjectDialogProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop21ProjectDialogProviderE_t>.strings))
        return static_cast<void*>(this);
    return IProjectDialogProvider::qt_metacast(_clname);
}

int KDevelop::ProjectDialogProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IProjectDialogProvider::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
