/********************************************************************************
** Form generated from reading UI file 'scratchpadview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCRATCHPADVIEW_H
#define UI_SCRATCHPADVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "emptymessagelistview.h"

QT_BEGIN_NAMESPACE

class Ui_ScratchpadBaseView
{
public:
    QVBoxLayout *vboxLayout;
    EmptyMessageListView *scratchView;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *commandWidget;

    void setupUi(QWidget *ScratchpadBaseView)
    {
        if (ScratchpadBaseView->objectName().isEmpty())
            ScratchpadBaseView->setObjectName("ScratchpadBaseView");
        ScratchpadBaseView->resize(232, 389);
        vboxLayout = new QVBoxLayout(ScratchpadBaseView);
        vboxLayout->setSpacing(2);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        scratchView = new EmptyMessageListView(ScratchpadBaseView);
        scratchView->setObjectName("scratchView");
        scratchView->setEditTriggers(QAbstractItemView::EditKeyPressed);

        vboxLayout->addWidget(scratchView);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        commandWidget = new QLineEdit(ScratchpadBaseView);
        commandWidget->setObjectName("commandWidget");

        horizontalLayout_2->addWidget(commandWidget);


        vboxLayout->addLayout(horizontalLayout_2);


        retranslateUi(ScratchpadBaseView);

        QMetaObject::connectSlotsByName(ScratchpadBaseView);
    } // setupUi

    void retranslateUi(QWidget *ScratchpadBaseView)
    {
        (void)ScratchpadBaseView;
    } // retranslateUi

};

namespace Ui {
    class ScratchpadBaseView: public Ui_ScratchpadBaseView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCRATCHPADVIEW_H

