/********************************************************************************
** Form generated from reading UI file 'dependencieswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEPENDENCIESWIDGET_H
#define UI_DEPENDENCIESWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "project/projectitemlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_DependenciesWidget
{
public:
    QGridLayout *gridLayout;
    ProjectItemLineEdit *targetDependency;
    QPushButton *browseProject;
    QPushButton *addDependency;
    QListWidget *dependencies;
    QPushButton *removeDependency;
    QPushButton *moveDepUp;
    QPushButton *moveDepDown;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DependenciesWidget)
    {
        if (DependenciesWidget->objectName().isEmpty())
            DependenciesWidget->setObjectName("DependenciesWidget");
        DependenciesWidget->resize(400, 300);
        gridLayout = new QGridLayout(DependenciesWidget);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        targetDependency = new ProjectItemLineEdit(DependenciesWidget);
        targetDependency->setObjectName("targetDependency");
        targetDependency->setClearButtonEnabled(true);

        gridLayout->addWidget(targetDependency, 0, 0, 1, 1);

        browseProject = new QPushButton(DependenciesWidget);
        browseProject->setObjectName("browseProject");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("folder-document")));
        browseProject->setIcon(icon);

        gridLayout->addWidget(browseProject, 0, 1, 1, 1);

        addDependency = new QPushButton(DependenciesWidget);
        addDependency->setObjectName("addDependency");
        addDependency->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addDependency->setIcon(icon1);

        gridLayout->addWidget(addDependency, 0, 2, 1, 1);

        dependencies = new QListWidget(DependenciesWidget);
        dependencies->setObjectName("dependencies");
        dependencies->setAlternatingRowColors(true);
        dependencies->setUniformItemSizes(true);

        gridLayout->addWidget(dependencies, 1, 0, 4, 2);

        removeDependency = new QPushButton(DependenciesWidget);
        removeDependency->setObjectName("removeDependency");
        removeDependency->setEnabled(false);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        removeDependency->setIcon(icon2);

        gridLayout->addWidget(removeDependency, 1, 2, 1, 1);

        moveDepUp = new QPushButton(DependenciesWidget);
        moveDepUp->setObjectName("moveDepUp");
        moveDepUp->setEnabled(false);
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("go-up")));
        moveDepUp->setIcon(icon3);

        gridLayout->addWidget(moveDepUp, 2, 2, 1, 1);

        moveDepDown = new QPushButton(DependenciesWidget);
        moveDepDown->setObjectName("moveDepDown");
        moveDepDown->setEnabled(false);
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("go-down")));
        moveDepDown->setIcon(icon4);

        gridLayout->addWidget(moveDepDown, 3, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 151, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 2, 1, 1);


        retranslateUi(DependenciesWidget);

        QMetaObject::connectSlotsByName(DependenciesWidget);
    } // setupUi

    void retranslateUi(QWidget *DependenciesWidget)
    {
#if QT_CONFIG(tooltip)
        targetDependency->setToolTip(tr2i18n("Enter a dependency to add to the list", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        targetDependency->setPlaceholderText(tr2i18n("Enter a dependency to add to the list...", "@info:placedholder"));
#if QT_CONFIG(tooltip)
        addDependency->setToolTip(tr2i18n("Add the listed target to the dependency list", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        addDependency->setText(QString());
#if QT_CONFIG(tooltip)
        dependencies->setToolTip(tr2i18n("List of indirect dependent targets.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        dependencies->setWhatsThis(tr2i18n("This list should contain targets that the application does not directly depend on, but for which an action needs to be taken before running the application.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        removeDependency->setToolTip(tr2i18n("Remove the selected dependencies from the list", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        removeDependency->setText(QString());
#if QT_CONFIG(tooltip)
        moveDepUp->setToolTip(tr2i18n("Move the selected dependency up in the list", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        moveDepUp->setText(QString());
#if QT_CONFIG(tooltip)
        moveDepDown->setToolTip(tr2i18n("Move the selected dependency down in the list", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        moveDepDown->setText(QString());
        (void)DependenciesWidget;
    } // retranslateUi

};

namespace Ui {
    class DependenciesWidget: public Ui_DependenciesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DEPENDENCIESWIDGET_H

