/********************************************************************************
** Form generated from reading UI file 'editexternalscript.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITEXTERNALSCRIPT_H
#define UI_EDITEXTERNALSCRIPT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KShortcutWidget"

QT_BEGIN_NAMESPACE

class Ui_EditExternalScriptBase
{
public:
    QVBoxLayout *vboxLayout;
    QFormLayout *formLayout;
    QLabel *nameLabel;
    QLineEdit *nameEdit;
    QLabel *commandLabel;
    QLineEdit *commandEdit;
    QLabel *stdinLabel;
    QComboBox *stdinCombo;
    QLabel *stdoutLabel;
    QComboBox *stdoutCombo;
    QLabel *stderrLabel;
    QComboBox *stderrCombo;
    QLabel *saveLabel;
    QComboBox *saveCombo;
    QLabel *label;
    QCheckBox *showOutputBox;
    QLabel *outputFilterLabel;
    QComboBox *outputFilterCombo;
    QLabel *shortcutLabel;
    KShortcutWidget *shortcutWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *EditExternalScriptBase)
    {
        if (EditExternalScriptBase->objectName().isEmpty())
            EditExternalScriptBase->setObjectName("EditExternalScriptBase");
        EditExternalScriptBase->resize(521, 400);
        vboxLayout = new QVBoxLayout(EditExternalScriptBase);
        vboxLayout->setObjectName("vboxLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        nameLabel = new QLabel(EditExternalScriptBase);
        nameLabel->setObjectName("nameLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, nameLabel);

        nameEdit = new QLineEdit(EditExternalScriptBase);
        nameEdit->setObjectName("nameEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, nameEdit);

        commandLabel = new QLabel(EditExternalScriptBase);
        commandLabel->setObjectName("commandLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, commandLabel);

        commandEdit = new QLineEdit(EditExternalScriptBase);
        commandEdit->setObjectName("commandEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, commandEdit);

        stdinLabel = new QLabel(EditExternalScriptBase);
        stdinLabel->setObjectName("stdinLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, stdinLabel);

        stdinCombo = new QComboBox(EditExternalScriptBase);
        stdinCombo->addItem(QString());
        stdinCombo->addItem(QString());
        stdinCombo->addItem(QString());
        stdinCombo->addItem(QString());
        stdinCombo->setObjectName("stdinCombo");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, stdinCombo);

        stdoutLabel = new QLabel(EditExternalScriptBase);
        stdoutLabel->setObjectName("stdoutLabel");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, stdoutLabel);

        stdoutCombo = new QComboBox(EditExternalScriptBase);
        stdoutCombo->addItem(QString());
        stdoutCombo->addItem(QString());
        stdoutCombo->addItem(QString());
        stdoutCombo->addItem(QString());
        stdoutCombo->addItem(QString());
        stdoutCombo->addItem(QString());
        stdoutCombo->setObjectName("stdoutCombo");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, stdoutCombo);

        stderrLabel = new QLabel(EditExternalScriptBase);
        stderrLabel->setObjectName("stderrLabel");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, stderrLabel);

        stderrCombo = new QComboBox(EditExternalScriptBase);
        stderrCombo->addItem(QString());
        stderrCombo->addItem(QString());
        stderrCombo->addItem(QString());
        stderrCombo->addItem(QString());
        stderrCombo->addItem(QString());
        stderrCombo->addItem(QString());
        stderrCombo->addItem(QString());
        stderrCombo->setObjectName("stderrCombo");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, stderrCombo);

        saveLabel = new QLabel(EditExternalScriptBase);
        saveLabel->setObjectName("saveLabel");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, saveLabel);

        saveCombo = new QComboBox(EditExternalScriptBase);
        saveCombo->addItem(QString());
        saveCombo->addItem(QString());
        saveCombo->addItem(QString());
        saveCombo->setObjectName("saveCombo");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, saveCombo);

        label = new QLabel(EditExternalScriptBase);
        label->setObjectName("label");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label);

        showOutputBox = new QCheckBox(EditExternalScriptBase);
        showOutputBox->setObjectName("showOutputBox");
        showOutputBox->setChecked(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, showOutputBox);

        outputFilterLabel = new QLabel(EditExternalScriptBase);
        outputFilterLabel->setObjectName("outputFilterLabel");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, outputFilterLabel);

        outputFilterCombo = new QComboBox(EditExternalScriptBase);
        outputFilterCombo->addItem(QString());
        outputFilterCombo->addItem(QString());
        outputFilterCombo->addItem(QString());
        outputFilterCombo->addItem(QString());
        outputFilterCombo->setObjectName("outputFilterCombo");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, outputFilterCombo);

        shortcutLabel = new QLabel(EditExternalScriptBase);
        shortcutLabel->setObjectName("shortcutLabel");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, shortcutLabel);

        shortcutWidget = new KShortcutWidget(EditExternalScriptBase);
        shortcutWidget->setObjectName("shortcutWidget");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, shortcutWidget);


        vboxLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(EditExternalScriptBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        nameLabel->setBuddy(nameEdit);
        commandLabel->setBuddy(commandEdit);
        stdinLabel->setBuddy(stdinCombo);
        stdoutLabel->setBuddy(stdoutCombo);
        stderrLabel->setBuddy(stderrCombo);
        saveLabel->setBuddy(saveCombo);
        label->setBuddy(showOutputBox);
        outputFilterLabel->setBuddy(outputFilterCombo);
#endif // QT_CONFIG(shortcut)

        retranslateUi(EditExternalScriptBase);

        QMetaObject::connectSlotsByName(EditExternalScriptBase);
    } // setupUi

    void retranslateUi(QWidget *EditExternalScriptBase)
    {
        nameLabel->setText(tr2i18n("&Name:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        nameEdit->setToolTip(tr2i18n("<p>The name will also be used as the identifier during code completion.</p>\n"
"  <p><b>Note:</b> No spaces allowed.</p>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        commandLabel->setText(tr2i18n("&Command:", "@label:textbox"));
        stdinLabel->setText(tr2i18n("&Input:", "@label:listbox"));
        stdinCombo->setItemText(0, tr2i18n("Nothing", "@item:inlistbox input source"));
        stdinCombo->setItemText(1, tr2i18n("Selection in Current File or Nothing", "@item:inlistbox input source"));
        stdinCombo->setItemText(2, tr2i18n("Selection in Current File or Whole File", "@item:inlistbox input source"));
        stdinCombo->setItemText(3, tr2i18n("Contents of Current File", "@item:inlistbox input source"));

        stdoutLabel->setText(tr2i18n("&Output:", "@label:listbox"));
        stdoutCombo->setItemText(0, tr2i18n("Ignore", "@item:inlistbox handle output"));
        stdoutCombo->setItemText(1, tr2i18n("Insert at Cursor Position of Current File", "@item:inlistbox handle output"));
        stdoutCombo->setItemText(2, tr2i18n("Replace Selection of Current File or Insert at Cursor Position", "@item:inlistbox handle output"));
        stdoutCombo->setItemText(3, tr2i18n("Replace Selection of Current File or Whole File", "@item:inlistbox handle output"));
        stdoutCombo->setItemText(4, tr2i18n("Replace Contents of Current File", "@item:inlistbox handle output"));
        stdoutCombo->setItemText(5, tr2i18n("Create New File", "@item:inlistbox handle output"));

        stderrLabel->setText(tr2i18n("Errors:", "@label:listbox"));
        stderrCombo->setItemText(0, tr2i18n("Ignore", "@item:inlistbox handle errors"));
        stderrCombo->setItemText(1, tr2i18n("Merge with Normal Output", "@item:inlistbox handle errors"));
        stderrCombo->setItemText(2, tr2i18n("Insert at Cursor Position of Current File", "@item:inlistbox handle errors"));
        stderrCombo->setItemText(3, tr2i18n("Replace Selection of Current File or Insert at Cursor Position", "@item:inlistbox handle errors"));
        stderrCombo->setItemText(4, tr2i18n("Replace Selection of Current File or Whole File", "@item:inlistbox handle errors"));
        stderrCombo->setItemText(5, tr2i18n("Replace Contents of Current File", "@item:inlistbox handle errors"));
        stderrCombo->setItemText(6, tr2i18n("Create New File", "@item:inlistbox handle errors"));

        saveLabel->setText(tr2i18n("Save &mode:", "@label:listbox"));
        saveCombo->setItemText(0, tr2i18n("Save Nothing", "@item:inlistbox save mode"));
        saveCombo->setItemText(1, tr2i18n("Save Active Document", "@item:inlistbox save mode"));
        saveCombo->setItemText(2, tr2i18n("Save All Open Documents", "@item:inlistbox save mode"));

        label->setText(tr2i18n("Show out&put:", "@option:check"));
        outputFilterLabel->setText(tr2i18n("Output filter:", "@label:listbox"));
        outputFilterCombo->setItemText(0, tr2i18n("No Filter", "@item:inlistbox output filter"));
        outputFilterCombo->setItemText(1, tr2i18n("Compiler Filter", "@item:inlistbox output filter"));
        outputFilterCombo->setItemText(2, tr2i18n("Script Error Filter", "@item:inlistbox output filter"));
        outputFilterCombo->setItemText(3, tr2i18n("Static Analysis Filter", "@item:inlistbox output filter"));

#if QT_CONFIG(tooltip)
        shortcutLabel->setToolTip(tr2i18n("Defines shortcuts you can use to execute this script.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        shortcutLabel->setText(tr2i18n("Shortcut:", "@label:chooser"));
        (void)EditExternalScriptBase;
    } // retranslateUi

};

namespace Ui {
    class EditExternalScriptBase: public Ui_EditExternalScriptBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITEXTERNALSCRIPT_H

