/********************************************************************************
** Form generated from reading UI file 'vcsdiffwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VCSDIFFWIDGET_H
#define UI_VCSDIFFWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KTextEdit"

QT_BEGIN_NAMESPACE

class Ui_VcsDiffWidget
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *revLabel;
    KTextEdit *diffDisplay;

    void setupUi(QWidget *VcsDiffWidget)
    {
        if (VcsDiffWidget->objectName().isEmpty())
            VcsDiffWidget->setObjectName("VcsDiffWidget");
        VcsDiffWidget->resize(625, 376);
        vboxLayout = new QVBoxLayout(VcsDiffWidget);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        revLabel = new QLabel(VcsDiffWidget);
        revLabel->setObjectName("revLabel");

        vboxLayout->addWidget(revLabel);

        diffDisplay = new KTextEdit(VcsDiffWidget);
        diffDisplay->setObjectName("diffDisplay");

        vboxLayout->addWidget(diffDisplay);


        retranslateUi(VcsDiffWidget);

        QMetaObject::connectSlotsByName(VcsDiffWidget);
    } // setupUi

    void retranslateUi(QWidget *VcsDiffWidget)
    {
        revLabel->setText(tr2i18n("Difference between revisions:", "@label"));
        (void)VcsDiffWidget;
    } // retranslateUi

};

namespace Ui {
    class VcsDiffWidget: public Ui_VcsDiffWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VCSDIFFWIDGET_H

