// This file is generated by kconfig_compiler_kf6 from globalsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef CPPCHECK_GLOBALSETTINGS_H
#define CPPCHECK_GLOBALSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include "parameters.h"

namespace cppcheck {

class GlobalSettings : public KConfigSkeleton
{
  public:

    static GlobalSettings *self();
    ~GlobalSettings() override;

    /**
      Get executablePath
    */
    static
    QString executablePath()
    {
      return self()->mExecutablePath;
    }

    /**
      Is executablePath Immutable
    */
    static
    bool isExecutablePathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "executablePath" ) );
    }

    /**
      Get hideOutputView
    */
    static
    bool hideOutputView()
    {
      return self()->mHideOutputView;
    }

    /**
      Is hideOutputView Immutable
    */
    static
    bool isHideOutputViewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "hideOutputView" ) );
    }

    /**
      Get showXmlOutput
    */
    static
    bool showXmlOutput()
    {
      return self()->mShowXmlOutput;
    }

    /**
      Is showXmlOutput Immutable
    */
    static
    bool isShowXmlOutputImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showXmlOutput" ) );
    }

  protected:
    GlobalSettings();
    friend class GlobalSettingsHelper;


    // Cppcheck
    QString mExecutablePath;
    bool mHideOutputView;
    bool mShowXmlOutput;
};

}

#endif

