/****************************************************************************
** Meta object code from reading C++ file 'mainwindow_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/sublime/mainwindow_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Sublime17MainWindowPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto Sublime::MainWindowPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN7Sublime17MainWindowPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Sublime::MainWindowPrivate",
        "toggleDocksShown",
        "",
        "viewAdded",
        "Sublime::AreaIndex*",
        "index",
        "Sublime::View*",
        "view",
        "viewRemovedInternal",
        "raiseToolView",
        "aboutToRemoveView",
        "toolViewAdded",
        "toolView",
        "Sublime::Position",
        "position",
        "aboutToRemoveToolView",
        "updateAreaSwitcher",
        "Sublime::Area*",
        "area",
        "widgetCloseRequest",
        "QWidget*",
        "widget",
        "selectNextDock",
        "selectPreviousDock",
        "messageDestroyed",
        "Message*",
        "message"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'toggleDocksShown'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'viewAdded'
        QtMocHelpers::SlotData<void(Sublime::AreaIndex *, Sublime::View *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'viewRemovedInternal'
        QtMocHelpers::SlotData<void(Sublime::AreaIndex *, Sublime::View *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'raiseToolView'
        QtMocHelpers::SlotData<void(Sublime::View *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'aboutToRemoveView'
        QtMocHelpers::SlotData<void(Sublime::AreaIndex *, Sublime::View *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'toolViewAdded'
        QtMocHelpers::SlotData<void(Sublime::View *, Sublime::Position)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'aboutToRemoveToolView'
        QtMocHelpers::SlotData<void(Sublime::View *, Sublime::Position)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'updateAreaSwitcher'
        QtMocHelpers::SlotData<void(Sublime::Area *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'widgetCloseRequest'
        QtMocHelpers::SlotData<void(QWidget *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'selectNextDock'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectPreviousDock'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'messageDestroyed'
        QtMocHelpers::SlotData<void(Message *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindowPrivate, qt_meta_tag_ZN7Sublime17MainWindowPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Sublime::MainWindowPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime17MainWindowPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime17MainWindowPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Sublime17MainWindowPrivateE_t>.metaTypes,
    nullptr
} };

void Sublime::MainWindowPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindowPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toggleDocksShown(); break;
        case 1: _t->viewAdded((*reinterpret_cast<std::add_pointer_t<Sublime::AreaIndex*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[2]))); break;
        case 2: _t->viewRemovedInternal((*reinterpret_cast<std::add_pointer_t<Sublime::AreaIndex*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[2]))); break;
        case 3: _t->raiseToolView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 4: _t->aboutToRemoveView((*reinterpret_cast<std::add_pointer_t<Sublime::AreaIndex*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[2]))); break;
        case 5: _t->toolViewAdded((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Position>>(_a[2]))); break;
        case 6: _t->aboutToRemoveToolView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Position>>(_a[2]))); break;
        case 7: _t->updateAreaSwitcher((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        case 8: _t->widgetCloseRequest((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 9: _t->selectNextDock(); break;
        case 10: _t->selectPreviousDock(); break;
        case 11: _t->messageDestroyed((*reinterpret_cast<std::add_pointer_t<Message*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Sublime::Area* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Sublime::MainWindowPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sublime::MainWindowPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime17MainWindowPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Sublime::MainWindowPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
