// This file is generated by kconfig_compiler_kf6 from androidpreferencessettings.kcfg.
// All changes you do to this file will be lost.

#include "androidpreferencessettings.h"

AndroidPreferencesSettings::AndroidPreferencesSettings( )
  : KConfigSkeleton()
{
  setCurrentGroup( QStringLiteral( "Android" ) );

  KConfigSkeleton::ItemPath  *itemCmakeToolchain;
  itemCmakeToolchain = new KConfigSkeleton::ItemPath( currentGroup(), QStringLiteral( "cmakeToolchain" ), mCmakeToolchain, QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("ECM/toolchain/Android.cmake")) );
  addItem( itemCmakeToolchain, QStringLiteral( "cmakeToolchain" ) );
  KConfigSkeleton::ItemPath  *itemNdk;
  itemNdk = new KConfigSkeleton::ItemPath( currentGroup(), QStringLiteral( "ndk" ), mNdk, QString::fromUtf8(qgetenv("ANDROID_NDK")) );
  addItem( itemNdk, QStringLiteral( "ndk" ) );
  KConfigSkeleton::ItemPath  *itemSdk;
  itemSdk = new KConfigSkeleton::ItemPath( currentGroup(), QStringLiteral( "sdk" ), mSdk, QString::fromUtf8(qgetenv("ANDROID_HOME")) );
  addItem( itemSdk, QStringLiteral( "sdk" ) );
  KConfigSkeleton::ItemString  *itemArch;
  itemArch = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "arch" ), mArch, QStringLiteral( "arm" ) );
  addItem( itemArch, QStringLiteral( "arch" ) );
  KConfigSkeleton::ItemString  *itemToolchain;
  itemToolchain = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "toolchain" ), mToolchain, QStringLiteral( "arm-linux-androideabi" ) );
  addItem( itemToolchain, QStringLiteral( "toolchain" ) );
  KConfigSkeleton::ItemString  *itemAbi;
  itemAbi = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "abi" ), mAbi, QStringLiteral( "armeabi-v7a" ) );
  addItem( itemAbi, QStringLiteral( "abi" ) );
  KConfigSkeleton::ItemString  *itemGcc;
  itemGcc = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "gcc" ), mGcc, QStringLiteral( "4.9" ) );
  addItem( itemGcc, QStringLiteral( "gcc" ) );
  KConfigSkeleton::ItemString  *itemApi;
  itemApi = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "api" ), mApi, QStringLiteral( "14" ) );
  addItem( itemApi, QStringLiteral( "api" ) );
  KConfigSkeleton::ItemString  *itemBuildtools;
  itemBuildtools = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "buildtools" ), mBuildtools, QStringLiteral( "21.1.1" ) );
  addItem( itemBuildtools, QStringLiteral( "buildtools" ) );
}

AndroidPreferencesSettings::~AndroidPreferencesSettings()
{
}

