/********************************************************************************
** Form generated from reading UI file 'perforceimportmetadatawidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PERFORCEIMPORTMETADATAWIDGET_H
#define UI_PERFORCEIMPORTMETADATAWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_PerforceImportMetadataWidget
{
public:
    QFormLayout *formLayout;
    QLabel *labelUrl;
    KUrlRequester *sourceLoc;
    QLabel *labelExec;
    KUrlRequester *executableLoc;
    QLabel *labelP4port;
    QLineEdit *p4portEdit;
    QLabel *labelP4user;
    QLineEdit *p4userEdit;
    QLabel *labelP4client;
    KComboBox *p4clientEdit;
    QLabel *labelP4config;
    QLineEdit *p4configEdit;
    QPushButton *testP4setupButton;
    QTextBrowser *errorMsg;
    QGroupBox *groupBox;
    QRadioButton *radioButtonConfig;
    QRadioButton *radioButtonVariables;

    void setupUi(QWidget *PerforceImportMetadataWidget)
    {
        if (PerforceImportMetadataWidget->objectName().isEmpty())
            PerforceImportMetadataWidget->setObjectName("PerforceImportMetadataWidget");
        PerforceImportMetadataWidget->resize(581, 339);
        formLayout = new QFormLayout(PerforceImportMetadataWidget);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(0, 0, 0, 0);
        labelUrl = new QLabel(PerforceImportMetadataWidget);
        labelUrl->setObjectName("labelUrl");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelUrl);

        sourceLoc = new KUrlRequester(PerforceImportMetadataWidget);
        sourceLoc->setObjectName("sourceLoc");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, sourceLoc);

        labelExec = new QLabel(PerforceImportMetadataWidget);
        labelExec->setObjectName("labelExec");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelExec);

        executableLoc = new KUrlRequester(PerforceImportMetadataWidget);
        executableLoc->setObjectName("executableLoc");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, executableLoc);

        labelP4port = new QLabel(PerforceImportMetadataWidget);
        labelP4port->setObjectName("labelP4port");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, labelP4port);

        p4portEdit = new QLineEdit(PerforceImportMetadataWidget);
        p4portEdit->setObjectName("p4portEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(p4portEdit->sizePolicy().hasHeightForWidth());
        p4portEdit->setSizePolicy(sizePolicy);
        p4portEdit->setMinimumSize(QSize(0, 0));

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, p4portEdit);

        labelP4user = new QLabel(PerforceImportMetadataWidget);
        labelP4user->setObjectName("labelP4user");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(labelP4user->sizePolicy().hasHeightForWidth());
        labelP4user->setSizePolicy(sizePolicy1);
        labelP4user->setMinimumSize(QSize(100, 0));

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, labelP4user);

        p4userEdit = new QLineEdit(PerforceImportMetadataWidget);
        p4userEdit->setObjectName("p4userEdit");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, p4userEdit);

        labelP4client = new QLabel(PerforceImportMetadataWidget);
        labelP4client->setObjectName("labelP4client");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, labelP4client);

        p4clientEdit = new KComboBox(PerforceImportMetadataWidget);
        p4clientEdit->setObjectName("p4clientEdit");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, p4clientEdit);

        labelP4config = new QLabel(PerforceImportMetadataWidget);
        labelP4config->setObjectName("labelP4config");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, labelP4config);

        p4configEdit = new QLineEdit(PerforceImportMetadataWidget);
        p4configEdit->setObjectName("p4configEdit");
        p4configEdit->setEnabled(false);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, p4configEdit);

        testP4setupButton = new QPushButton(PerforceImportMetadataWidget);
        testP4setupButton->setObjectName("testP4setupButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(50);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(testP4setupButton->sizePolicy().hasHeightForWidth());
        testP4setupButton->setSizePolicy(sizePolicy2);

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, testP4setupButton);

        errorMsg = new QTextBrowser(PerforceImportMetadataWidget);
        errorMsg->setObjectName("errorMsg");
        errorMsg->setStyleSheet(QString::fromUtf8("* { background-color: rgba(0, 0, 0, 0); }"));

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, errorMsg);

        groupBox = new QGroupBox(PerforceImportMetadataWidget);
        groupBox->setObjectName("groupBox");
        groupBox->setEnabled(true);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy3);
        groupBox->setMinimumSize(QSize(250, 0));
        groupBox->setLayoutDirection(Qt::LeftToRight);
        groupBox->setAutoFillBackground(false);
        groupBox->setFlat(true);
        groupBox->setCheckable(false);
        groupBox->setChecked(false);
        radioButtonConfig = new QRadioButton(groupBox);
        radioButtonConfig->setObjectName("radioButtonConfig");
        radioButtonConfig->setGeometry(QRect(7, 10, 100, 30));
        radioButtonConfig->setChecked(true);
        radioButtonVariables = new QRadioButton(groupBox);
        radioButtonVariables->setObjectName("radioButtonVariables");
        radioButtonVariables->setGeometry(QRect(115, 10, 140, 31));

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, groupBox);


        retranslateUi(PerforceImportMetadataWidget);

        QMetaObject::connectSlotsByName(PerforceImportMetadataWidget);
    } // setupUi

    void retranslateUi(QWidget *PerforceImportMetadataWidget)
    {
        labelUrl->setText(tr2i18n("Source directory:", "@label:textbox"));
        labelExec->setText(tr2i18n("P4 executable:", "@label:textbox"));
        labelP4port->setText(tr2i18n("P4 Port", nullptr));
#if QT_CONFIG(tooltip)
        p4portEdit->setToolTip(tr2i18n("The format of P4PORT for Perforce applications is protocol:host:port, or port by itself if both the Perforce application and versioning service are running on the same host. Port numbers must be in the range 1024 through 32767", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        p4portEdit->setText(QString());
        labelP4user->setText(tr2i18n("P4 User", nullptr));
#if QT_CONFIG(tooltip)
        p4userEdit->setToolTip(tr2i18n("Current Perforce user name. By default, the Perforce username is the same as the OS username", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        labelP4client->setText(tr2i18n("P4 Client", nullptr));
#if QT_CONFIG(tooltip)
        p4clientEdit->setToolTip(tr2i18n("Name of current client workspace on the Perforce server", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        labelP4config->setText(tr2i18n("P4 Config", nullptr));
#if QT_CONFIG(tooltip)
        p4configEdit->setToolTip(tr2i18n("Contains a file name without a path. The specified file is used to store other Perforce environment variables ", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        testP4setupButton->setText(tr2i18n("Test", "@action:button"));
        groupBox->setTitle(QString());
        radioButtonConfig->setText(tr2i18n("Config File", "@option:radio"));
        radioButtonVariables->setText(tr2i18n("User/Port Config", "@option:radio"));
        (void)PerforceImportMetadataWidget;
    } // retranslateUi

};

namespace Ui {
    class PerforceImportMetadataWidget: public Ui_PerforceImportMetadataWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PERFORCEIMPORTMETADATAWIDGET_H

