/********************************************************************************
** Form generated from reading UI file 'basicrefactoring.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BASICREFACTORING_H
#define UI_BASICREFACTORING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RenameDialog
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *newNameLabel;
    QLineEdit *edit;
    QPushButton *goButton;
    QPushButton *cancelButton;
    QTabWidget *tabWidget;

    void setupUi(QDialog *RenameDialog)
    {
        if (RenameDialog->objectName().isEmpty())
            RenameDialog->setObjectName("RenameDialog");
        RenameDialog->resize(750, 550);
        verticalLayout = new QVBoxLayout(RenameDialog);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        newNameLabel = new QLabel(RenameDialog);
        newNameLabel->setObjectName("newNameLabel");

        horizontalLayout->addWidget(newNameLabel);

        edit = new QLineEdit(RenameDialog);
        edit->setObjectName("edit");

        horizontalLayout->addWidget(edit);

        goButton = new QPushButton(RenameDialog);
        goButton->setObjectName("goButton");

        horizontalLayout->addWidget(goButton);

        cancelButton = new QPushButton(RenameDialog);
        cancelButton->setObjectName("cancelButton");

        horizontalLayout->addWidget(cancelButton);


        verticalLayout->addLayout(horizontalLayout);

        tabWidget = new QTabWidget(RenameDialog);
        tabWidget->setObjectName("tabWidget");

        verticalLayout->addWidget(tabWidget);

#if QT_CONFIG(shortcut)
        newNameLabel->setBuddy(edit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(RenameDialog);
        QObject::connect(cancelButton, &QPushButton::clicked, RenameDialog, qOverload<>(&QDialog::reject));
        QObject::connect(goButton, &QPushButton::clicked, RenameDialog, qOverload<>(&QDialog::accept));

        tabWidget->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(RenameDialog);
    } // setupUi

    void retranslateUi(QDialog *RenameDialog)
    {
        RenameDialog->setWindowTitle(tr2i18n("Rename", "@title:window"));
        newNameLabel->setText(tr2i18n("&New name:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        goButton->setToolTip(tr2i18n("<html><head/><body><p>&quot;Note: All overloaded functions, overloads, forward-declarations, etc. will be renamed too&quot;</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        goButton->setText(tr2i18n("&Rename", "@action:button"));
        cancelButton->setText(tr2i18n("&Cancel", "@action:button"));
    } // retranslateUi

};

namespace Ui {
    class RenameDialog: public Ui_RenameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BASICREFACTORING_H

