/****************************************************************************
** Meta object code from reading C++ file 'documentcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/shell/documentcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documentcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop18DocumentControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::DocumentController::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop18DocumentControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::DocumentController",
        "D-Bus Interface",
        "org.kdevelop.DocumentController",
        "openDocument",
        "IDocument*",
        "",
        "QUrl",
        "url",
        "KTextEditor::Range",
        "range",
        "DocumentActivationParams",
        "activationParams",
        "encoding",
        "buddy",
        "openDocumentFromText",
        "data",
        "KDevelop::IDocument*",
        "prefName",
        "fileClose",
        "slotSaveAllDocuments",
        "closeAllDocuments",
        "closeAllOtherDocuments",
        "reloadAllDocuments",
        "openDocumentSimple",
        "line",
        "column",
        "openDocumentsSimple",
        "urls",
        "openDocumentFromTextSimple",
        "text",
        "activeDocumentPath",
        "target",
        "activeDocumentPaths",
        "vcsAnnotateCurrentDocument",
        "slotOpenDocument",
        "notifyDocumentClosed",
        "Sublime::Document*",
        "doc"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'openDocument'
        QtMocHelpers::SlotData<IDocument *(const QUrl &, const KTextEditor::Range &, DocumentActivationParams, const QString &, IDocument *)>(3, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 },
            { 0x80000000 | 4, 13 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<IDocument *(const QUrl &, const KTextEditor::Range &, DocumentActivationParams, const QString &)>(3, 5, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<IDocument *(const QUrl &, const KTextEditor::Range &, DocumentActivationParams)>(3, 5, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<IDocument *(const QUrl &, const KTextEditor::Range &)>(3, 5, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<IDocument *(const QUrl &)>(3, 5, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'openDocumentFromText'
        QtMocHelpers::SlotData<IDocument *(const QString &)>(14, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const QString &)>(3, 5, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'fileClose'
        QtMocHelpers::SlotData<void()>(18, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveAllDocuments'
        QtMocHelpers::SlotData<void()>(19, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeAllDocuments'
        QtMocHelpers::SlotData<bool()>(20, 5, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'closeAllOtherDocuments'
        QtMocHelpers::SlotData<void()>(21, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadAllDocuments'
        QtMocHelpers::SlotData<void()>(22, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openDocumentSimple'
        QtMocHelpers::SlotData<bool(QString, int, int)>(23, 5, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'openDocumentSimple'
        QtMocHelpers::SlotData<bool(QString, int)>(23, 5, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'openDocumentSimple'
        QtMocHelpers::SlotData<bool(QString)>(23, 5, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'openDocumentsSimple'
        QtMocHelpers::SlotData<bool(QStringList)>(26, 5, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QStringList, 27 },
        }}),
        // Slot 'openDocumentFromTextSimple'
        QtMocHelpers::SlotData<bool(QString)>(28, 5, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'activeDocumentPath'
        QtMocHelpers::SlotData<QString(const QString &) const>(30, 5, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'activeDocumentPath'
        QtMocHelpers::SlotData<QString() const>(30, 5, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'activeDocumentPaths'
        QtMocHelpers::SlotData<QStringList() const>(32, 5, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Slot 'vcsAnnotateCurrentDocument'
        QtMocHelpers::SlotData<void()>(33, 5, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenDocument'
        QtMocHelpers::SlotData<void(const QUrl &)>(34, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'notifyDocumentClosed'
        QtMocHelpers::SlotData<void(Sublime::Document *)>(35, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DocumentController, qt_meta_tag_ZN8KDevelop18DocumentControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KDevelop::DocumentController::staticMetaObject = { {
    QMetaObject::SuperData::link<IDocumentController::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18DocumentControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18DocumentControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop18DocumentControllerE_t>.metaTypes,
    nullptr
} };

void KDevelop::DocumentController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[5])));
            if (_a[0]) *reinterpret_cast<IDocument**>(_a[0]) = std::move(_r); }  break;
        case 1: { IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<IDocument**>(_a[0]) = std::move(_r); }  break;
        case 2: { IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])));
            if (_a[0]) *reinterpret_cast<IDocument**>(_a[0]) = std::move(_r); }  break;
        case 3: { IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])));
            if (_a[0]) *reinterpret_cast<IDocument**>(_a[0]) = std::move(_r); }  break;
        case 4: { IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<IDocument**>(_a[0]) = std::move(_r); }  break;
        case 5: { IDocument* _r = _t->openDocumentFromText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<IDocument**>(_a[0]) = std::move(_r); }  break;
        case 6: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->fileClose(); break;
        case 8: _t->slotSaveAllDocuments(); break;
        case 9: { bool _r = _t->closeAllDocuments();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->closeAllOtherDocuments(); break;
        case 11: _t->reloadAllDocuments(); break;
        case 12: { bool _r = _t->openDocumentSimple((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->openDocumentSimple((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->openDocumentSimple((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->openDocumentsSimple((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->openDocumentFromTextSimple((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->activeDocumentPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: { QString _r = _t->activeDocumentPath();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 19: { QStringList _r = _t->activeDocumentPaths();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->vcsAnnotateCurrentDocument(); break;
        case 21: _t->slotOpenDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 22: _t->notifyDocumentClosed((*reinterpret_cast<std::add_pointer_t<Sublime::Document*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::DocumentController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::DocumentController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18DocumentControllerE_t>.strings))
        return static_cast<void*>(this);
    return IDocumentController::qt_metacast(_clname);
}

int KDevelop::DocumentController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IDocumentController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}
QT_WARNING_POP
