/****************************************************************************
** Meta object code from reading C++ file 'mainwindow_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/shell/mainwindow_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop17MainWindowPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::MainWindowPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop17MainWindowPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::MainWindowPrivate",
        "addPlugin",
        "",
        "KDevelop::IPlugin*",
        "plugin",
        "removePlugin",
        "updateSourceFormatterGuiClient",
        "hasFormatters",
        "activePartChanged",
        "KParts::Part*",
        "part",
        "mergeView",
        "Sublime::View*",
        "view",
        "changeActiveView",
        "xmlguiclientDestroyed",
        "obj",
        "fileNew",
        "gotoNextWindow",
        "gotoPreviousWindow",
        "selectPrevItem",
        "selectNextItem",
        "viewAddNewToolView",
        "newWindow",
        "splitHorizontal",
        "splitVertical",
        "split",
        "Qt::Orientation",
        "orientation",
        "toggleFullScreen",
        "fullScreen",
        "gotoNextSplit",
        "gotoPreviousSplit",
        "settingsDialog",
        "quitAll",
        "configureNotifications",
        "showLoadedPlugins",
        "toggleArea",
        "b",
        "showErrorMessage",
        "message",
        "timeout",
        "pluginDestroyed",
        "contextMenuFileNew",
        "contextMenuSplitHorizontal",
        "contextMenuSplitVertical",
        "reloadAll",
        "kateWrapper",
        "KTextEditorIntegration::MainWindow*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addPlugin'
        QtMocHelpers::SlotData<void(KDevelop::IPlugin *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'removePlugin'
        QtMocHelpers::SlotData<void(KDevelop::IPlugin *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'updateSourceFormatterGuiClient'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'activePartChanged'
        QtMocHelpers::SlotData<void(KParts::Part *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'mergeView'
        QtMocHelpers::SlotData<void(Sublime::View *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'changeActiveView'
        QtMocHelpers::SlotData<void(Sublime::View *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'xmlguiclientDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 16 },
        }}),
        // Slot 'fileNew'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoNextWindow'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoPreviousWindow'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectPrevItem'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectNextItem'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'viewAddNewToolView'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newWindow'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'splitHorizontal'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'splitVertical'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'split'
        QtMocHelpers::SlotData<void(Qt::Orientation)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'toggleFullScreen'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'gotoNextSplit'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoPreviousSplit'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'settingsDialog'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quitAll'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configureNotifications'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showLoadedPlugins'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleArea'
        QtMocHelpers::SlotData<void(bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'showErrorMessage'
        QtMocHelpers::SlotData<void(const QString &, int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 40 }, { QMetaType::Int, 41 },
        }}),
        // Slot 'pluginDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 },
        }}),
        // Slot 'contextMenuFileNew'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'contextMenuSplitHorizontal'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'contextMenuSplitVertical'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadAll'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'kateWrapper'
        QtMocHelpers::SlotData<KTextEditorIntegration::MainWindow *() const>(47, 2, QMC::AccessPublic, 0x80000000 | 48),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindowPrivate, qt_meta_tag_ZN8KDevelop17MainWindowPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::MainWindowPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17MainWindowPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17MainWindowPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop17MainWindowPrivateE_t>.metaTypes,
    nullptr
} };

void KDevelop::MainWindowPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindowPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addPlugin((*reinterpret_cast<std::add_pointer_t<KDevelop::IPlugin*>>(_a[1]))); break;
        case 1: _t->removePlugin((*reinterpret_cast<std::add_pointer_t<KDevelop::IPlugin*>>(_a[1]))); break;
        case 2: _t->updateSourceFormatterGuiClient((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->activePartChanged((*reinterpret_cast<std::add_pointer_t<KParts::Part*>>(_a[1]))); break;
        case 4: _t->mergeView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 5: _t->changeActiveView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 6: _t->xmlguiclientDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 7: _t->fileNew(); break;
        case 8: _t->gotoNextWindow(); break;
        case 9: _t->gotoPreviousWindow(); break;
        case 10: _t->selectPrevItem(); break;
        case 11: _t->selectNextItem(); break;
        case 12: _t->viewAddNewToolView(); break;
        case 13: _t->newWindow(); break;
        case 14: _t->splitHorizontal(); break;
        case 15: _t->splitVertical(); break;
        case 16: _t->split((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1]))); break;
        case 17: _t->toggleFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->gotoNextSplit(); break;
        case 19: _t->gotoPreviousSplit(); break;
        case 20: _t->settingsDialog(); break;
        case 21: _t->quitAll(); break;
        case 22: _t->configureNotifications(); break;
        case 23: _t->showLoadedPlugins(); break;
        case 24: _t->toggleArea((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 26: _t->pluginDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 27: _t->contextMenuFileNew(); break;
        case 28: _t->contextMenuSplitHorizontal(); break;
        case 29: _t->contextMenuSplitVertical(); break;
        case 30: _t->reloadAll(); break;
        case 31: { KTextEditorIntegration::MainWindow* _r = _t->kateWrapper();
            if (_a[0]) *reinterpret_cast<KTextEditorIntegration::MainWindow**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::MainWindowPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::MainWindowPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17MainWindowPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::MainWindowPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}
QT_WARNING_POP
