// This file is generated by kconfig_compiler_kf6 from customdefinesandincludes.kcfg.
// All changes you do to this file will be lost.
#ifndef CUSTOMDEFINESANDINCLUDES_H
#define CUSTOMDEFINESANDINCLUDES_H

#include <project/projectconfigskeleton.h>

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class CustomDefinesAndIncludes : public KDevelop::ProjectConfigSkeleton
{
  public:

    static CustomDefinesAndIncludes *self();
    static void instance(const QString& cfgfilename);
    static void instance(KSharedConfig::Ptr config);
    ~CustomDefinesAndIncludes() override;

    /**
      Get reparse
    */
    static
    bool reparse()
    {
      return self()->mReparse;
    }

    /**
      Is reparse Immutable
    */
    static
    bool isReparseImmutable()
    {
      return self()->isImmutable( QStringLiteral( "reparse" ) );
    }

  protected:
    CustomDefinesAndIncludes(KSharedConfig::Ptr config);
    friend class CustomDefinesAndIncludesHelper;


    // Defines And Includes
    bool mReparse;
};

#endif

