/********************************************************************************
** Form generated from reading UI file 'processselection.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROCESSSELECTION_H
#define UI_PROCESSSELECTION_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "KLineEdit"

QT_BEGIN_NAMESPACE

class Ui_ProcessSelection
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    KLineEdit *filterEdit;
    QToolButton *buttonList;
    QToolButton *buttonTree;
    QComboBox *processesCombo;
    QTreeView *view;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ProcessSelection)
    {
        if (ProcessSelection->objectName().isEmpty())
            ProcessSelection->setObjectName("ProcessSelection");
        ProcessSelection->resize(740, 720);
        verticalLayout = new QVBoxLayout(ProcessSelection);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, -1, -1, 0);
        filterEdit = new KLineEdit(ProcessSelection);
        filterEdit->setObjectName("filterEdit");
        filterEdit->setProperty("showClearButton", QVariant(true));

        horizontalLayout->addWidget(filterEdit);

        buttonList = new QToolButton(ProcessSelection);
        buttonList->setObjectName("buttonList");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("view-list-details")));
        buttonList->setIcon(icon);
        buttonList->setIconSize(QSize(22, 22));
        buttonList->setCheckable(true);
        buttonList->setChecked(true);

        horizontalLayout->addWidget(buttonList);

        buttonTree = new QToolButton(ProcessSelection);
        buttonTree->setObjectName("buttonTree");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("view-list-tree")));
        buttonTree->setIcon(icon1);
        buttonTree->setIconSize(QSize(22, 22));
        buttonTree->setCheckable(true);

        horizontalLayout->addWidget(buttonTree);

        processesCombo = new QComboBox(ProcessSelection);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("view-process-own")));
        processesCombo->addItem(icon2, QString());
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("view-process-users")));
        processesCombo->addItem(icon3, QString());
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("view-process-system")));
        processesCombo->addItem(icon4, QString());
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("view-process-all")));
        processesCombo->addItem(icon5, QString());
        processesCombo->setObjectName("processesCombo");
        processesCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        horizontalLayout->addWidget(processesCombo);


        verticalLayout->addLayout(horizontalLayout);

        view = new QTreeView(ProcessSelection);
        view->setObjectName("view");
        view->setAlternatingRowColors(true);
        view->setUniformRowHeights(true);
        view->setSortingEnabled(true);
        view->header()->setProperty("showSortIndicator", QVariant(true));

        verticalLayout->addWidget(view);

        buttonBox = new QDialogButtonBox(ProcessSelection);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ProcessSelection);

        QMetaObject::connectSlotsByName(ProcessSelection);
    } // setupUi

    void retranslateUi(QDialog *ProcessSelection)
    {
        ProcessSelection->setWindowTitle(tr2i18n("Attach to a Process", "@title:window"));
        filterEdit->setPlaceholderText(tr2i18n("Search", "@info:placeholder"));
#if QT_CONFIG(tooltip)
        buttonList->setToolTip(tr2i18n("Display as List", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        buttonTree->setToolTip(tr2i18n("Display as Tree", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        processesCombo->setItemText(0, tr2i18n("Own Processes", "@item:inlistbox"));
        processesCombo->setItemText(1, tr2i18n("User Processes", "@item:inlistbox"));
        processesCombo->setItemText(2, tr2i18n("System Processes", "@item:inlistbox"));
        processesCombo->setItemText(3, tr2i18n("All Processes", "@item:inlistbox"));

    } // retranslateUi

};

namespace Ui {
    class ProcessSelection: public Ui_ProcessSelection {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROCESSSELECTION_H

