/********************************************************************************
** Form generated from reading UI file 'mesonrewriteroptioncontainer.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONREWRITEROPTIONCONTAINER_H
#define UI_MESONREWRITEROPTIONCONTAINER_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MesonRewriterOptionContainer
{
public:
    QHBoxLayout *h_layout;
    QToolButton *b_delete;

    void setupUi(QWidget *MesonRewriterOptionContainer)
    {
        if (MesonRewriterOptionContainer->objectName().isEmpty())
            MesonRewriterOptionContainer->setObjectName("MesonRewriterOptionContainer");
        MesonRewriterOptionContainer->resize(500, 32);
        h_layout = new QHBoxLayout(MesonRewriterOptionContainer);
        h_layout->setObjectName("h_layout");
        h_layout->setContentsMargins(0, 0, 0, 0);
        b_delete = new QToolButton(MesonRewriterOptionContainer);
        b_delete->setObjectName("b_delete");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        b_delete->setIcon(icon);

        h_layout->addWidget(b_delete);


        retranslateUi(MesonRewriterOptionContainer);
        QObject::connect(b_delete, SIGNAL(clicked()), MesonRewriterOptionContainer, SLOT(deleteMe()));

        QMetaObject::connectSlotsByName(MesonRewriterOptionContainer);
    } // setupUi

    void retranslateUi(QWidget *MesonRewriterOptionContainer)
    {
        (void)MesonRewriterOptionContainer;
    } // retranslateUi

};

namespace Ui {
    class MesonRewriterOptionContainer: public Ui_MesonRewriterOptionContainer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONREWRITEROPTIONCONTAINER_H

