/********************************************************************************
** Form generated from reading UI file 'globalconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GLOBALCONFIGPAGE_H
#define UI_GLOBALCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "KUrlRequester"
#include "config/checksetmanagewidget.h"

namespace Clazy {

class Ui_GlobalConfigPage
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *pathBox;
    QFormLayout *formLayout;
    QLabel *executableLabel;
    KUrlRequester *kcfg_executablePath;
    QLabel *docsLabel;
    KUrlRequester *kcfg_docsPath;
    QLabel *checksInfoLabel;
    QGroupBox *jobsBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_parallelJobsEnabled;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_parallelJobsAutoCount;
    QSpacerItem *horizontalSpacer;
    QLabel *parallelJobsFixedCountLabel;
    QSpinBox *kcfg_parallelJobsFixedCount;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_hideOutputView;
    QCheckBox *kcfg_verboseOutput;
    KMessageWidget *errorWidget;
    Clazy::CheckSetManageWidget *checksets;

    void setupUi(QWidget *Clazy__GlobalConfigPage)
    {
        if (Clazy__GlobalConfigPage->objectName().isEmpty())
            Clazy__GlobalConfigPage->setObjectName("Clazy__GlobalConfigPage");
        Clazy__GlobalConfigPage->resize(568, 670);
        verticalLayout_3 = new QVBoxLayout(Clazy__GlobalConfigPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        pathBox = new QGroupBox(Clazy__GlobalConfigPage);
        pathBox->setObjectName("pathBox");
        formLayout = new QFormLayout(pathBox);
        formLayout->setObjectName("formLayout");
        executableLabel = new QLabel(pathBox);
        executableLabel->setObjectName("executableLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, executableLabel);

        kcfg_executablePath = new KUrlRequester(pathBox);
        kcfg_executablePath->setObjectName("kcfg_executablePath");
        kcfg_executablePath->setMode(KFile::ExistingOnly|KFile::File|KFile::LocalOnly);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_executablePath);

        docsLabel = new QLabel(pathBox);
        docsLabel->setObjectName("docsLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, docsLabel);

        kcfg_docsPath = new KUrlRequester(pathBox);
        kcfg_docsPath->setObjectName("kcfg_docsPath");
        kcfg_docsPath->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_docsPath);

        checksInfoLabel = new QLabel(pathBox);
        checksInfoLabel->setObjectName("checksInfoLabel");
        checksInfoLabel->setText(QString::fromUtf8("checksInfoLabel"));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, checksInfoLabel);


        verticalLayout_3->addWidget(pathBox);

        jobsBox = new QGroupBox(Clazy__GlobalConfigPage);
        jobsBox->setObjectName("jobsBox");
        jobsBox->setTitle(QString::fromUtf8(""));
        verticalLayout = new QVBoxLayout(jobsBox);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_parallelJobsEnabled = new QCheckBox(jobsBox);
        kcfg_parallelJobsEnabled->setObjectName("kcfg_parallelJobsEnabled");

        verticalLayout->addWidget(kcfg_parallelJobsEnabled);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_parallelJobsAutoCount = new QCheckBox(jobsBox);
        kcfg_parallelJobsAutoCount->setObjectName("kcfg_parallelJobsAutoCount");

        horizontalLayout->addWidget(kcfg_parallelJobsAutoCount);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        parallelJobsFixedCountLabel = new QLabel(jobsBox);
        parallelJobsFixedCountLabel->setObjectName("parallelJobsFixedCountLabel");

        horizontalLayout->addWidget(parallelJobsFixedCountLabel);

        kcfg_parallelJobsFixedCount = new QSpinBox(jobsBox);
        kcfg_parallelJobsFixedCount->setObjectName("kcfg_parallelJobsFixedCount");
        kcfg_parallelJobsFixedCount->setMinimum(1);

        horizontalLayout->addWidget(kcfg_parallelJobsFixedCount);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_3->addWidget(jobsBox);

        groupBox = new QGroupBox(Clazy__GlobalConfigPage);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_hideOutputView = new QCheckBox(groupBox);
        kcfg_hideOutputView->setObjectName("kcfg_hideOutputView");

        verticalLayout_2->addWidget(kcfg_hideOutputView);

        kcfg_verboseOutput = new QCheckBox(groupBox);
        kcfg_verboseOutput->setObjectName("kcfg_verboseOutput");

        verticalLayout_2->addWidget(kcfg_verboseOutput);


        verticalLayout_3->addWidget(groupBox);

        errorWidget = new KMessageWidget(Clazy__GlobalConfigPage);
        errorWidget->setObjectName("errorWidget");
        errorWidget->setText(QString::fromUtf8("errorWidget"));
        errorWidget->setWordWrap(true);
        errorWidget->setCloseButtonVisible(false);
        errorWidget->setMessageType(KMessageWidget::Error);

        verticalLayout_3->addWidget(errorWidget);

        checksets = new Clazy::CheckSetManageWidget(Clazy__GlobalConfigPage);
        checksets->setObjectName("checksets");

        verticalLayout_3->addWidget(checksets);


        retranslateUi(Clazy__GlobalConfigPage);

        QMetaObject::connectSlotsByName(Clazy__GlobalConfigPage);
    } // setupUi

    void retranslateUi(QWidget *Clazy__GlobalConfigPage)
    {
        pathBox->setTitle(tr2i18n("Paths", "@title:group"));
        executableLabel->setText(tr2i18n("clazy-standalone:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        kcfg_executablePath->setToolTip(tr2i18n("Path to clazy-standalone executable.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        docsLabel->setText(tr2i18n("Documentation:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        kcfg_docsPath->setToolTip(tr2i18n("Path to clazy documentation directory.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_parallelJobsEnabled->setText(tr2i18n("Run analysis jobs in parallel", "@option:check"));
        kcfg_parallelJobsAutoCount->setText(tr2i18n("Use all CPU cores", "@option:check"));
        parallelJobsFixedCountLabel->setText(tr2i18n("Maximum number of threads:", "@label:spinbox"));
        groupBox->setTitle(tr2i18n("Output", "@title:group"));
        kcfg_hideOutputView->setText(tr2i18n("Hide output view during check", "@option:check"));
        kcfg_verboseOutput->setText(tr2i18n("Verbose output", "@option:check"));
        (void)Clazy__GlobalConfigPage;
    } // retranslateUi

};

} // namespace Clazy

namespace Clazy {
namespace Ui {
    class GlobalConfigPage: public Ui_GlobalConfigPage {};
} // namespace Ui
} // namespace Clazy

#endif // GLOBALCONFIGPAGE_H

