/********************************************************************************
** Form generated from reading UI file 'bgpreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BGPREFERENCES_H
#define UI_BGPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BGPreferences
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *kcfg_enable;
    QFormLayout *formLayout_2;
    QLabel *label;
    QSpinBox *kcfg_delay;
    QLabel *label_3;
    QSpinBox *kcfg_threads;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *BGPreferences)
    {
        if (BGPreferences->objectName().isEmpty())
            BGPreferences->setObjectName("BGPreferences");
        BGPreferences->resize(475, 402);
        verticalLayout = new QVBoxLayout(BGPreferences);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_enable = new QGroupBox(BGPreferences);
        kcfg_enable->setObjectName("kcfg_enable");
        kcfg_enable->setCheckable(true);
        kcfg_enable->setChecked(true);
        formLayout_2 = new QFormLayout(kcfg_enable);
        formLayout_2->setObjectName("formLayout_2");
        label = new QLabel(kcfg_enable);
        label->setObjectName("label");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        kcfg_delay = new QSpinBox(kcfg_enable);
        kcfg_delay->setObjectName("kcfg_delay");
        kcfg_delay->setMaximum(5000);
        kcfg_delay->setValue(500);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_delay);

        label_3 = new QLabel(kcfg_enable);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_threads = new QSpinBox(kcfg_enable);
        kcfg_threads->setObjectName("kcfg_threads");
        kcfg_threads->setMinimum(1);
        kcfg_threads->setMaximum(32);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_threads);


        verticalLayout->addWidget(kcfg_enable);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        retranslateUi(BGPreferences);

        QMetaObject::connectSlotsByName(BGPreferences);
    } // setupUi

    void retranslateUi(QWidget *BGPreferences)
    {
#if QT_CONFIG(tooltip)
        kcfg_enable->setToolTip(tr2i18n("<p>Enables or disables the background parser.<br>If unsure, leave it enabled. Disabling the background parser will disable large parts of KDevelop's functionality.</p>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_enable->setTitle(tr2i18n("Enable Background Parser", "@title:group"));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("The time to wait before the document is re-analyzed when you edit it.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Delay:", "@label:spinbox"));
#if QT_CONFIG(tooltip)
        kcfg_delay->setToolTip(tr2i18n("The time to wait before the document is re-analyzed when you edit it.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_delay->setSuffix(tr2i18n(" ms", "@item:valuesuffix"));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("The maximum number of parallel instances the background parser uses. If unsure, select 1 or 2.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Maximum number of threads:", "@label:spinbox"));
#if QT_CONFIG(tooltip)
        kcfg_threads->setToolTip(tr2i18n("The maximum number of parallel instances the background parser uses. If unsure, select 1 or 2.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_threads->setSuffix(tr2i18n(" threads", "@item:valuesuffix"));
        (void)BGPreferences;
    } // retranslateUi

};

namespace Ui {
    class BGPreferences: public Ui_BGPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BGPREFERENCES_H

