/********************************************************************************
** Form generated from reading UI file 'dockerpreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOCKERPREFERENCES_H
#define UI_DOCKERPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DockerPreferences
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QLineEdit *kcfg_extraArguments;
    QLabel *label_2;
    QLineEdit *kcfg_projectsVolume;

    void setupUi(QWidget *DockerPreferences)
    {
        if (DockerPreferences->objectName().isEmpty())
            DockerPreferences->setObjectName("DockerPreferences");
        DockerPreferences->resize(400, 300);
        formLayout = new QFormLayout(DockerPreferences);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(DockerPreferences);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        kcfg_extraArguments = new QLineEdit(DockerPreferences);
        kcfg_extraArguments->setObjectName("kcfg_extraArguments");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_extraArguments);

        label_2 = new QLabel(DockerPreferences);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_projectsVolume = new QLineEdit(DockerPreferences);
        kcfg_projectsVolume->setObjectName("kcfg_projectsVolume");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_projectsVolume);


        retranslateUi(DockerPreferences);

        QMetaObject::connectSlotsByName(DockerPreferences);
    } // setupUi

    void retranslateUi(QWidget *DockerPreferences)
    {
        label->setText(tr2i18n("'docker run' arguments:", "@label:textbox"));
        label_2->setText(tr2i18n("Projects volume:", "@label:textbox"));
        (void)DockerPreferences;
    } // retranslateUi

};

namespace Ui {
    class DockerPreferences: public Ui_DockerPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DOCKERPREFERENCES_H

