/****************************************************************************
** Meta object code from reading C++ file 'abstractfilemanagerplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/project/abstractfilemanagerplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractfilemanagerplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop25AbstractFileManagerPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::AbstractFileManagerPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop25AbstractFileManagerPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::AbstractFileManagerPlugin",
        "reloadedFileItem",
        "",
        "KDevelop::ProjectFileItem*",
        "file",
        "reloadedFolderItem",
        "KDevelop::ProjectFolderItem*",
        "folder",
        "folderAdded",
        "folderRemoved",
        "folderRenamed",
        "KDevelop::Path",
        "oldFolder",
        "newFolder",
        "fileAdded",
        "fileRemoved",
        "fileRenamed",
        "oldFile",
        "newFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reloadedFileItem'
        QtMocHelpers::SignalData<void(KDevelop::ProjectFileItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'reloadedFolderItem'
        QtMocHelpers::SignalData<void(KDevelop::ProjectFolderItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'folderAdded'
        QtMocHelpers::SignalData<void(KDevelop::ProjectFolderItem *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'folderRemoved'
        QtMocHelpers::SignalData<void(KDevelop::ProjectFolderItem *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'folderRenamed'
        QtMocHelpers::SignalData<void(const KDevelop::Path &, KDevelop::ProjectFolderItem *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 6, 13 },
        }}),
        // Signal 'fileAdded'
        QtMocHelpers::SignalData<void(KDevelop::ProjectFileItem *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fileRemoved'
        QtMocHelpers::SignalData<void(KDevelop::ProjectFileItem *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fileRenamed'
        QtMocHelpers::SignalData<void(const KDevelop::Path &, KDevelop::ProjectFileItem *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 17 }, { 0x80000000 | 3, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractFileManagerPlugin, qt_meta_tag_ZN8KDevelop25AbstractFileManagerPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::AbstractFileManagerPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25AbstractFileManagerPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25AbstractFileManagerPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop25AbstractFileManagerPluginE_t>.metaTypes,
    nullptr
} };

void KDevelop::AbstractFileManagerPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractFileManagerPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reloadedFileItem((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[1]))); break;
        case 1: _t->reloadedFolderItem((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFolderItem*>>(_a[1]))); break;
        case 2: _t->folderAdded((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFolderItem*>>(_a[1]))); break;
        case 3: _t->folderRemoved((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFolderItem*>>(_a[1]))); break;
        case 4: _t->folderRenamed((*reinterpret_cast<std::add_pointer_t<KDevelop::Path>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFolderItem*>>(_a[2]))); break;
        case 5: _t->fileAdded((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[1]))); break;
        case 6: _t->fileRemoved((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[1]))); break;
        case 7: _t->fileRenamed((*reinterpret_cast<std::add_pointer_t<KDevelop::Path>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::Path >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::Path >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractFileManagerPlugin::*)(KDevelop::ProjectFileItem * )>(_a, &AbstractFileManagerPlugin::reloadedFileItem, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileManagerPlugin::*)(KDevelop::ProjectFolderItem * )>(_a, &AbstractFileManagerPlugin::reloadedFolderItem, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileManagerPlugin::*)(KDevelop::ProjectFolderItem * )>(_a, &AbstractFileManagerPlugin::folderAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileManagerPlugin::*)(KDevelop::ProjectFolderItem * )>(_a, &AbstractFileManagerPlugin::folderRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileManagerPlugin::*)(const KDevelop::Path & , KDevelop::ProjectFolderItem * )>(_a, &AbstractFileManagerPlugin::folderRenamed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileManagerPlugin::*)(KDevelop::ProjectFileItem * )>(_a, &AbstractFileManagerPlugin::fileAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileManagerPlugin::*)(KDevelop::ProjectFileItem * )>(_a, &AbstractFileManagerPlugin::fileRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileManagerPlugin::*)(const KDevelop::Path & , KDevelop::ProjectFileItem * )>(_a, &AbstractFileManagerPlugin::fileRenamed, 7))
            return;
    }
}

const QMetaObject *KDevelop::AbstractFileManagerPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::AbstractFileManagerPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25AbstractFileManagerPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IProjectFileManager"))
        return static_cast< IProjectFileManager*>(this);
    if (!strcmp(_clname, "org.kdevelop.IProjectFileManager"))
        return static_cast< KDevelop::IProjectFileManager*>(this);
    return IPlugin::qt_metacast(_clname);
}

int KDevelop::AbstractFileManagerPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::AbstractFileManagerPlugin::reloadedFileItem(KDevelop::ProjectFileItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevelop::AbstractFileManagerPlugin::reloadedFolderItem(KDevelop::ProjectFolderItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDevelop::AbstractFileManagerPlugin::folderAdded(KDevelop::ProjectFolderItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDevelop::AbstractFileManagerPlugin::folderRemoved(KDevelop::ProjectFolderItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KDevelop::AbstractFileManagerPlugin::folderRenamed(const KDevelop::Path & _t1, KDevelop::ProjectFolderItem * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KDevelop::AbstractFileManagerPlugin::fileAdded(KDevelop::ProjectFileItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KDevelop::AbstractFileManagerPlugin::fileRemoved(KDevelop::ProjectFileItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KDevelop::AbstractFileManagerPlugin::fileRenamed(const KDevelop::Path & _t1, KDevelop::ProjectFileItem * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
