/********************************************************************************
** Form generated from reading UI file 'sourceformattersettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SOURCEFORMATTERSETTINGS_H
#define UI_SOURCEFORMATTERSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "sourceformatterselectionedit.h"

QT_BEGIN_NAMESPACE

class Ui_SourceFormatterSettingsUI
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *chkKateOverrideIndentation;
    QCheckBox *chkKateModelines;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    KDevelop::SourceFormatterSelectionEdit *formatterSelectionEdit;

    void setupUi(QWidget *SourceFormatterSettingsUI)
    {
        if (SourceFormatterSettingsUI->objectName().isEmpty())
            SourceFormatterSettingsUI->setObjectName("SourceFormatterSettingsUI");
        SourceFormatterSettingsUI->resize(636, 632);
        verticalLayout_3 = new QVBoxLayout(SourceFormatterSettingsUI);
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        groupBox_2 = new QGroupBox(SourceFormatterSettingsUI);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        chkKateOverrideIndentation = new QCheckBox(groupBox_2);
        chkKateOverrideIndentation->setObjectName("chkKateOverrideIndentation");

        verticalLayout_2->addWidget(chkKateOverrideIndentation);

        chkKateModelines = new QCheckBox(groupBox_2);
        chkKateModelines->setObjectName("chkKateModelines");

        verticalLayout_2->addWidget(chkKateModelines);


        verticalLayout_3->addWidget(groupBox_2);

        groupBox = new QGroupBox(SourceFormatterSettingsUI);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(200);
        sizePolicy.setVerticalStretch(129);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        formatterSelectionEdit = new KDevelop::SourceFormatterSelectionEdit(groupBox);
        formatterSelectionEdit->setObjectName("formatterSelectionEdit");

        verticalLayout->addWidget(formatterSelectionEdit);


        verticalLayout_3->addWidget(groupBox);


        retranslateUi(SourceFormatterSettingsUI);

        QMetaObject::connectSlotsByName(SourceFormatterSettingsUI);
    } // setupUi

    void retranslateUi(QWidget *SourceFormatterSettingsUI)
    {
        groupBox_2->setTitle(tr2i18n("General", "@title:group"));
#if QT_CONFIG(tooltip)
        chkKateOverrideIndentation->setToolTip(tr2i18n("Override the editor indentation mode according to the formatting style for documents without Kate modeline.", "@info:tolltip"));
#endif // QT_CONFIG(tooltip)
        chkKateOverrideIndentation->setText(tr2i18n("Override Kate Indentation Mode", "@option:check"));
#if QT_CONFIG(tooltip)
        chkKateModelines->setToolTip(tr2i18n("Add a Kate modeline according to the formatting style to formatted documents.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        chkKateModelines->setText(tr2i18n("Add Kate Modeline", "@option:check"));
        groupBox->setTitle(tr2i18n("Formatting Styles", "@title:group"));
        (void)SourceFormatterSettingsUI;
    } // retranslateUi

};

namespace Ui {
    class SourceFormatterSettingsUI: public Ui_SourceFormatterSettingsUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SOURCEFORMATTERSETTINGS_H

