/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/shell/mainwindow.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::MainWindow",
        "D-Bus Interface",
        "org.kdevelop.MainWindow",
        "showErrorMessage",
        "",
        "message",
        "timeout",
        "ensureVisible",
        "windowTitle",
        "configureShortcuts",
        "tabContextMenuRequested",
        "Sublime::View*",
        "QMenu*",
        "tabToolTipRequested",
        "view",
        "Sublime::Container*",
        "container",
        "tab",
        "dockBarContextMenuRequested",
        "Qt::DockWidgetArea",
        "QPoint",
        "newTabRequested",
        "saveNewToolbarConfig",
        "documentActivated",
        "QPointer<KTextEditor::Document>",
        "textDocument",
        "updateCaption",
        "updateTabColor",
        "IDocument*",
        "doc",
        "updateAllTabColors",
        "shortcutsChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showErrorMessage'
        QtMocHelpers::SlotData<void(const QString &, int)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'ensureVisible'
        QtMocHelpers::SlotData<void()>(7, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'windowTitle'
        QtMocHelpers::SlotData<QString()>(8, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Slot 'configureShortcuts'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tabContextMenuRequested'
        QtMocHelpers::SlotData<void(Sublime::View *, QMenu *)>(10, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 4 }, { 0x80000000 | 12, 4 },
        }}),
        // Slot 'tabToolTipRequested'
        QtMocHelpers::SlotData<void(Sublime::View *, Sublime::Container *, int)>(13, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'dockBarContextMenuRequested'
        QtMocHelpers::SlotData<void(Qt::DockWidgetArea, const QPoint &)>(18, 4, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 19, 4 }, { 0x80000000 | 20, 4 },
        }}),
        // Slot 'newTabRequested'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'saveNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessProtected, QMetaType::Void),
        // Slot 'documentActivated'
        QtMocHelpers::SlotData<void(const QPointer<KTextEditor::Document> &)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'updateCaption'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTabColor'
        QtMocHelpers::SlotData<void(IDocument *)>(27, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'updateAllTabColors'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'shortcutsChanged'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN8KDevelop10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KDevelop::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<Sublime::MainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop10MainWindowE_t>.metaTypes,
    nullptr
} };

void KDevelop::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->ensureVisible(); break;
        case 2: { QString _r = _t->windowTitle();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->configureShortcuts(); break;
        case 4: _t->tabContextMenuRequested((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2]))); break;
        case 5: _t->tabToolTipRequested((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Container*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->dockBarContextMenuRequested((*reinterpret_cast<std::add_pointer_t<Qt::DockWidgetArea>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 7: _t->newTabRequested(); break;
        case 8: _t->saveNewToolbarConfig(); break;
        case 9: _t->documentActivated((*reinterpret_cast<std::add_pointer_t<QPointer<KTextEditor::Document>>>(_a[1]))); break;
        case 10: _t->updateCaption(); break;
        case 11: _t->updateTabColor((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1]))); break;
        case 12: _t->updateAllTabColors(); break;
        case 13: _t->shortcutsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QMenu* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KDevelop::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return Sublime::MainWindow::qt_metacast(_clname);
}

int KDevelop::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Sublime::MainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
