/****************************************************************************
** Meta object code from reading C++ file 'checksetselectionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/plugins/clangtidy/checksetselectionmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'checksetselectionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9ClangTidy24CheckSetSelectionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ClangTidy::CheckSetSelectionManager::qt_create_metaobjectdata<qt_meta_tag_ZN9ClangTidy24CheckSetSelectionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ClangTidy::CheckSetSelectionManager",
        "checkSetSelectionsChanged",
        "",
        "QList<CheckSetSelection>",
        "checkSetSelections",
        "checkSetSelectionsRemoved",
        "checkSetSelectionIds",
        "defaultCheckSetSelectionChanged",
        "checkSetSelectionId",
        "checkSetSelectionsLocked",
        "checkSetSelectionsUnlocked",
        "onCheckSetSelectionsFolderChanged",
        "path",
        "onDefaultCheckSetSelectionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checkSetSelectionsChanged'
        QtMocHelpers::SignalData<void(const QVector<CheckSetSelection> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'checkSetSelectionsRemoved'
        QtMocHelpers::SignalData<void(const QVector<QString> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'defaultCheckSetSelectionChanged'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'checkSetSelectionsLocked'
        QtMocHelpers::SignalData<void(const QVector<QString> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'checkSetSelectionsUnlocked'
        QtMocHelpers::SignalData<void(const QVector<QString> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Slot 'onCheckSetSelectionsFolderChanged'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'onDefaultCheckSetSelectionChanged'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CheckSetSelectionManager, qt_meta_tag_ZN9ClangTidy24CheckSetSelectionManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ClangTidy::CheckSetSelectionManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ClangTidy24CheckSetSelectionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ClangTidy24CheckSetSelectionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9ClangTidy24CheckSetSelectionManagerE_t>.metaTypes,
    nullptr
} };

void ClangTidy::CheckSetSelectionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CheckSetSelectionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkSetSelectionsChanged((*reinterpret_cast<std::add_pointer_t<QList<CheckSetSelection>>>(_a[1]))); break;
        case 1: _t->checkSetSelectionsRemoved((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 2: _t->defaultCheckSetSelectionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->checkSetSelectionsLocked((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 4: _t->checkSetSelectionsUnlocked((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1]))); break;
        case 5: _t->onCheckSetSelectionsFolderChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->onDefaultCheckSetSelectionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CheckSetSelectionManager::*)(const QVector<CheckSetSelection> & )>(_a, &CheckSetSelectionManager::checkSetSelectionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CheckSetSelectionManager::*)(const QVector<QString> & )>(_a, &CheckSetSelectionManager::checkSetSelectionsRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CheckSetSelectionManager::*)(const QString & )>(_a, &CheckSetSelectionManager::defaultCheckSetSelectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CheckSetSelectionManager::*)(const QVector<QString> & )>(_a, &CheckSetSelectionManager::checkSetSelectionsLocked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CheckSetSelectionManager::*)(const QVector<QString> & )>(_a, &CheckSetSelectionManager::checkSetSelectionsUnlocked, 4))
            return;
    }
}

const QMetaObject *ClangTidy::CheckSetSelectionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClangTidy::CheckSetSelectionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9ClangTidy24CheckSetSelectionManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ClangTidy::CheckSetSelectionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ClangTidy::CheckSetSelectionManager::checkSetSelectionsChanged(const QVector<CheckSetSelection> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ClangTidy::CheckSetSelectionManager::checkSetSelectionsRemoved(const QVector<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ClangTidy::CheckSetSelectionManager::defaultCheckSetSelectionChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ClangTidy::CheckSetSelectionManager::checkSetSelectionsLocked(const QVector<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ClangTidy::CheckSetSelectionManager::checkSetSelectionsUnlocked(const QVector<QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
