/********************************************************************************
** Form generated from reading UI file 'gdbconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GDBCONFIGPAGE_H
#define UI_GDBCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_GdbConfigPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_3;
    QFormLayout *gridLayout;
    QLabel *gdbPath_label;
    KUrlRequester *kcfg_gdbPath;
    QLabel *debuggingShell_label;
    KUrlRequester *kcfg_debuggingShell;
    QGroupBox *groupBox_2;
    QFormLayout *formLayout;
    QLabel *label_3;
    QCheckBox *kcfg_displayStaticMembers;
    QLabel *label_2;
    QCheckBox *kcfg_asmDemangle;
    QLabel *label;
    QComboBox *kcfg_startWith;
    QGroupBox *groupBox;
    QFormLayout *formLayout1;
    QLabel *runShellScript_label;
    KUrlRequester *kcfg_runShellScript;
    QLabel *configGdbScript_label;
    KUrlRequester *kcfg_runGdbScript;
    QLabel *runGdbScript_label;
    KUrlRequester *kcfg_configGdbScript;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GdbConfigPage)
    {
        if (GdbConfigPage->objectName().isEmpty())
            GdbConfigPage->setObjectName("GdbConfigPage");
        GdbConfigPage->resize(698, 483);
        verticalLayout = new QVBoxLayout(GdbConfigPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox_3 = new QGroupBox(GdbConfigPage);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout = new QFormLayout(groupBox_3);
        gridLayout->setObjectName("gridLayout");
        gdbPath_label = new QLabel(groupBox_3);
        gdbPath_label->setObjectName("gdbPath_label");
        gdbPath_label->setWordWrap(false);

        gridLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, gdbPath_label);

        kcfg_gdbPath = new KUrlRequester(groupBox_3);
        kcfg_gdbPath->setObjectName("kcfg_gdbPath");

        gridLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_gdbPath);

        debuggingShell_label = new QLabel(groupBox_3);
        debuggingShell_label->setObjectName("debuggingShell_label");
        debuggingShell_label->setWordWrap(false);

        gridLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, debuggingShell_label);

        kcfg_debuggingShell = new KUrlRequester(groupBox_3);
        kcfg_debuggingShell->setObjectName("kcfg_debuggingShell");

        gridLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_debuggingShell);


        verticalLayout->addWidget(groupBox_3);

        groupBox_2 = new QGroupBox(GdbConfigPage);
        groupBox_2->setObjectName("groupBox_2");
        formLayout = new QFormLayout(groupBox_2);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_displayStaticMembers = new QCheckBox(groupBox_2);
        kcfg_displayStaticMembers->setObjectName("kcfg_displayStaticMembers");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_displayStaticMembers);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_asmDemangle = new QCheckBox(groupBox_2);
        kcfg_asmDemangle->setObjectName("kcfg_asmDemangle");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_asmDemangle);

        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        kcfg_startWith = new QComboBox(groupBox_2);
        kcfg_startWith->addItem(QString());
        kcfg_startWith->addItem(QString());
        kcfg_startWith->addItem(QString());
        kcfg_startWith->setObjectName("kcfg_startWith");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_startWith);


        verticalLayout->addWidget(groupBox_2);

        groupBox = new QGroupBox(GdbConfigPage);
        groupBox->setObjectName("groupBox");
        formLayout1 = new QFormLayout(groupBox);
        formLayout1->setObjectName("formLayout1");
        runShellScript_label = new QLabel(groupBox);
        runShellScript_label->setObjectName("runShellScript_label");
        runShellScript_label->setWordWrap(false);

        formLayout1->setWidget(1, QFormLayout::ItemRole::LabelRole, runShellScript_label);

        kcfg_runShellScript = new KUrlRequester(groupBox);
        kcfg_runShellScript->setObjectName("kcfg_runShellScript");

        formLayout1->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_runShellScript);

        configGdbScript_label = new QLabel(groupBox);
        configGdbScript_label->setObjectName("configGdbScript_label");
        configGdbScript_label->setWordWrap(false);

        formLayout1->setWidget(0, QFormLayout::ItemRole::LabelRole, configGdbScript_label);

        kcfg_runGdbScript = new KUrlRequester(groupBox);
        kcfg_runGdbScript->setObjectName("kcfg_runGdbScript");

        formLayout1->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_runGdbScript);

        runGdbScript_label = new QLabel(groupBox);
        runGdbScript_label->setObjectName("runGdbScript_label");
        runGdbScript_label->setWordWrap(false);

        formLayout1->setWidget(2, QFormLayout::ItemRole::LabelRole, runGdbScript_label);

        kcfg_configGdbScript = new KUrlRequester(groupBox);
        kcfg_configGdbScript->setObjectName("kcfg_configGdbScript");

        formLayout1->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_configGdbScript);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        gdbPath_label->setBuddy(kcfg_gdbPath);
        debuggingShell_label->setBuddy(kcfg_debuggingShell);
        label_3->setBuddy(kcfg_displayStaticMembers);
        label_2->setBuddy(kcfg_asmDemangle);
        label->setBuddy(kcfg_startWith);
        runShellScript_label->setBuddy(kcfg_runShellScript);
        configGdbScript_label->setBuddy(kcfg_configGdbScript);
        runGdbScript_label->setBuddy(kcfg_runGdbScript);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_gdbPath, kcfg_debuggingShell);
        QWidget::setTabOrder(kcfg_debuggingShell, kcfg_displayStaticMembers);
        QWidget::setTabOrder(kcfg_displayStaticMembers, kcfg_asmDemangle);
        QWidget::setTabOrder(kcfg_asmDemangle, kcfg_startWith);
        QWidget::setTabOrder(kcfg_startWith, kcfg_configGdbScript);
        QWidget::setTabOrder(kcfg_configGdbScript, kcfg_runShellScript);
        QWidget::setTabOrder(kcfg_runShellScript, kcfg_runGdbScript);

        retranslateUi(GdbConfigPage);

        QMetaObject::connectSlotsByName(GdbConfigPage);
    } // setupUi

    void retranslateUi(QWidget *GdbConfigPage)
    {
        groupBox_3->setTitle(tr2i18n("Debugger", "@title:group"));
        gdbPath_label->setText(tr2i18n("Debugger e&xecutable:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        kcfg_gdbPath->setToolTip(tr2i18n("Gdb executable", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_gdbPath->setWhatsThis(tr2i18n("To run \"gdb\" executable from $PATH, leave this field empty. To run custom gdb, for example, for a different architecture, enter the executable name here. You can either run gdb from $PATH, but with a different name (say, \"arm-gdb\"), by typing the name here, or specify full path to the gdb executable.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        kcfg_gdbPath->setProperty("placeholderText", QVariant(tr2i18n("Override path to gdb executable...", "@info:placeholder")));
#if QT_CONFIG(tooltip)
        debuggingShell_label->setToolTip(tr2i18n("<html><head/><body><p>If you want gdb to be executed by a special shell script, which for example properly sets the library path, insert it here e.g.: /path/to/script.sh --scriptArguments</p><p>Note: your script'll be invoked like this: /path/to/script.sh --scriptArguments debugger --debuggerArguments. So script.sh <span style=\" font-weight:600;\">must</span> invoke &quot;debugger&quot; executable manually.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        debuggingShell_label->setText(tr2i18n("She&ll script:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        kcfg_debuggingShell->setToolTip(tr2i18n("<html><head/><body><p>If you want gdb to be executed by a special shell script, which for example properly sets the library path, insert it here e.g.: /path/to/script.sh --scriptArguments</p><p>Note: your script'll be invoked like this: /path/to/script.sh --scriptArguments debugger --debuggerArguments. So script.sh <span style=\" font-weight:600;\">must</span> invoke &quot;debugger&quot; executable manually.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        groupBox_2->setTitle(tr2i18n("Options", "@title:group"));
        label_3->setText(tr2i18n("Display static &members:", "@option:check"));
#if QT_CONFIG(whatsthis)
        kcfg_displayStaticMembers->setWhatsThis(tr2i18n("Displaying static members makes GDB slower in\n"
"producing data with Qt-based code.\n"
"It may change the \"signature\" of the data\n"
"which QString and friends rely on,\n"
"but if you need to debug into these values then\n"
"check this option.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        kcfg_displayStaticMembers->setText(QString());
        label_2->setText(tr2i18n("Display &demangled names:", "@option:check"));
#if QT_CONFIG(whatsthis)
        kcfg_asmDemangle->setWhatsThis(tr2i18n("When displaying the disassembled code you\n"
"can select to see the methods' mangled names.\n"
"However, non-mangled names are easier to read.", "@info:whatthis"));
#endif // QT_CONFIG(whatsthis)
        kcfg_asmDemangle->setText(QString());
        label->setText(tr2i18n("S&tart debugger with:", "@label:listbox"));
        kcfg_startWith->setItemText(0, tr2i18n("Application Output", "@item:inlistbox start debugger with"));
        kcfg_startWith->setItemText(1, tr2i18n("GDB Console", "@item:inlistbox start debugger with"));
        kcfg_startWith->setItemText(2, tr2i18n("Frame Stack", "@item:inlistbox start debugger with"));

#if QT_CONFIG(whatsthis)
        groupBox->setWhatsThis(tr2i18n("This script is intended for the actual commands needed to connect to a remotely running executable.\n"
"	shell sleep 5	wait for remote program to start\n"
"	target remote ...	connect to the remote debugger\n"
"	continue	[optional] run debugging to the first breakpoint", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        groupBox->setTitle(tr2i18n("Remote Debugging", "@title:group"));
#if QT_CONFIG(tooltip)
        runShellScript_label->setToolTip(tr2i18n("<html><head/><body><p>Script to start remote application</p><p></p><p>This shell script is run after the Gdb Config script has been sourced by gdb.</p><p>It's purpose is to actually start the remote process.</p><p>1) Find a way to execute a command remotely - rsh, ssh, telnet, ...</p><p>2a) Execute &quot;gdbserver ... application&quot; on target.</p><p>or if your executable contains the gdb stub:</p><p>2b) Execute &quot;application&quot; on target.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        runShellScript_label->setText(tr2i18n("R&un shell script:", "@label:chooser Shell script to be executed at run time"));
#if QT_CONFIG(tooltip)
        kcfg_runShellScript->setToolTip(tr2i18n("<html><head/><body><p>Script to start remote application</p><p></p><p>This shell script is run after the Gdb Config script has been sourced by gdb.</p><p>It's purpose is to actually start the remote process.</p><p>1) Find a way to execute a command remotely - rsh, ssh, telnet, ...</p><p>2a) Execute &quot;gdbserver ... application&quot; on target.</p><p>or if your executable contains the gdb stub:</p><p>2b) Execute &quot;application&quot; on target.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        configGdbScript_label->setToolTip(tr2i18n("This script is sourced by gdb when the debugging starts.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        configGdbScript_label->setText(tr2i18n("Gdb &config script:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        kcfg_runGdbScript->setToolTip(tr2i18n("<html><head/><body><p>Script to connect with remote application</p><p>For example:</p><p>	shell sleep 5	 #wait for remote program to start</p><p>	target remote ...	#connect to the remote debugger</p><p>	continue	#[optional] run debugging to the first breakpoint.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        runGdbScript_label->setToolTip(tr2i18n("<html><head/><body><p>Script to connect with remote application</p><p>For example:</p><p>	shell sleep 5	 #wait for remote program to start</p><p>	target remote ...	#connect to the remote debugger</p><p>	continue	#[optional] run debugging to the first breakpoint.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        runGdbScript_label->setText(tr2i18n("Run &gdb script:", "@label:chooser Gdb script to be executed at run time."));
#if QT_CONFIG(tooltip)
        kcfg_configGdbScript->setToolTip(tr2i18n("This script is sourced by gdb when the debugging starts.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        (void)GdbConfigPage;
    } // retranslateUi

};

namespace Ui {
    class GdbConfigPage: public Ui_GdbConfigPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GDBCONFIGPAGE_H

