/****************************************************************************
** Meta object code from reading C++ file 'vcspluginhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/vcs/vcspluginhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vcspluginhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop15VcsPluginHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::VcsPluginHelper::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop15VcsPluginHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::VcsPluginHelper",
        "commit",
        "",
        "add",
        "revert",
        "history",
        "VcsRevision",
        "rev",
        "annotation",
        "annotationContextMenuAboutToShow",
        "KTextEditor::View*",
        "view",
        "QMenu*",
        "menu",
        "line",
        "diffToBase",
        "diffForRev",
        "diffForRevGlobal",
        "update",
        "pull",
        "push",
        "diffJobFinished",
        "KJob*",
        "job",
        "revertDone",
        "disposeEventually",
        "KTextEditor::Document*",
        "delayedModificationWarningOn",
        "handleAnnotationBorderVisibilityChanged",
        "visible"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'commit'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'add'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'revert'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'history'
        QtMocHelpers::SlotData<void(const VcsRevision &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'history'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'annotation'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'annotationContextMenuAboutToShow'
        QtMocHelpers::SlotData<void(KTextEditor::View *, QMenu *, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'diffToBase'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'diffForRev'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'diffForRevGlobal'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pull'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'push'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'diffJobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'revertDone'
        QtMocHelpers::SlotData<void(KJob *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'disposeEventually'
        QtMocHelpers::SlotData<void(KTextEditor::Document *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Slot 'disposeEventually'
        QtMocHelpers::SlotData<void(KTextEditor::View *, bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'delayedModificationWarningOn'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleAnnotationBorderVisibilityChanged'
        QtMocHelpers::SlotData<void(KTextEditor::View *, bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Bool, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VcsPluginHelper, qt_meta_tag_ZN8KDevelop15VcsPluginHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::VcsPluginHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15VcsPluginHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15VcsPluginHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop15VcsPluginHelperE_t>.metaTypes,
    nullptr
} };

void KDevelop::VcsPluginHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VcsPluginHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->commit(); break;
        case 1: _t->add(); break;
        case 2: _t->revert(); break;
        case 3: _t->history((*reinterpret_cast<std::add_pointer_t<VcsRevision>>(_a[1]))); break;
        case 4: _t->history(); break;
        case 5: _t->annotation(); break;
        case 6: _t->annotationContextMenuAboutToShow((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->diffToBase(); break;
        case 8: _t->diffForRev(); break;
        case 9: _t->diffForRevGlobal(); break;
        case 10: _t->update(); break;
        case 11: _t->pull(); break;
        case 12: _t->push(); break;
        case 13: _t->diffJobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 14: _t->revertDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 15: _t->disposeEventually((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1]))); break;
        case 16: _t->disposeEventually((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->delayedModificationWarningOn(); break;
        case 18: _t->handleAnnotationBorderVisibilityChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::VcsPluginHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::VcsPluginHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15VcsPluginHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::VcsPluginHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
