/****************************************************************************
** Meta object code from reading C++ file 'backgroundparser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/language/backgroundparser/backgroundparser.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'backgroundparser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop16BackgroundParserE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::BackgroundParser::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop16BackgroundParserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::BackgroundParser",
        "parseJobFinished",
        "",
        "KDevelop::ParseJob*",
        "job",
        "clearMessage",
        "KDevelop::IStatus*",
        "showMessage",
        "message",
        "timeout",
        "hideProgress",
        "showProgress",
        "minimum",
        "maximum",
        "value",
        "showErrorMessage",
        "abortAllJobs",
        "suspend",
        "resume",
        "revertAllRequests",
        "notifyWhenReady",
        "addDocument",
        "IndexedString",
        "url",
        "TopDUContext::Features",
        "features",
        "priority",
        "ParseJob::SequentialProcessingFlags",
        "flags",
        "delay_ms",
        "addListenerToDocumentIfExist",
        "removeDocument",
        "parseDocuments",
        "updateProgressData",
        "setNeededPriority",
        "disableProcessing",
        "enableProcessing",
        "documentClosed",
        "KDevelop::IDocument*",
        "documentLoaded",
        "documentUrlChanged",
        "loadSettings",
        "parseComplete",
        "ThreadWeaver::JobPointer",
        "parseProgress",
        "text",
        "startTimer",
        "delay",
        "aboutToQuit",
        "updateProgressBar",
        "projectAboutToBeOpened",
        "KDevelop::IProject*",
        "project",
        "projectOpened",
        "projectOpeningAborted"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'parseJobFinished'
        QtMocHelpers::SignalData<void(KDevelop::ParseJob *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'clearMessage'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'showMessage'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *, const QString &, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::QString, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'showMessage'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *, const QString &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'hideProgress'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'showProgress'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *, int, int, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::Int, 12 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'abortAllJobs'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'suspend'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resume'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'revertAllRequests'
        QtMocHelpers::SlotData<void(QObject *)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 20 },
        }}),
        // Slot 'addDocument'
        QtMocHelpers::SlotData<void(const IndexedString &, TopDUContext::Features, int, QObject *, ParseJob::SequentialProcessingFlags, int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 26 }, { QMetaType::QObjectStar, 20 },
            { 0x80000000 | 27, 28 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'addDocument'
        QtMocHelpers::SlotData<void(const IndexedString &, TopDUContext::Features, int, QObject *, ParseJob::SequentialProcessingFlags)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 26 }, { QMetaType::QObjectStar, 20 },
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'addDocument'
        QtMocHelpers::SlotData<void(const IndexedString &, TopDUContext::Features, int, QObject *)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 26 }, { QMetaType::QObjectStar, 20 },
        }}),
        // Slot 'addDocument'
        QtMocHelpers::SlotData<void(const IndexedString &, TopDUContext::Features, int)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 26 },
        }}),
        // Slot 'addDocument'
        QtMocHelpers::SlotData<void(const IndexedString &, TopDUContext::Features)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'addDocument'
        QtMocHelpers::SlotData<void(const IndexedString &)>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'addListenerToDocumentIfExist'
        QtMocHelpers::SlotData<bool(const IndexedString &, TopDUContext::Features, int, QObject *, ParseJob::SequentialProcessingFlags, int)>(30, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 26 }, { QMetaType::QObjectStar, 20 },
            { 0x80000000 | 27, 28 }, { QMetaType::Int, 29 },
        }}),
        // Slot 'addListenerToDocumentIfExist'
        QtMocHelpers::SlotData<bool(const IndexedString &, TopDUContext::Features, int, QObject *, ParseJob::SequentialProcessingFlags)>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 26 }, { QMetaType::QObjectStar, 20 },
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'addListenerToDocumentIfExist'
        QtMocHelpers::SlotData<bool(const IndexedString &, TopDUContext::Features, int, QObject *)>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 26 }, { QMetaType::QObjectStar, 20 },
        }}),
        // Slot 'addListenerToDocumentIfExist'
        QtMocHelpers::SlotData<bool(const IndexedString &, TopDUContext::Features, int)>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Int, 26 },
        }}),
        // Slot 'addListenerToDocumentIfExist'
        QtMocHelpers::SlotData<bool(const IndexedString &, TopDUContext::Features)>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'addListenerToDocumentIfExist'
        QtMocHelpers::SlotData<bool(const IndexedString &)>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'removeDocument'
        QtMocHelpers::SlotData<void(const IndexedString &, QObject *)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 }, { QMetaType::QObjectStar, 20 },
        }}),
        // Slot 'removeDocument'
        QtMocHelpers::SlotData<void(const IndexedString &)>(31, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'parseDocuments'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateProgressData'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setNeededPriority'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'disableProcessing'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableProcessing'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'documentClosed'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'documentLoaded'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'documentUrlChanged'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 2 },
        }}),
        // Slot 'loadSettings'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'parseComplete'
        QtMocHelpers::SlotData<void(const ThreadWeaver::JobPointer &)>(42, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 43, 4 },
        }}),
        // Slot 'parseProgress'
        QtMocHelpers::SlotData<void(KDevelop::ParseJob *, float, const QString &)>(44, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Float, 14 }, { QMetaType::QString, 45 },
        }}),
        // Slot 'startTimer'
        QtMocHelpers::SlotData<void(int)>(46, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 47 },
        }}),
        // Slot 'aboutToQuit'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateProgressBar'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'projectAboutToBeOpened'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'projectOpened'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'projectOpeningAborted'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BackgroundParser, qt_meta_tag_ZN8KDevelop16BackgroundParserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::BackgroundParser::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop16BackgroundParserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop16BackgroundParserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop16BackgroundParserE_t>.metaTypes,
    nullptr
} };

void KDevelop::BackgroundParser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BackgroundParser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->parseJobFinished((*reinterpret_cast<std::add_pointer_t<KDevelop::ParseJob*>>(_a[1]))); break;
        case 1: _t->clearMessage((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1]))); break;
        case 2: _t->showMessage((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->showMessage((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->hideProgress((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1]))); break;
        case 5: _t->showProgress((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 6: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->abortAllJobs(); break;
        case 8: _t->suspend(); break;
        case 9: _t->resume(); break;
        case 10: _t->revertAllRequests((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 11: _t->addDocument((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<ParseJob::SequentialProcessingFlags>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6]))); break;
        case 12: _t->addDocument((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<ParseJob::SequentialProcessingFlags>>(_a[5]))); break;
        case 13: _t->addDocument((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[4]))); break;
        case 14: _t->addDocument((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 15: _t->addDocument((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2]))); break;
        case 16: _t->addDocument((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1]))); break;
        case 17: { bool _r = _t->addListenerToDocumentIfExist((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<ParseJob::SequentialProcessingFlags>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->addListenerToDocumentIfExist((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<ParseJob::SequentialProcessingFlags>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->addListenerToDocumentIfExist((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->addListenerToDocumentIfExist((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->addListenerToDocumentIfExist((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TopDUContext::Features>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->addListenerToDocumentIfExist((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->removeDocument((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 24: _t->removeDocument((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1]))); break;
        case 25: _t->parseDocuments(); break;
        case 26: _t->updateProgressData(); break;
        case 27: _t->setNeededPriority((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->disableProcessing(); break;
        case 29: _t->enableProcessing(); break;
        case 30: _t->documentClosed((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 31: _t->documentLoaded((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 32: _t->documentUrlChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 33: _t->loadSettings(); break;
        case 34: _t->parseComplete((*reinterpret_cast<std::add_pointer_t<ThreadWeaver::JobPointer>>(_a[1]))); break;
        case 35: _t->parseProgress((*reinterpret_cast<std::add_pointer_t<KDevelop::ParseJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 36: _t->startTimer((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->aboutToQuit(); break;
        case 38: _t->updateProgressBar(); break;
        case 39: _t->projectAboutToBeOpened((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 40: _t->projectOpened((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 41: _t->projectOpeningAborted((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::ParseJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ThreadWeaver::JobPointer >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::ParseJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BackgroundParser::*)(KDevelop::ParseJob * )>(_a, &BackgroundParser::parseJobFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BackgroundParser::*)(KDevelop::IStatus * )>(_a, &BackgroundParser::clearMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BackgroundParser::*)(KDevelop::IStatus * , const QString & , int )>(_a, &BackgroundParser::showMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BackgroundParser::*)(KDevelop::IStatus * )>(_a, &BackgroundParser::hideProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BackgroundParser::*)(KDevelop::IStatus * , int , int , int )>(_a, &BackgroundParser::showProgress, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BackgroundParser::*)(const QString & , int )>(_a, &BackgroundParser::showErrorMessage, 6))
            return;
    }
}

const QMetaObject *KDevelop::BackgroundParser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::BackgroundParser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop16BackgroundParserE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "IStatus"))
        return static_cast< IStatus*>(this);
    if (!strcmp(_clname, "org.kdevelop.IStatus"))
        return static_cast< KDevelop::IStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::BackgroundParser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::BackgroundParser::parseJobFinished(KDevelop::ParseJob * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevelop::BackgroundParser::clearMessage(KDevelop::IStatus * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDevelop::BackgroundParser::showMessage(KDevelop::IStatus * _t1, const QString & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void KDevelop::BackgroundParser::hideProgress(KDevelop::IStatus * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KDevelop::BackgroundParser::showProgress(KDevelop::IStatus * _t1, int _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 6
void KDevelop::BackgroundParser::showErrorMessage(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
