/****************************************************************************
** Meta object code from reading C++ file 'contextbrowser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/plugins/contextbrowser/contextbrowser.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'contextbrowser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20ContextBrowserPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto ContextBrowserPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN20ContextBrowserPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ContextBrowserPlugin",
        "showUsesDelayed",
        "",
        "KDevelop::DeclarationPointer",
        "declaration",
        "previousContextShortcut",
        "nextContextShortcut",
        "startDelayedBrowsing",
        "KTextEditor::View*",
        "view",
        "stopDelayedBrowsing",
        "invokeAction",
        "index",
        "previousUseShortcut",
        "nextUseShortcut",
        "declarationSelectedInUI",
        "decl",
        "updateReady",
        "KDevelop::IndexedString",
        "url",
        "KDevelop::ReferencedTopDUContext",
        "topContext",
        "textDocumentCreated",
        "KDevelop::IDocument*",
        "document",
        "documentActivated",
        "viewDestroyed",
        "obj",
        "cursorPositionChanged",
        "KTextEditor::Cursor",
        "newPosition",
        "viewCreated",
        "KTextEditor::Document*",
        "updateViews",
        "hideToolTip",
        "findUses",
        "textInserted",
        "doc",
        "cursor",
        "text",
        "selectionChanged",
        "historyNext",
        "historyPrevious",
        "colorSetupChanged",
        "documentJumpPerformed",
        "newDocument",
        "newCursor",
        "previousDocument",
        "previousCursor",
        "nextMenuAboutToShow",
        "previousMenuAboutToShow",
        "actionTriggered",
        "navigateLeft",
        "navigateRight",
        "navigateUp",
        "navigateDown",
        "navigateAccept",
        "navigateBack"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showUsesDelayed'
        QtMocHelpers::SlotData<void(const KDevelop::DeclarationPointer &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'previousContextShortcut'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextContextShortcut'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startDelayedBrowsing'
        QtMocHelpers::SlotData<void(KTextEditor::View *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'stopDelayedBrowsing'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'invokeAction'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'previousUseShortcut'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextUseShortcut'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'declarationSelectedInUI'
        QtMocHelpers::SlotData<void(const KDevelop::DeclarationPointer &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 16 },
        }}),
        // Slot 'updateReady'
        QtMocHelpers::SlotData<void(const KDevelop::IndexedString &, const KDevelop::ReferencedTopDUContext &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'textDocumentCreated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'documentActivated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Slot 'viewDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 27 },
        }}),
        // Slot 'cursorPositionChanged'
        QtMocHelpers::SlotData<void(KTextEditor::View *, const KTextEditor::Cursor &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'viewCreated'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, KTextEditor::View *)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Slot 'updateViews'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hideToolTip'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findUses'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'textInserted'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, const KTextEditor::Cursor &, const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 37 }, { 0x80000000 | 29, 38 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(KTextEditor::View *)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'historyNext'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'historyPrevious'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'colorSetupChanged'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'documentJumpPerformed'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *, const KTextEditor::Cursor &, KDevelop::IDocument *, const KTextEditor::Cursor &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 45 }, { 0x80000000 | 29, 46 }, { 0x80000000 | 23, 47 }, { 0x80000000 | 29, 48 },
        }}),
        // Slot 'nextMenuAboutToShow'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'previousMenuAboutToShow'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'actionTriggered'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'navigateLeft'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'navigateRight'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'navigateUp'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'navigateDown'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'navigateAccept'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'navigateBack'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ContextBrowserPlugin, qt_meta_tag_ZN20ContextBrowserPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ContextBrowserPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContextBrowserPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContextBrowserPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ContextBrowserPluginE_t>.metaTypes,
    nullptr
} };

void ContextBrowserPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ContextBrowserPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showUsesDelayed((*reinterpret_cast<std::add_pointer_t<KDevelop::DeclarationPointer>>(_a[1]))); break;
        case 1: _t->previousContextShortcut(); break;
        case 2: _t->nextContextShortcut(); break;
        case 3: _t->startDelayedBrowsing((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 4: _t->stopDelayedBrowsing(); break;
        case 5: _t->invokeAction((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->previousUseShortcut(); break;
        case 7: _t->nextUseShortcut(); break;
        case 8: _t->declarationSelectedInUI((*reinterpret_cast<std::add_pointer_t<KDevelop::DeclarationPointer>>(_a[1]))); break;
        case 9: _t->updateReady((*reinterpret_cast<std::add_pointer_t<KDevelop::IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDevelop::ReferencedTopDUContext>>(_a[2]))); break;
        case 10: _t->textDocumentCreated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 11: _t->documentActivated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 12: _t->viewDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 13: _t->cursorPositionChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2]))); break;
        case 14: _t->viewCreated((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[2]))); break;
        case 15: _t->updateViews(); break;
        case 16: _t->hideToolTip(); break;
        case 17: _t->findUses(); break;
        case 18: _t->textInserted((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 20: _t->historyNext(); break;
        case 21: _t->historyPrevious(); break;
        case 22: _t->colorSetupChanged(); break;
        case 23: _t->documentJumpPerformed((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[4]))); break;
        case 24: _t->nextMenuAboutToShow(); break;
        case 25: _t->previousMenuAboutToShow(); break;
        case 26: _t->actionTriggered(); break;
        case 27: _t->navigateLeft(); break;
        case 28: _t->navigateRight(); break;
        case 29: _t->navigateUp(); break;
        case 30: _t->navigateDown(); break;
        case 31: _t->navigateAccept(); break;
        case 32: _t->navigateBack(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::DeclarationPointer >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::DeclarationPointer >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IndexedString >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ContextBrowserPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ContextBrowserPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ContextBrowserPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KDevelop::IContextBrowser"))
        return static_cast< KDevelop::IContextBrowser*>(this);
    if (!strcmp(_clname, "org.kdevelop.IContextBrowser"))
        return static_cast< KDevelop::IContextBrowser*>(this);
    return KDevelop::IPlugin::qt_metacast(_clname);
}

int ContextBrowserPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}
QT_WARNING_POP
