/********************************************************************************
** Form generated from reading UI file 'overridevirtuals.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OVERRIDEVIRTUALS_H
#define UI_OVERRIDEVIRTUALS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_OverridesDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_3;
    QTreeWidget *overridesTree;
    QHBoxLayout *horizontalLayout;
    QPushButton *selectAllPushButton;
    QPushButton *deselectAllPushButton;
    QWidget *extraFunctionWidget;

    void setupUi(QWidget *OverridesDialog)
    {
        if (OverridesDialog->objectName().isEmpty())
            OverridesDialog->setObjectName("OverridesDialog");
        OverridesDialog->resize(720, 531);
        verticalLayout_2 = new QVBoxLayout(OverridesDialog);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(OverridesDialog);
        groupBox->setObjectName("groupBox");
        verticalLayout_3 = new QVBoxLayout(groupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        overridesTree = new QTreeWidget(groupBox);
        overridesTree->setObjectName("overridesTree");
        overridesTree->setRootIsDecorated(false);
        overridesTree->setUniformRowHeights(false);
        overridesTree->setItemsExpandable(false);
        overridesTree->setAllColumnsShowFocus(true);
        overridesTree->setExpandsOnDoubleClick(false);

        verticalLayout_3->addWidget(overridesTree);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        selectAllPushButton = new QPushButton(groupBox);
        selectAllPushButton->setObjectName("selectAllPushButton");

        horizontalLayout->addWidget(selectAllPushButton);

        deselectAllPushButton = new QPushButton(groupBox);
        deselectAllPushButton->setObjectName("deselectAllPushButton");

        horizontalLayout->addWidget(deselectAllPushButton);

        extraFunctionWidget = new QWidget(groupBox);
        extraFunctionWidget->setObjectName("extraFunctionWidget");

        horizontalLayout->addWidget(extraFunctionWidget);


        verticalLayout_3->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(groupBox);


        retranslateUi(OverridesDialog);

        QMetaObject::connectSlotsByName(OverridesDialog);
    } // setupUi

    void retranslateUi(QWidget *OverridesDialog)
    {
        groupBox->setTitle(tr2i18n("Select any methods you would like to override in the new class.", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = overridesTree->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Properties", "@title:column"));
        ___qtreewidgetitem->setText(1, tr2i18n("Access", "@title:column"));
        ___qtreewidgetitem->setText(0, tr2i18n("Superclass -> Function", "@title:column"));
        selectAllPushButton->setText(tr2i18n("Select &All", "@action:button"));
        deselectAllPushButton->setText(tr2i18n("&Deselect All", "@action:button"));
        (void)OverridesDialog;
    } // retranslateUi

};

namespace Ui {
    class OverridesDialog: public Ui_OverridesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OVERRIDEVIRTUALS_H

