/****************************************************************************
** Meta object code from reading C++ file 'idebugsession.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.08.0/kdevplatform/debugger/interfaces/idebugsession.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'idebugsession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop13IDebugSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::IDebugSession::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop13IDebugSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::IDebugSession",
        "stateChanged",
        "",
        "KDevelop::IDebugSession::DebuggerState",
        "state",
        "showStepInSource",
        "QUrl",
        "file",
        "line",
        "addr",
        "showStepInDisassemble",
        "clearExecutionPoint",
        "raiseFramestackViews",
        "event",
        "IDebugSession::event_t",
        "e",
        "restartDebugger",
        "stopDebugger",
        "killDebuggerNow",
        "interruptDebugger",
        "run",
        "runToCursor",
        "jumpToCursor",
        "stepOver",
        "stepIntoInstruction",
        "stepInto",
        "stepOverInstruction",
        "stepOut",
        "DebuggerState",
        "NotStartedState",
        "StartingState",
        "ActiveState",
        "PausedState",
        "StoppingState",
        "StoppedState",
        "EndedState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(KDevelop::IDebugSession::DebuggerState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'showStepInSource'
        QtMocHelpers::SignalData<void(const QUrl &, int, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'showStepInDisassemble'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'clearExecutionPoint'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raiseFramestackViews'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'event'
        QtMocHelpers::SignalData<void(IDebugSession::event_t)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'restartDebugger'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopDebugger'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'killDebuggerNow'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'interruptDebugger'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'run'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'runToCursor'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jumpToCursor'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepOver'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepIntoInstruction'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepInto'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepOverInstruction'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepOut'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DebuggerState'
        QtMocHelpers::EnumData<enum DebuggerState>(28, 28, QMC::EnumFlags{}).add({
            {   29, DebuggerState::NotStartedState },
            {   30, DebuggerState::StartingState },
            {   31, DebuggerState::ActiveState },
            {   32, DebuggerState::PausedState },
            {   33, DebuggerState::StoppingState },
            {   34, DebuggerState::StoppedState },
            {   35, DebuggerState::EndedState },
        }),
    };
    return QtMocHelpers::metaObjectData<IDebugSession, qt_meta_tag_ZN8KDevelop13IDebugSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::IDebugSession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13IDebugSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13IDebugSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop13IDebugSessionE_t>.metaTypes,
    nullptr
} };

void KDevelop::IDebugSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IDebugSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IDebugSession::DebuggerState>>(_a[1]))); break;
        case 1: _t->showStepInSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->showStepInDisassemble((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->clearExecutionPoint(); break;
        case 4: _t->raiseFramestackViews(); break;
        case 5: _t->event((*reinterpret_cast<std::add_pointer_t<IDebugSession::event_t>>(_a[1]))); break;
        case 6: _t->restartDebugger(); break;
        case 7: _t->stopDebugger(); break;
        case 8: _t->killDebuggerNow(); break;
        case 9: _t->interruptDebugger(); break;
        case 10: _t->run(); break;
        case 11: _t->runToCursor(); break;
        case 12: _t->jumpToCursor(); break;
        case 13: _t->stepOver(); break;
        case 14: _t->stepIntoInstruction(); break;
        case 15: _t->stepInto(); break;
        case 16: _t->stepOverInstruction(); break;
        case 17: _t->stepOut(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IDebugSession::*)(KDevelop::IDebugSession::DebuggerState )>(_a, &IDebugSession::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDebugSession::*)(const QUrl & , int , const QString & )>(_a, &IDebugSession::showStepInSource, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDebugSession::*)(const QString & )>(_a, &IDebugSession::showStepInDisassemble, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDebugSession::*)()>(_a, &IDebugSession::clearExecutionPoint, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDebugSession::*)()>(_a, &IDebugSession::raiseFramestackViews, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDebugSession::*)(IDebugSession::event_t )>(_a, &IDebugSession::event, 5))
            return;
    }
}

const QMetaObject *KDevelop::IDebugSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::IDebugSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13IDebugSessionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::IDebugSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::IDebugSession::stateChanged(KDevelop::IDebugSession::DebuggerState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevelop::IDebugSession::showStepInSource(const QUrl & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void KDevelop::IDebugSession::showStepInDisassemble(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDevelop::IDebugSession::clearExecutionPoint()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KDevelop::IDebugSession::raiseFramestackViews()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KDevelop::IDebugSession::event(IDebugSession::event_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
